(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     25287,        614]*)
(*NotebookOutlinePosition[     26001,        639]*)
(*  CellTagsIndexPosition[     25957,        635]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Definition of the commands of the button palette", "Subtitle"],

Cell[CellGroupData[{

Cell["Some initialisations", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Graphics`Graphics`;\)\), "\[IndentingNewLine]", 
    \(\(<< Graphics`MultipleListPlot`;\)\), "\[IndentingNewLine]", 
    \(\(SetDirectory["\<D:/fott/reflecMCA\>"];\)\), "\[IndentingNewLine]", 
    \(\(layersNB = First[Notebooks["\<layers.nb\>"]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(First::"first" \(\(:\)\(\ \)\) 
      "\!\({}\) has a length of zero and no first element."\)], "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constants definition.", "Section"],

Cell[BoxData[{
    \(\(me = 
        9.109*10^\(-31\);\)\ \ \ \t\ \ \ \ \ \  (*\ \ electron\ mass\ *) \), \
"\[IndentingNewLine]", 
    \(\(mn = 1.675*10^\(-27\);\)\ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      neutron\ mass\ *) \), "\[IndentingNewLine]", 
    \(\(hp = 6.626*10^\(-34\);\)\ \ \ \ \ \ \ \ \ \ \  (*\ 
      Planck' s\ contant\ *) \), "\[IndentingNewLine]", 
    \(hb = 1.0546*10^\(-34\); \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Planck' s\ constant\ h\ bar\ *) \[IndentingNewLine]hb2 = \ 
      1.1121811600000002*10^\(-68\);\), "\[IndentingNewLine]", 
    \(\(mu0 = 4*pi*10^\(-7\);\)\ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      vacuum\ permitivitty\ *) \), "\[IndentingNewLine]", 
    \(\(muB = \(-9.27408\)*10^\(-24\);\)\ \ \ \ \ \ \  (*\ 
      magneton\ de\ Bohr\ *) \), "\[IndentingNewLine]", 
    \(\(mun = \(-1.91\)*5.05082*10^\(-27\);\)\ \ \  (*\ %  
        neutron\ moment\ *) \ \ \), "\[IndentingNewLine]", 
    \(\(Deg = \ Pi/180;\)\  (*\ 
      facteur\ de\ conversion\ en\ radians\ *) \[IndentingNewLine]\)}], \
"Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reflectivity calculation routine.", "Section"],

Cell["\<\
INPUT\t:\tlambda, _Real\t: the neutron wavelength
\t\t\tangles, _Real\t: a 1-dim list of the incidence angles
\t\t\tz,_Real\t: a 1-dim vector of the layers thicknesses (from vacuum to \
substrate)
\t\t\tV, _Complex,\t: a 1-dim vector of the interaction potential in each \
layer
OUTPUT\t:\ta list of the reflected intensity corresponding to the input \
angles
REMARK\t:\tto be optimized for speed (see ReflecNP2)\
\>", "Text"],

Cell[BoxData[
    \(\(ReflecNPCompiled3 = 
        Compile[\[IndentingNewLine]{{\ 
              lambda, \ _Real}, \ {angles, \ _Real, \ 1}, \ {z, _Real, 
              1}, \ {V, \ _Complex, 
              1}}, \[IndentingNewLine]Module[\[IndentingNewLine]{\ 
              hb2over2mn, \ aux, nbrLayers, nbrPoints, 
              k, \ \ \[IndentingNewLine]q = {I}, \ qq, \ q0, \ Eq0, 
              Eq, \[IndentingNewLine]DD = {\ {I, 0}, {0, 0}}, 
              P = {\ {I, 0}, \ {\ 0, 0\ }}, \ M = {{I, 0}, {0, 0}}, \ R, \ 
              T}, \ \[IndentingNewLine]nbrLayers\  = \ \(Dimensions[
                  z]\)[\([1]\)]; \[IndentingNewLine]nbrPoints\  = \ \
\(Dimensions[angles]\)[\([1]\)]; \[IndentingNewLine]k = 
              2*Pi/\((lambda*10^\(-9\))\); \  (*\ 
              moment\ du\ neutron\ en\ SI\ *) \[IndentingNewLine]hb2over2mn = \
\(hb2/2\)/mn; \[IndentingNewLine]R = 
              Table[1.0, {nbrPoints}]; \[IndentingNewLine]T = 
              Table[1.0, {nbrPoints}]; \[IndentingNewLine]Eq0\  = \ 
              hb2over2mn*
                Table[1, {nbrLayers}]; \[IndentingNewLine]Do[\ \
\[IndentingNewLine]\t
              q0 = \ k*Sin[angles[\([i]\)]*Deg];  (*\ 
                comp . \ perp . \ du\ vecteur\ d' 
                  onde\ *) \[IndentingNewLine]\t
              Eq = q0*q0*Eq0; \  (*\ 
                energy\ cinetique\ perp . \ 
                    dans\ chaque\ couche\ *) \[IndentingNewLine]\t
              q = \((\((Eq - 
                          V)\)/\((hb2over2mn)\))\)^0.5; \ \ \
\[IndentingNewLine]\t (*\ 
                perp . \ 
                    wavevectors\ in\ each\ layer\ *) \[IndentingNewLine]\t
              Do[\ \[IndentingNewLine]\t\tqq = q[\([k]\)];  (*\ 
                  initialisation\ of\ the\ D\ matrix\ *) \[IndentingNewLine]\t\
\tDD = {\ {1, 1}, {qq, \(-qq\)}}; \[IndentingNewLine]\t\t (*\ 
                  initialisation\ of\ the\ propagation\ matrix\ \
*) \[IndentingNewLine]\t\taux = 
                  Exp[\(-I\)*qq*
                      z[\([k]\)]\ ]; \[IndentingNewLine]\t\tP = {\ {aux, 
                      0}, \ {\ 0, 1/aux\ }}; \[IndentingNewLine]\t\tIf[\ 
                  k \[Equal] 1, 
                  M = Inverse[DD], \[IndentingNewLine]\t\t\tIf[\ 
                    k \[Equal] nbrLayers, M = M . DD, 
                    M = M . DD . P . Inverse[DD]]];\[IndentingNewLine]\t, {k, 
                  nbrLayers}\[IndentingNewLine]\t]; \[IndentingNewLine]\t
              T[\([i]\)] = \((1/Abs[M[\([1, 1]\)]])\)^2; \[IndentingNewLine]\t
              R[\([i]\)] = \((Abs[M[\([2, 1]\)]]/
                      Abs[M[\([1, 1]\)]])\)^2\[IndentingNewLine], {i, 
                nbrPoints}\[IndentingNewLine]]; \[IndentingNewLine]R\
\[IndentingNewLine]]\[IndentingNewLine]];\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["\<\
Version calculant tous les coefficients interm\[EAcute]diaires de reflexion \
et de transmission\
\>", "Subsection"],

Cell["\<\
INPUT:\tlambda,_Real:the neutron wavelength
\t\tangles,_Real:a 1-dim list of the incidence angles
\t\tz,_Real:a 1-dim vector of the layers thicknesses (from vacuum to \
substrate)\t
\t\tV,_Complex,\t:a 1-dim vector of the interaction potential in each layer
OUTPUT:\ta list of the reflected intensity corresponding to the input angles
REMARK:\tto be optimized for speed (see ReflecNP2)\
\>", "Text"],

Cell[BoxData[
    \(Clear[ReflecNPCompiled4]\)], "Input"],

Cell[BoxData[
    \(\(ReflecNPCompiled4[\ lambda_, \ angles\ _, \ z_, \ 
          V_] := \[IndentingNewLine]Module[\[IndentingNewLine]{\ 
            hb2over2mn, \ aux, nbrLayers, nbrPoints, 
            k, \ \ \[IndentingNewLine]q = {I}, \ qq0, qq1, \ q0, \ Eq0, 
            Eq, \[IndentingNewLine]DD0 = {\ {I, 0}, {0, 0}}, 
            DD1 = {\ {I, 0}, {0, 0}}, \ P = {\ {I, 0}, \ {\ 0, 0\ }}, \ 
            M = {{I, 0}, {0, 0}}, \ R, \ 
            T}, \ \[IndentingNewLine]nbrLayers\  = \ \(Dimensions[
                z]\)[\([1]\)]; \[IndentingNewLine]nbrPoints\  = \ \
\(Dimensions[angles]\)[\([1]\)]; \[IndentingNewLine]k = 
            2*Pi/\((lambda*10^\(-9\))\); \  (*\ 
            moment\ du\ neutron\ en\ SI\ *) \[IndentingNewLine]hb2over2mn = \
\(hb2/2\)/mn; \[IndentingNewLine]R = 
            Table[1.0, {nbrPoints}]; \[IndentingNewLine]T = 
            Table[1.0, {nbrPoints}]; \[IndentingNewLine]Eq0\  = \ 
            hb2over2mn*
              Table[1, {nbrLayers}]; \[IndentingNewLine]Do[\ \
\[IndentingNewLine]\t
            q0 = \ k*Sin[angles[\([i]\)]*Deg];  (*\ 
              comp . \ perp . \ du\ vecteur\ d' onde\ *) \[IndentingNewLine]\t
            Eq = q0*q0*Eq0; \  (*\ 
              energy\ cinetique\ perp . \ 
                  dans\ chaque\ couche\ *) \[IndentingNewLine]\t
            q = \((\((Eq - 
                        V)\)/\((hb2over2mn)\))\)^0.5; \ \ \[IndentingNewLine]\
\t (*\ perp . \ wavevectors\ in\ each\ layer\ *) \[IndentingNewLine]\t
            Do[\ \[IndentingNewLine]\t\tqq0 = q[\([k]\)];  (*\ 
                initialisation\ of\ the\ D\ matrix\ *) \  (*\ 
                indice\ j*) \[IndentingNewLine]\t\tqq1 = 
                q[\([k + 1]\)]; \  (*\ 
                indice\ j + 
                  1\ *) \[IndentingNewLine]\t\tDD0 = {\ {1, 
                    1}, {qq0, \(-qq0\)}}; \ 
              Print[k, "\<DD0\>", 
                DD0]; \ \[IndentingNewLine]\t\tDD1 = {\ {1, 
                    1}, {qq1, \(-qq1\)}};  (*\ \(Print[k, "\<DD1\>", 
                    DD1];\)\ *) \[IndentingNewLine]\t\t (*\ 
                initialisation\ of\ the\ propagation\ matrix\ \
*) \[IndentingNewLine]\t\taux = 
                Exp[\(-I\)*qq1*
                    z[\([k]\)]\ ]; \[IndentingNewLine]\t\tP = {\ {aux, 
                    0}, \ {\ 0, 1/aux\ }};  (*\ \(If[k \[Equal] 2, 
                    Print[k, "\<P\>", P]];\)\ *) \[IndentingNewLine]\t\tIf[\ 
                k \[Equal] 1, M = Inverse[DD0] . DD1, 
                M = M . P . Inverse[DD0] . 
                    DD1];\[IndentingNewLine]\t\t (*\ \(Print["\<D-1*D\>", 
                    Inverse[DD0] . DD0];\)\ *) \[IndentingNewLine]\t, {k, 
                nbrLayers - 1}\[IndentingNewLine]\t]; \[IndentingNewLine]\t
            T[\([i]\)] = \((1/Abs[M[\([1, 1]\)]])\)^2; \[IndentingNewLine]\t
            R[\([i]\)] = \((Abs[M[\([2, 1]\)]]/Abs[M[\([1, 1]\)]])\)^2; \ 
            Print[i, R[\([i]\)]];\[IndentingNewLine], {i, 
              nbrPoints}\[IndentingNewLine]]; \[IndentingNewLine]Print[
            R];\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(\(ReflecNPCompiled5[\ lambda_, \ angles\ _, \ z_, \ 
        V_]\)\(:=\)\(\[IndentingNewLine]\)\(Module[\[IndentingNewLine]{\
hb2over2mn, \ aux, nbrLayers, nbrPoints, k, \ \ \[IndentingNewLine]q = {I}, \ 
          qq0, qq1, \ q0, \ Eq0, 
          Eq, \[IndentingNewLine]DD0 = {\ {I, 0}, {0, 0}}, 
          DD1 = {\ {I, 0}, {0, 0}}, \ P = {\ {I, 0}, \ {\ 0, 0\ }}, \ 
          M = {{I, 0}, {0, 0}}, \ R, \ 
          T\ }, \ \[IndentingNewLine]nbrLayers\  = \ \(Dimensions[
              z]\)[\([1]\)]; \[IndentingNewLine]nbrPoints\  = \ \(Dimensions[
              angles]\)[\([1]\)]; \[IndentingNewLine]k = 
          2*Pi/\((lambda*10^\(-9\))\); \  (*\ 
          moment\ du\ neutron\ en\ SI\ *) \[IndentingNewLine]hb2over2mn = \
\(hb2/2\)/mn; \[IndentingNewLine]R = 
          Table[1.0, {nbrPoints}]; \[IndentingNewLine]T = 
          Table[1.0, {nbrPoints}]; \[IndentingNewLine]Eq0\  = \ 
          hb2over2mn*
            Table[1, {nbrLayers}]; \[IndentingNewLine]Do[\ \
\[IndentingNewLine]\t
          q0 = \ k*Sin[angles[\([i]\)]*Deg];  (*\ 
            comp . \ perp . \ du\ vecteur\ d' onde\ *) \[IndentingNewLine]\t
          Eq = q0*q0*Eq0; \  (*\ 
            energy\ cinetique\ perp . \ 
                dans\ chaque\ couche\ *) \[IndentingNewLine]\t
          q = \((\((Eq - 
                      V)\)/\((hb2over2mn)\))\)^0.5; \ \ \[IndentingNewLine]\t \
(*\ perp . \ wavevectors\ in\ each\ layer\ *) \[IndentingNewLine]\t
          Do[\ \[IndentingNewLine]\t\tqq0 = q[\([k]\)];  (*\ 
              initialisation\ of\ the\ D\ matrix\ *) \  (*\ 
              indice\ j*) \[IndentingNewLine]\t\tqq1 = q[\([k + 1]\)]; \  (*\ 
              indice\ j + 
                1\ *) \[IndentingNewLine]\t\tDD0 = {\ {1, 
                  1}, {qq0, \(-qq0\)}}; \ 
            Print[k, "\<DD0\>", 
              DD0]; \ \[IndentingNewLine]\t\tDD1 = {\ {1, 
                  1}, {qq1, \(-qq1\)}};  (*\ \(Print[k, "\<DD1\>", 
                  DD1];\)\ *) \[IndentingNewLine]\t\t (*\ 
              initialisation\ of\ the\ propagation\ matrix\ \
*) \[IndentingNewLine]\t\taux = 
              Exp[\(-I\)*qq1*
                  z[\([k]\)]\ ]; \[IndentingNewLine]\t\tP = {\ {aux, 0}, \ {\ 
                  0, 1/aux\ }};  (*\ \(If[k \[Equal] 2, 
                  Print[k, "\<P\>", P]];\)\ *) \[IndentingNewLine]\t\tIf[\ 
              k \[Equal] 1, M = Inverse[DD0] . DD1, 
              M = 
                M . P . Inverse[DD0] . 
                  DD1];\[IndentingNewLine]\t\t (*\ \(Print["\<D-1*D\>", 
                  Inverse[DD0] . DD0];\)\ *) \[IndentingNewLine]\t, {k, 
              nbrLayers - 1}\[IndentingNewLine]\t]; \[IndentingNewLine]\t
          T[\([i]\)] = \((1/Abs[M[\([1, 1]\)]])\)^2; \[IndentingNewLine]\t
          R[\([i]\)] = \((Abs[M[\([2, 1]\)]]/Abs[M[\([1, 1]\)]])\)^2; \ 
          Print[i, R[\([i]\)]];\[IndentingNewLine], {i, 
            nbrPoints}\[IndentingNewLine]]; \[IndentingNewLine]Print["\<De la \
merde en boite\>"]\[IndentingNewLine]]\)\(\[IndentingNewLine]\)\)\)], "Input"],

Cell[BoxData[
    \(\(PlotReflecNP4[lambda_, angles_] := 
        Module[\[IndentingNewLine]{\ RR\ }, \[IndentingNewLine]NotebookFind[
            layersNB, "\<thickness\>", All]; 
          layersTable = NotebookRead[layersNB]; 
          layersAux = \(\(layersTable[\([1]\)]\)[\([1]\)]\)[\([1]\)]; 
          Layers = 
            ToExpression[
              layersAux[\([Range[
                    2, \(Dimensions[
                        layersAux]\)[\([1]\)]]]\)]]; \[IndentingNewLine]z = 
            Layers[\([All, 2]\)]*10^\(-9\); \  (*\ 
            vecteur\ des\ epaisseurs\ *) \[IndentingNewLine]b = 
            Layers[\([All, 6]\)]*10^\(-15\); \ \ \ \ \ \  (*\ 
            vecteur\ des\ longueurs\ de\ diffusion\ *) \[IndentingNewLine]d = 
            Layers[\([All, 
                  4]\)]*10^28; \[IndentingNewLine] (*\ \ \(calculation\ of\ \
the\ potential\ in\ each\ layer;\)\ *) \[IndentingNewLine]V = 
            2*Pi*hb*hb*d*b/mn; \[IndentingNewLine]RR = 
            ReflecNPCompiled4[lambda, angles, \ z, 
              V]; \[IndentingNewLine]Print[R]; \[IndentingNewLine] (*\ 
            LogListPlot[Transpose[{angles, RR}], \ 
              GridLines \[Rule] \ None, \ 
              PlotJoined \[Rule] \ 
                False\ ]\ *) \[IndentingNewLine]];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reflectivity plot routine.", "Section"],

Cell["\<\
INPUT\t:\tlambda, nuetron wavalength
\t\t\tangles, a 1-dim list of the incidence angles
OUTPUT\t:\tPlot of the reflectivity curve
REMARK\t:\tle pointeur \"layersNB\" vers le notebook doit etre a jour !\
\>", "Text"],

Cell[BoxData[
    \(\(PlotReflecNP[lambda_, angles_] := 
        Module[\[IndentingNewLine]{\ RR\ }, \[IndentingNewLine]NotebookFind[
            layersNB, "\<thickness\>", All]; 
          layersTable = NotebookRead[layersNB]; 
          layersAux = \(\(layersTable[\([1]\)]\)[\([1]\)]\)[\([1]\)]; 
          Layers = 
            ToExpression[
              layersAux[\([Range[
                    2, \(Dimensions[
                        layersAux]\)[\([1]\)]]]\)]]; \[IndentingNewLine]z = 
            Layers[\([All, 2]\)]*10^\(-9\); \  (*\ 
            vecteur\ des\ epaisseurs\ *) \[IndentingNewLine]b = 
            Layers[\([All, 6]\)]*10^\(-15\); \ \ \ \ \ \  (*\ 
            vecteur\ des\ longueurs\ de\ diffusion\ *) \[IndentingNewLine]d = 
            Layers[\([All, 
                  4]\)]*10^28; \[IndentingNewLine] (*\ \ \(calculation\ of\ \
the\ potential\ in\ each\ layer;\)\ *) \[IndentingNewLine]V = 
            2*Pi*hb*hb*d*b/mn; \[IndentingNewLine]RR = 
            ReflecNPCompiled3[lambda, angles, \ z, 
              V]; \ \[IndentingNewLine]LogListPlot[Transpose[{angles, RR}], \ 
            GridLines \[Rule] \ None, \ 
            PlotJoined \[Rule] \ True\ ]\[IndentingNewLine]];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Augmentation de 1 du nombre de couches", "Section"],

Cell["\<\
INPUT\t:\tle tableau dans le notbook \"layers.nb\" ( implicite )
OUTPUT\t:\ton rajoute une ligne vide au tableau
REMARK\t:\tle pointeur \"layersNB\" vers le notebook doit etre a jour !\
\>", "Text"],

Cell[BoxData[
    \(\(IncNbrLayers := 
        Module[\ {}, \[IndentingNewLine] (*\ 
            mise\ a\ jour\ de\ la\ variable\ "\<Layers\>"\ \
*) \[IndentingNewLine]NotebookFind[layersNB, "\<thickness\>", All]; 
          layersTable = NotebookRead[layersNB]; 
          layersAux = \(\(layersTable[\([1]\)]\)[\([1]\)]\)[\([1]\)]; 
          Layers = 
            ToExpression[
              layersAux[\([Range[
                    2, \(Dimensions[
                        layersAux]\)[\([1]\)]]]\)]]; \[IndentingNewLine] (*\ 
            addition\ d' une\ ligne\ vide\ *) \[IndentingNewLine]AppendTo[
            Layers, {0, 0, "\<n\>", 0, "\<n\>", 0, "\<n\>", 0, "\<n\>", 
              0, "\<n\>", 0, "\<n\>"}]; \[IndentingNewLine]layersAux = 
            Prepend[Layers, 
              layersAux[\([1]\)]]; \[IndentingNewLine]LT = \
\(layersTable[\([1]\)]\)[\([1]\)]; \[IndentingNewLine]LT[\([1]\)] = 
            layersAux; \[IndentingNewLine]NotebookFind[
            layersNB, "\<thickness\>", All]; 
          NotebookWrite[layersNB, Cell[BoxData[LT]]];];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Diminution de 1 du nombre de couches", "Section"],

Cell["\<\
INPUT\t:\tle tableau dans le notbook \"layers.nb\" ( implicite )
OUTPUT\t:\ton supprime la derni\[EGrave]re ligne du tableau 
REMARK\t:\tle pointeur \"layersNB\" vers le notebook doit etre a jour !\
\>", "Text"],

Cell[BoxData[
    \(\(DecNbrLayers\  := \ 
        Module[\ {}, \[IndentingNewLine] (*\ 
            mise\ a\ jour\ de\ la\ variable\ "\<Layers\>"\ \
*) \[IndentingNewLine]NotebookFind[layersNB, "\<thickness\>", All]; 
          layersTable = NotebookRead[layersNB]; 
          layersAux = \(\(layersTable[\([1]\)]\)[\([1]\)]\)[\([1]\)]; 
          Layers = 
            ToExpression[
              layersAux[\([Range[
                    2, \(Dimensions[
                        layersAux]\)[\([1]\)]]]\)]]; \[IndentingNewLine] (*\ 
            retrait\ de\ la\ derni\[EGrave]re\ ligne\ \
*) \[IndentingNewLine]Layers = 
            Drop[Layers, \(-1\)]; \[IndentingNewLine]layersAux = 
            Prepend[Layers, 
              layersAux[\([1]\)]]; \[IndentingNewLine]LT = \
\(layersTable[\([1]\)]\)[\([1]\)]; \[IndentingNewLine]LT[\([1]\)] = 
            layersAux; \[IndentingNewLine]NotebookFind[
            layersNB, "\<thickness\>", All]; 
          NotebookWrite[layersNB, Cell[BoxData[LT]]];];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simple tests", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IncN = 
      ButtonBox[StyleBox[RowBox[{"\<N+1\>"}]\n\ \ \ \ \ ], \ 
          ButtonEvaluator\  -> \ "\<Automatic\>", \ \
\[IndentingNewLine]ButtonFunction \[RuleDelayed] \
\((Notebook[{Cell[\(nbrLayers++\)]}])\), \[IndentingNewLine]\ 
          Active\  -> \ True]\  // \ DisplayForm\)], "Input"],

Cell[BoxData[
    TagBox[
      ButtonBox[\(N + 1\),
        ButtonFunction:>Notebook[ {
            Cell[ 
              Increment[ nbrLayers]]}],
        ButtonEvaluator->Automatic,
        Active->True],
      DisplayForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DecN = 
      ButtonBox[StyleBox[RowBox[{"\<N-1\>"}]\n\ \ \ \ \ ], \ 
          ButtonEvaluator\  -> \ "\<Automatic\>", \ \
\[IndentingNewLine]ButtonFunction \[RuleDelayed] \
\((Notebook[{Cell[\(nbrLayers--\)]}])\), \[IndentingNewLine]\ 
          Active\  -> \ True]\  // \ DisplayForm\)], "Input"],

Cell[BoxData[
    TagBox[
      ButtonBox[\(N - 1\),
        ButtonFunction:>Notebook[ {
            Cell[ 
              Decrement[ nbrLayers]]}],
        ButtonEvaluator->Automatic,
        Active->True],
      DisplayForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(nbrLayers\)], "Input"],

Cell[BoxData[
    \(nbrLayers\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GridBox[{{ButtonBox[StyleBox[RowBox[{"\<N+1\>"}]\n\ \ \ \ \ ], \ 
              ButtonEvaluator\  -> \ "\<Automatic\>", \ \
\[IndentingNewLine]ButtonFunction \[RuleDelayed] \
\((Notebook[{Cell[\(nbrLayers++\)]}])\), \[IndentingNewLine]\ 
              Active\  -> \ True], 
            ButtonBox[StyleBox[RowBox[{"\<N-1\>"}]\n\ \ \ \ \ ], \ 
              ButtonEvaluator\  -> \ "\<Automatic\>", \ \
\[IndentingNewLine]ButtonFunction \[RuleDelayed] \
\((Notebook[{Cell[\(nbrLayers--\)]}])\), \[IndentingNewLine]\ 
              Active\  -> \ True]}}, ColumnSpacings \[Rule] 0] // 
      DisplayForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            ButtonBox[\(N + 1\),
              ButtonFunction:>Notebook[ {
                  Cell[ 
                    Increment[ nbrLayers]]}],
              ButtonEvaluator->Automatic,
              Active->True], 
            ButtonBox[\(N - 1\),
              ButtonFunction:>Notebook[ {
                  Cell[ 
                    Decrement[ nbrLayers]]}],
              ButtonEvaluator->Automatic,
              Active->True]}
          },
        ColumnSpacings->0],
      DisplayForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definition of the palette", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GridBox[{{ButtonBox[StyleBox[RowBox[{"\<N+1\>"}]\n\ \ \ \ \ ], \ 
              ButtonEvaluator\  -> \ "\<Automatic\>", \ \
\[IndentingNewLine]ButtonFunction \[RuleDelayed] \((Notebook[{Cell[
                        IncNbrLayers]}])\), \[IndentingNewLine]\ 
              Active\  -> \ True], 
            ButtonBox[StyleBox[RowBox[{"\<N-1\>"}]\n\ \ \ \ \ ], \ 
              ButtonEvaluator\  -> \ "\<Automatic\>", \ \
\[IndentingNewLine]ButtonFunction \[RuleDelayed] \((Notebook[{Cell[
                        DecNbrLayers]}])\), \[IndentingNewLine]\ 
              Active\  -> \ True], \ 
            ButtonBox[StyleBox[RowBox[{"\<PLOT\>"}]\n\ \ \ \ \ ], \ 
              ButtonEvaluator\  -> \ "\<Automatic\>", \ \
\[IndentingNewLine]ButtonFunction \[RuleDelayed] \((Notebook[{Cell[
                        PlotReflecNP[0.4, angles]]}])\), \[IndentingNewLine]\ 
              Active\  -> \ True]}}, ColumnSpacings \[Rule] 0] // 
      DisplayForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            ButtonBox[\(N + 1\),
              ButtonFunction:>Notebook[ {
                  Cell[ IncNbrLayers]}],
              ButtonEvaluator->Automatic,
              Active->True], 
            ButtonBox[\(N - 1\),
              ButtonFunction:>Notebook[ {
                  Cell[ DecNbrLayers]}],
              ButtonEvaluator->Automatic,
              Active->True], 
            ButtonBox["PLOT",
              ButtonFunction:>Notebook[ {
                  Cell[ 
                    PlotReflecNP[ .40000000000000002, angles]]}],
              ButtonEvaluator->Automatic,
              Active->True]}
          },
        ColumnSpacings->0],
      DisplayForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Lecture du tableau Layers", "Subsection"],

Cell["\<\
INPUT:\tnone
OUTPUT:\tla variable <Layers> est updat\[EAcute]e a partir du notebook \
\"layers.nb\"
\t\tla variable <layersNum> est updat\[EAcute]e a partir du notebook \
\"layers.nb\"\
\>", "Text"],

Cell[BoxData[
    \(LitTableLayers := 
      Module[{}, \[IndentingNewLine]NotebookFind[layersNB, "\<thickness\>", 
          All]; layersTable = NotebookRead[layersNB]; 
        layersAux = \(\(layersTable[\([1]\)]\)[\([1]\)]\)[\([1]\)]; 
        Layers = 
          ToExpression[
            layersAux[\([Range[
                  2, \(Dimensions[
                      layersAux]\)[\([1]\)]]]\)]]; \[IndentingNewLine]LayersT \
= Transpose[
            Layers]; \[IndentingNewLine]layersNum = {}; \
\[IndentingNewLine]AppendTo[layersNum, 
          LayersT[\([2]\)]]; \[IndentingNewLine]AppendTo[layersNum, 
          LayersT[\([4]\)]]; \[IndentingNewLine]AppendTo[layersNum, 
          LayersT[\([6]\)]]; \[IndentingNewLine]AppendTo[layersNum, 
          LayersT[\([8]\)]]; \[IndentingNewLine]AppendTo[layersNum, 
          LayersT[\([10]\)]]; \[IndentingNewLine]AppendTo[layersNum, 
          LayersT[\([12]\)]]; \[IndentingNewLine]layersNum = 
          Transpose[layersNum];\[IndentingNewLine]]\)], "Input",
  InitializationCell->True],

Cell["\<\
=====================
L'essentiel du travail se situe au niveau de l'\[EAcute]valuation de Reflec
Pourquoi la Pr\[EAcute]cision machine standard ne suffit-elle pas?
=====================
Calcul du xhi\.b2\
\>", "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1800}, {0, 1367}},
AutoGeneratedPackage->Automatic,
WindowToolbars->"EditBar",
WindowSize->{977, 648},
WindowMargins->{{2, Automatic}, {Automatic, 0}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 68, 0, 64, "Subtitle"],

Cell[CellGroupData[{
Cell[1832, 55, 39, 0, 53, "Section"],

Cell[CellGroupData[{
Cell[1896, 59, 316, 5, 90, "Input",
  InitializationCell->True],
Cell[2215, 66, 126, 2, 24, "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2390, 74, 40, 0, 53, "Section"],
Cell[2433, 76, 1053, 20, 210, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[3523, 101, 52, 0, 53, "Section"],
Cell[3578, 103, 436, 10, 128, "Text"],
Cell[4017, 115, 2808, 50, 710, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[6850, 169, 126, 3, 47, "Subsection"],
Cell[6979, 174, 409, 8, 128, "Text"],
Cell[7391, 184, 57, 1, 30, "Input"],
Cell[7451, 187, 3084, 53, 710, "Input"],
Cell[10538, 242, 3047, 53, 730, "Input"],
Cell[13588, 297, 1299, 24, 270, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14936, 327, 45, 0, 53, "Section"],
Cell[14984, 329, 225, 5, 90, "Text"],
Cell[15212, 336, 1254, 23, 250, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[16503, 364, 57, 0, 53, "Section"],
Cell[16563, 366, 208, 4, 71, "Text"],
Cell[16774, 372, 1109, 21, 210, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[17920, 398, 55, 0, 53, "Section"],
Cell[17978, 400, 221, 4, 71, "Text"],
Cell[18202, 406, 1047, 21, 210, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[19286, 432, 31, 0, 53, "Section"],

Cell[CellGroupData[{
Cell[19342, 436, 319, 6, 90, "Input"],
Cell[19664, 444, 237, 8, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19938, 457, 319, 6, 90, "Input"],
Cell[20260, 465, 237, 8, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20534, 478, 42, 1, 30, "Input"],
Cell[20579, 481, 43, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20659, 487, 631, 11, 150, "Input"],
Cell[21293, 500, 553, 17, 33, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[21895, 523, 44, 0, 53, "Section"],

Cell[CellGroupData[{
Cell[21964, 527, 983, 16, 210, "Input"],
Cell[22950, 545, 728, 21, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23715, 571, 47, 0, 47, "Subsection"],
Cell[23765, 573, 208, 6, 71, "Text"],
Cell[23976, 581, 1040, 20, 270, "Input",
  InitializationCell->True],
Cell[25019, 603, 228, 6, 109, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

