(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     75285,       2522]*)
(*NotebookOutlinePosition[     76021,       2548]*)
(*  CellTagsIndexPosition[     75977,       2544]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Calcul de reflectivit\[EAcute] sur un syst\[EGrave]me de couches \
minces", "Title"],

Cell[CellGroupData[{

Cell["D\[EAcute]finition de quelques constantes", "Section"],

Cell[BoxData[{
    \(\(me = 
        9.109*10^\(-31\);\)\ \ \ \t\ \ \ \ \ \  (*\ \ electron\ mass\ *) \), \
"\[IndentingNewLine]", 
    \(\(mn = 1.675*10^\(-27\);\)\ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      neutron\ mass\ *) \), "\[IndentingNewLine]", 
    \(\(hp = 6.626*10^\(-34\);\)\ \ \ \ \ \ \ \ \ \ \  (*\ 
      Planck' s\ contant\ *) \), "\[IndentingNewLine]", 
    \(hb = 1.0546*10^\(-34\); \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Planck' s\ constant\ h\ bar\ *) \[IndentingNewLine]hb2 = \ 
      1.1121811600000002*10^\(-68\);\), "\[IndentingNewLine]", 
    \(\(mu0 = 4*pi*10^\(-7\);\)\ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      vacuum\ permitivitty\ *) \), "\[IndentingNewLine]", 
    \(\(muB = \(-9.27408\)*10^\(-24\);\)\ \ \ \ \ \ \  (*\ 
      magneton\ de\ Bohr\ *) \), "\[IndentingNewLine]", 
    \(\(mun = \(-1.91\)*5.05082*10^\(-27\);\)\ \ \  (*\ %  
        neutron\ moment\ *) \ \ \), "\[IndentingNewLine]", 
    \(\(Deg = \ Pi/180;\)\  (*\ 
      facteur\ de\ conversion\ en\ radians\ *) \[IndentingNewLine]\)}], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Trac\[EAcute] d'une courbe de r\[EAcute]flectivit\[EAcute] a partir du \
fichier \"layers.txt\"\
\>", "Section"],

Cell[BoxData[
    \(\(SetDirectory["\<F:/Simul/reflecMCA\>"];\)\)], "Input"],

Cell["\<\
% colonne 1 contains the thickness in nm
% colonne 2 contains the diffusion length in fm
% colonne 3 contains the magnetic field in \[Micro]B per atom
% colonne 4 contains the direction of the magnetic field (always supposed to \
be in the plane of th layers)
% colonne 5 contains the atomic density in atoms/m3\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Layers = Import["\<layers.txt\>", "\<Table\>"];\)\)], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(Layers\)\" is similar \
to existing symbol \"\!\(layers\)\"."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Layers\)], "Input"],

Cell[BoxData[
    \({{0, 0, 0, 0, 0}, {40, 10.3`, 0, 0, 9.15`}, {0, 4.15`, 0, 0, 
        5.`}}\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(z = Layers[\([All, 1]\)]*10^\(-9\);\)\  (*\ 
      vecteur\ des\ epaisseurs\ *) \), "\[IndentingNewLine]", 
    \(\(b = Layers[\([All, 2]\)]*10^\(-15\);\)\ \ \ \ \ \  (*\ 
      vecteur\ des\ longueur\ de\ diffusion\ *) \), "\[IndentingNewLine]", 
    \(\(d = 
        Layers[\([All, 
              5]\)]*10^28;\)\[IndentingNewLine] (*\ \ \(calculation\ of\ the\ \
potential\ in\ each\ layer;\)\ *) \), "\[IndentingNewLine]", 
    \(\(V = 2*Pi*hb*hb*d*b/mn;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(V\)], "Input"],

Cell[BoxData[
    \({0, 3.9318678225792994`*^-26, 8.656826072313698`*^-27}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Subroutine de calcul", "Subsection"],

Cell[BoxData[
    \(\(Iteration = 
        Compile[{{k, _Integer}, {nbrLayers, \ _Integer}, {q, _Complex}, {z, \
_Real}, \ {M, _Complex, 
              2}}, \[IndentingNewLine]Module[{DD = {\ {1, 1}, {q, \(-q\)}}, 
              P = {\ {\ Exp[\(-I\)*q*z], 0}, \ {\ 0, Exp[I*q*z]\ }}, \ 
              MM = {{I, 0}, {0, 0}}}, \ \[IndentingNewLine]\t
            If[\ k \[Equal] 1, 
              MM = Inverse[DD], \[IndentingNewLine]\t\tIf[\ 
                k \[Equal] nbrLayers, MM = N[M . DD], 
                MM = N[M . DD . P . Inverse[DD]]]]; \ \[IndentingNewLine]\t
            MM\[IndentingNewLine]]\[IndentingNewLine]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Iteration[1, 3, 1.1, 10, {{0, 0}, {0, 0}}]\)], "Input"],

Cell[BoxData[
    \({{\(\(0.5`\)\(\[InvisibleSpace]\)\) + 
          0.`\ \[ImaginaryI], \(\(0.45454545454545453`\)\(\[InvisibleSpace]\)\
\) + 0.`\ \[ImaginaryI]}, {\(\(0.5`\)\(\[InvisibleSpace]\)\) + 
          0.`\ \[ImaginaryI], \(-0.45454545454545453`\) + 
          0.`\ \[ImaginaryI]}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Function de calcul d'une courbe de reflectivit\[EAcute]", "Subsection"],

Cell["\<\
(* INPUT: \tangles_ : \ta table of angles en degr\[EAcute]s *)
(*        \tlambda_ : \tthe neutron wavelength (nm) *)
(* OUTPUT:\tRef_   : \ta Table of the reflectivities for the different \
incidence angle *)\
\>", "Text"],

Cell[BoxData[
    \(\(\(ReflecNP[angles_, 
        lambda_]\)\(:=\)\(\ \)\(Module[\[IndentingNewLine]{l, \ k, \ f1, \ 
          kp, \ q0, \ DD, \ P, \ T, R, \ M}, \[IndentingNewLine]l = 
          lambda*10^\(-9\); \  (*\ passage\ en\ SI\ *) \[IndentingNewLine]k = 
          2*Pi/l; \  (*\ moment\ du\ neutron\ *) \[IndentingNewLine]T = {}; 
        R = {}; \[IndentingNewLine]\[IndentingNewLine]Do[\ 
          f1 = angles[\([i]\)]*Pi/180; \  (*\ 
            passage\ en\ degr\[EAcute]s\ *) \[IndentingNewLine]\t
          kp\  = \ k*Cos[f1]; \  (*\ 
            composante\ planaire\ *) \[IndentingNewLine]\t
          q0\  = \ k*Sin[f1]; \ \  (*\ 
            composante\ perpendiculaire\ *) \[IndentingNewLine]\t
          nbrLayers\  = \ \(Dimensions[z]\)[\([1]\)]; \[IndentingNewLine]\t
          Eq = hb2*q0*\(q0/2\)/mn*
              Table[1, {nbrLayers}]; \ \[IndentingNewLine]\t (*\ 
            energy\ cinetique\ perpendiculaire\ dans\ chaque\ couche\ \
*) \[IndentingNewLine]\t
          q = \((2*
                  mn*\((Eq - 
                        V)\)/\((hb2)\))\)^0.5; \ \[IndentingNewLine]\t (*\ \
\(Print[f1, kp, q0, nbrLayers, Eq, "\<  \>", 
                q];\)\ *) \[IndentingNewLine]\t (*\ 
            perpendicular\ wavevector\ in\ each\ layer\ \
*) \[IndentingNewLine]\t
          Do[\ \  (*\ 
              initialisation\ of\ the\ D\ matrix\ *) \[IndentingNewLine]\t\t\
DD = {\ {1, 1}, {q[\([k]\)], \(-q[\([k]\)]\)}}; \[IndentingNewLine]\t\t (*\ 
              initialisation\ of\ the\ propagation\ matrix\ \
*) \[IndentingNewLine]\t\tP = {\ {\ Exp[\(-I\)*q[\([k]\)]*z[\([k]\)]\ ], 
                  0}, \ {\ 0, 
                  Exp[I*q[\([k]\)]*
                      z[\([k]\)]]\ }}; \[IndentingNewLine]\t\t (*\ \(Print[
                  q[\([k]\)], z[\([k]\)]];\)\ *) \[IndentingNewLine]\t\t (*\ 
              Print[k]; Print[DD]; Print[P];\ *) \[IndentingNewLine]\t\tIf[\ 
              k \[Equal] 1, 
              M = N[Inverse[DD]], \[IndentingNewLine]\t\t\tIf[\ 
                k \[Equal] nbrLayers, M = N[M . DD], 
                M = N[M . DD . P . Inverse[DD]]]];\[IndentingNewLine]\t\t (*\ 
              Print[M]\ *) \[IndentingNewLine]\t, {k, 
              nbrLayers}\[IndentingNewLine]\t]; \[IndentingNewLine]\t
          AppendTo[T, Abs[1/M[\([1, 1]\)]]^2]; \[IndentingNewLine]\t
          AppendTo[R, 
            Abs[M[\([2, 1]\)]/
                  M[\([1, 1]\)]]^2\ ]\[IndentingNewLine], {i, \(Dimensions[
                
                angles]\)[\([1]\)]}\[IndentingNewLine]]; \
\[IndentingNewLine]ListPlot[
          Log[R]];\ \[IndentingNewLine]]\)\(\[IndentingNewLine]\)\)\)], \
"Input"],

Cell[BoxData[
    \(\(angles = Table[i, {i, 0.01, 2, 0.01}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ReflecNP[angles, 0.4];\)\  // Timing\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.603319 0.050776 [
[.2619 .59082 -6 -9 ]
[.2619 .59082 6 0 ]
[.5 .59082 -9 -9 ]
[.5 .59082 9 0 ]
[.7381 .59082 -9 -9 ]
[.7381 .59082 9 0 ]
[.97619 .59082 -9 -9 ]
[.97619 .59082 9 0 ]
[.01131 .09556 -18 -4.5 ]
[.01131 .09556 0 4.5 ]
[.01131 .19711 -12 -4.5 ]
[.01131 .19711 0 4.5 ]
[.01131 .29866 -12 -4.5 ]
[.01131 .29866 0 4.5 ]
[.01131 .40021 -12 -4.5 ]
[.01131 .40021 0 4.5 ]
[.01131 .50177 -12 -4.5 ]
[.01131 .50177 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .60332 m
.2619 .60957 L
s
[(50)] .2619 .59082 0 1 Mshowa
.5 .60332 m
.5 .60957 L
s
[(100)] .5 .59082 0 1 Mshowa
.7381 .60332 m
.7381 .60957 L
s
[(150)] .7381 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(200)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.21429 .60332 m
.21429 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.40476 .60332 m
.40476 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.59524 .60332 m
.59524 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.78571 .60332 m
.78571 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .09556 m
.03006 .09556 L
s
[(-10)] .01131 .09556 1 0 Mshowa
.02381 .19711 m
.03006 .19711 L
s
[(-8)] .01131 .19711 1 0 Mshowa
.02381 .29866 m
.03006 .29866 L
s
[(-6)] .01131 .29866 1 0 Mshowa
.02381 .40021 m
.03006 .40021 L
s
[(-4)] .01131 .40021 1 0 Mshowa
.02381 .50177 m
.03006 .50177 L
s
[(-2)] .01131 .50177 1 0 Mshowa
.125 Mabswid
.02381 .12095 m
.02756 .12095 L
s
.02381 .14633 m
.02756 .14633 L
s
.02381 .17172 m
.02756 .17172 L
s
.02381 .2225 m
.02756 .2225 L
s
.02381 .24789 m
.02756 .24789 L
s
.02381 .27327 m
.02756 .27327 L
s
.02381 .32405 m
.02756 .32405 L
s
.02381 .34944 m
.02756 .34944 L
s
.02381 .37483 m
.02756 .37483 L
s
.02381 .4256 m
.02756 .4256 L
s
.02381 .45099 m
.02756 .45099 L
s
.02381 .47638 m
.02756 .47638 L
s
.02381 .52715 m
.02756 .52715 L
s
.02381 .55254 m
.02756 .55254 L
s
.02381 .57793 m
.02756 .57793 L
s
.02381 .07017 m
.02756 .07017 L
s
.02381 .04478 m
.02756 .04478 L
s
.02381 .01939 m
.02756 .01939 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .60332 Mdot
.03333 .60332 Mdot
.0381 .60332 Mdot
.04286 .60332 Mdot
.04762 .60332 Mdot
.05238 .60332 Mdot
.05714 .60332 Mdot
.0619 .60332 Mdot
.06667 .60332 Mdot
.07143 .60332 Mdot
.07619 .60332 Mdot
.08095 .60332 Mdot
.08571 .60332 Mdot
.09048 .60332 Mdot
.09524 .60332 Mdot
.1 .60332 Mdot
.10476 .60332 Mdot
.10952 .60332 Mdot
.11429 .6033 Mdot
.11905 .60328 Mdot
.12381 .60326 Mdot
.12857 .60323 Mdot
.13333 .60321 Mdot
.1381 .60317 Mdot
.14286 .60313 Mdot
.14762 .60307 Mdot
.15238 .603 Mdot
.15714 .60291 Mdot
.1619 .6028 Mdot
.16667 .60265 Mdot
.17143 .60246 Mdot
.17619 .6022 Mdot
.18095 .60186 Mdot
.18571 .60141 Mdot
.19048 .60079 Mdot
.19524 .59994 Mdot
.2 .59875 Mdot
.20476 .59708 Mdot
.20952 .5947 Mdot
.21429 .59126 Mdot
.21905 .58625 Mdot
.22381 .57893 Mdot
.22857 .56824 Mdot
.23333 .55274 Mdot
.2381 .53052 Mdot
.24286 .49885 Mdot
.24762 .45262 Mdot
.25238 .37792 Mdot
.25714 .27451 Mdot
.2619 .36713 Mdot
.26667 .41809 Mdot
.27143 .44509 Mdot
.27619 .46091 Mdot
.28095 .47027 Mdot
.28571 .47536 Mdot
.29048 .47733 Mdot
.29524 .47681 Mdot
.3 .47414 Mdot
.30476 .46948 Mdot
.30952 .46288 Mdot
.31429 .45428 Mdot
.31905 .44349 Mdot
.32381 .43024 Mdot
.32857 .41403 Mdot
.33333 .39412 Mdot
.3381 .3692 Mdot
.34286 .33697 Mdot
.34762 .29289 Mdot
.35238 .23077 Mdot
.35714 .20406 Mdot
.3619 .26003 Mdot
.36667 .30285 Mdot
.37143 .3312 Mdot
.37619 .35092 Mdot
.38095 .36504 Mdot
.38571 .3752 Mdot
.39048 .38236 Mdot
.39524 .3871 Mdot
.4 .3898 Mdot
.40476 .39072 Mdot
.40952 .39 Mdot
.41429 .38774 Mdot
.41905 .38396 Mdot
.42381 .37866 Mdot
.42857 .37176 Mdot
.43333 .36312 Mdot
.4381 .35256 Mdot
.44286 .33974 Mdot
.44762 .32419 Mdot
.45238 .30516 Mdot
.45714 .28142 Mdot
.4619 .25085 Mdot
.46667 .20982 Mdot
.47143 .15658 Mdot
.47619 .13934 Mdot
.48095 .18612 Mdot
.48571 .22668 Mdot
.49048 .25532 Mdot
.49524 .27611 Mdot
.5 .29164 Mdot
.50476 .30338 Mdot
.50952 .31222 Mdot
.51429 .31873 Mdot
.51905 .32326 Mdot
.52381 .32609 Mdot
.52857 .32736 Mdot
.53333 .32718 Mdot
.5381 .32562 Mdot
.54286 .32269 Mdot
.54762 .31837 Mdot
.55238 .31261 Mdot
.55714 .30528 Mdot
.5619 .29624 Mdot
.56667 .28522 Mdot
.57143 .27186 Mdot
.57619 .2556 Mdot
.58095 .23555 Mdot
.58571 .21026 Mdot
.59048 .1773 Mdot
.59524 .1333 Mdot
.6 .08742 Mdot
.60476 .10238 Mdot
.60952 .14789 Mdot
.61429 .18301 Mdot
.61905 .20855 Mdot
.62381 .22765 Mdot
.62857 .24227 Mdot
.63333 .25355 Mdot
.6381 .26223 Mdot
.64286 .26877 Mdot
.64762 .27348 Mdot
.65238 .27658 Mdot
.65714 .27822 Mdot
.6619 .27848 Mdot
.66667 .27742 Mdot
.67143 .27506 Mdot
.67619 .27138 Mdot
.68095 .26632 Mdot
.68571 .25978 Mdot
.69048 .25163 Mdot
.69524 .24164 Mdot
.7 .2295 Mdot
.70476 .21473 Mdot
.70952 .19658 Mdot
.71429 .1739 Mdot
.71905 .14474 Mdot
.72381 .10612 Mdot
.72857 .05879 Mdot
.73333 .04614 Mdot
.7381 .08807 Mdot
.74286 .12722 Mdot
.74762 .15605 Mdot
.75238 .17758 Mdot
.75714 .19408 Mdot
.7619 .20692 Mdot
.76667 .21694 Mdot
.77143 .2247 Mdot
.77619 .23054 Mdot
.78095 .23472 Mdot
.78571 .23741 Mdot
.79048 .23871 Mdot
.79524 .23871 Mdot
.8 .23743 Mdot
.80476 .23487 Mdot
.80952 .23101 Mdot
.81429 .22578 Mdot
.81905 .21906 Mdot
.82381 .21071 Mdot
.82857 .20048 Mdot
.83333 .18802 Mdot
.8381 .17282 Mdot
.84286 .15406 Mdot
.84762 .13048 Mdot
.85238 .09995 Mdot
.85714 .05958 Mdot
.8619 .01472 Mdot
.86667 .01787 Mdot
.87143 .06136 Mdot
.87619 .09802 Mdot
.88095 .12515 Mdot
.88571 .14566 Mdot
.89048 .16152 Mdot
.89524 .17397 Mdot
.9 .18375 Mdot
.90476 .19136 Mdot
.90952 .19713 Mdot
.91429 .2013 Mdot
.91905 .20401 Mdot
.92381 .20537 Mdot
.92857 .20545 Mdot
.93333 .20427 Mdot
.9381 .20183 Mdot
.94286 .19811 Mdot
.94762 .19302 Mdot
.95238 .18648 Mdot
.95714 .17831 Mdot
.9619 .16828 Mdot
.96667 .15604 Mdot
.97143 .14109 Mdot
.97619 .12264 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gPP10`40000100000800002008200000
P800P020P<30`8f9HL:oYL3L`:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV
09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000
<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI
<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0
I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<
IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHc
VITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<
VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01V
c3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Ko
c9Woc<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2I
oc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D5
1@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5?okl0000000000000000000
00000>7PdZ2PY820P?l0003o0?oo0000ool0o`3oooooooooJOl00?ooJOl00?ooJOl00?ooJOl00?oo
JOl00?ooJOl00?ooJOl001[o00<0ool0oom<o`006_l00`3oo`3oodco000Jo`030?oo0?ooC?l001[o
00<0ool0oom<o`006_l00`3oo`3ooaSo0P0bo`006_l00`3oo`3ooaSo100`o`006_l20?oo6ol2033o
000Jo`030?oo0?ooC?l001[o00<0ool0oom<o`006_l00`3oo`3oodco000Jo`030?oo0?ooC?l001[o
00<0ool0oom<o`006_l00`3oo`3oodco000Jo`030?oo0?ooC?l001[o00<0ool0oom<o`006_l20>go
0P1Mo`006_l00`3oo`3/o`80GOl001[o00<0ool0oom<o`006_l00`3oo`3oodco000Jo`030?oo0>[o
0P1Oo`006_l00`3oo`3Zo`80:Ol200?o0P0_o`006_l00`3oo`3ooaKo0P03o`80;ol001[o00<0ool0
oom<o`006_l20?ooCOl001[o00<0ool0oom<o`006_l00`3oo`3oodco000Jo`030?oo0?ooC?l001[o
00<0ool0oom<o`006_l00`3oo`3oodco0008o`D00ol400Ko00<0ool0_ol202co0P1Lo`002_l00`3o
o`02o`030?oo00;o00<0ool00ol00`3oo`2oo`80;?l205co000:o`030?oo00;o00<0ool00_l00`3o
o`03o`030?oo0?ooC?l000D01Ol00`3oo`02o`030?oo00;o00<0ool00ol30?oo7Ol202go000:o`03
0?oo00;o00<0ool00_l00`3oo`03o`030?oo0?oo5Ol200Ko0P0]o`002_l00`3oo`02o`030?oo00;o
00<0ool00ol00`3oo`30o`80D_l203Go0008o`<01?l00`3oo`02o`030?oo00?o00<0ool0`?l202Ko
0P1Qo`002_l00`3oo`03o`@01_l00`3oo`3Xo`80HOl001[o00<0ool0oom<o`006_l00`3oo`3oodco
000Jo`030?oo0?ooC?l001[o0P3oodgo000Jo`030?oo0?oo?_l200co000Jo`030?oo0>oo0P0/o`80
7_l200co000Jo`030?oo0>oo0P0Qo`802Ol202co000Jo`030?oo0;go0P1Co`80=ol001[o00<0ool0
_Ol208co000Jo`030?oo09Go0P2do`006_l00`3oo`2Eo`80YOl200go000Jo`030?oo0>Oo0P1Co`80
3Ol001[o0P33o`808ol203Ko0P0Zo`006_l00`3oo`32o`80Fol202[o000Jo`030?oo0?oo4Ol203Wo
000Jo`030?oo09?o0P1Ko`807_l202So0P0?o`006_l00`3oo`2Co`80Fol204So0P0?o`006_l00`3o
o`3oob;o0P0Xo`006_l00`3oo`3oob;o0P0Xo`006_l00`3oo`3ooc[o0P0@o`006_l00`3oo`3ooc[o
0P0@o`006_l20>Ko0P0Xo`804Ol202Oo000Jo`030?oo0;_o0P0Xo`802ol201_o0P0Ao`809ol001[o
00<0ool0^ol203Go0P13o`804_l001[o00<0ool0`ol205oo0P0Ao`804_l001[o00<0ool0U_l202_o
0P1Oo`803ol201Co000@o`@01_l00`3oo`2Fo`80MOl202Ko0P0Do`003ol00`3oo`02o`030?oo00?o
00<0ool0ool>o`805_l202Co000?o`030?oo00;o00<0ool00ol00`3oo`3do`80;ol200go0P0Eo`00
1ol600;o00<0ool00_l00`3oo`03o`<0i?l200ko0P0ao`802Ol401Go000@o`@01_l00`3oo`3To`80
9_l201Wo1006o`<05ol000oo00<0ool00_l00`3oo`03o`030?oo06go0P2Mo`806ol300?o100Ho`00
3ol00`3oo`02o`030?oo00?o00<0ool0KOl208Ko0P0co`L06_l0013o1006o`030?oo09;o0P0Vo`80
2Ol202ko0P0Co`808?l301co000Jo`030?oo09;o0P0Vo`802Ol204?o0P0oo`006_l00`3oo`3Ro`80
Iol001[o00<0ool0h_l201?o0P0?o`80@Ol001[o00<0ool0mol200oo0P11o`006_l20?Wo0P1Ao`00
6_l00`3oo`2Ho`80;Ol202oo0P0=o`80@_l001[o00<0ool0Jol202_o0P0]o`805ol201So0P09o`@0
@_l001[o00<0ool0Jol207?o0P0Ho`802Ol204Co000Jo`030?oo0;So0P12o`<00ol404Go000Jo`03
0?oo0;So0P12o`X0AOl001[o00<0ool0b?l201Go0P0No`<0BOl001[o00<0ool0b?l201Go0P1Zo`00
6_l20?ooCOl001[o00<0ool0T?l204_o0P1/o`006_l00`3oo`2@o`80>?l2017o0P1/o`006_l00`3o
o`2Jo`806ol2017o0P1oo`006_l00`3oo`1^o`80:_l201_o0P0So`80KOl001[o00<0ool0K_l205_o
0P0?o`80KOl001[o00<0ool0bol200go0P1_o`006_l00`3oo`3=o`802ol206oo000Jo`030?oo0;Go
0P0Fo`802Ol2077o000Jo`80C?l206So0P0Ho`801_l3077o000Jo`030?oo04_o0P1>o`80<_l:07;o
000Jo`030?oo08ko0P0;o`80<ol707Co000Jo`030?oo08ko0P2ko`006_l00`3oo`2co`80U_l0017o
0`06o`030?oo0;?o0P2Fo`004?l01@3oool000Go00<0ool0J_l2037o0P2/o`004?l01@3oool000Go
00<0ool0J_l2037o0P0Co`80Uol000Oo1P03o`050?ooo`001Ol30;;o0P2Go`004?l400Ko00<0ool0
oom<o`004?l00`3oo`07o`030?oo073o0P0Ko`804?l200oo0P2Io`004Ol00`3oo`06o`030?oo073o
0P0Ko`804?l200oo0P2Io`004_l300Go00<0ool0oom<o`006_l00`3oo`2Po`803Ol209[o000Jo`03
0?oo0:3o0P0=o`80V_l001[o00<0ool0X_l200Wo0P2Lo`006_l00`3oo`2Ro`<01_l409co000Jo`80
S?l201Ko1003o`<0W_l001[o00<0ool0Rol201So1`2Oo`006_l00`3oo`1bo`80<ol30:7o000Jo`03
0?oo07;o0P3Go`006_l00`3oo`1Xo`80hOl001[o00<0ool0J?l2023o0P2oo`006_l00`3oo`2:o`80
_ol001[o00<0ool0oom<o`006_l20?ooCOl001[o00<0ool0Lol201?o0P31o`006_l00`3oo`1co`80
4ol20<7o000Jo`030?oo0?ooC?l001[o00<0ool0oom<o`006_l00`3oo`26o`80`ol001[o00<0ool0
COl202Ko0P0?o`80`ol001[o00<0ool0COl201Oo0P0=o`80e?l001[o00<0ool0I_l201go0P34o`00
6_l207Oo0P0=o`80a?l001[o00<0ool0BOl202_o0P0;o`80a_l001[o00<0ool0BOl202go0P09o`80
a_l001[o00<0ool0N?l200So0P37o`006_l00`3oo`1jo`801?l40<Oo000Jo`030?oo07[o2039o`00
4_l300Go00<0ool0IOl201Co1@3;o`004ol00`3oo`04o`030?oo06Go0P3To`004ol00`3oo`04o`03
0?oo0?ooC?l000Oo1P02o`H01Ol30?ooC?l0013o00@0ool01_l00`3oo`3oodco000@o`040?oo00Ko
00<0ool0oom<o`004Ol00`3o0006o`030?oo0?ooC?l001;o0P06o`030?oo06?o0P3Vo`006_l00`3o
o`1>o`804ol20>Ko000Jo`030?oo04ko0P3ko`006_l00`3oo`3oodco000Jo`80oom=o`006_l00`3o
o`1Ro`80iol001[o00<0ool0H_l20>Oo000Jo`030?oo0?ooC?l001[o00<0ool0oom<o`006_l00`3o
o`3oodco000Jo`030?oo053o0P0>o`80jOl001[o00<0ool0D?l200ko0P3Yo`006_l00`3oo`3oodco
000Jo`80BOl20?oo0_l001[o00<0ool0B?l201Co0P3[o`006_l00`3oo`1No`80jol001[o00<0ool0
DOl200[o0P3/o`006_l00`3oo`1Ao`802_l20>co000Jo`030?oo0?ooC?l001[o00<0ool0Dol200Ko
0P3^o`006_l00`3oo`1Co`801Ol30>ko000Jo`80E_l70>oo000Jo`030?oo05Go1@3ao`006_l00`3o
o`3oodco000Jo`030?oo0?ooC?l001[o00<0ool0oom<o`006_l00`3oo`3oodco000?o`D01_l00`3o
o`3oodco000?o`050?ooo`001_l00`3oo`3oodco000@o`030?oo00Oo00<0ool0A_l20?oo1?l000Oo
1P04o`030?oo00Ko0`16o`80ool4o`004_l00`3oo`05o`030?oo0?ooC?l001?o00<0ool01?l00`3o
o`3oodco000?o`050?ooo`001_l00`3oo`3oodco000@o`<01ol00`3oo`3oodco000Jo`030?oo0?oo
C?l001[o00<0ool0oom<o`006_l00`3oo`3oodco000Jo`80oom=o`006_l00`3oo`15o`80ool5o`00
6_l00`3oo`15o`80ool5o`006_l00`3oo`3oodco000Jo`030?oo0?ooC?l001[o00<0ool0oom<o`00
6_l00`3oo`3oodco000Jo`030?oo0?ooC?l001[o00<0ool0oom<o`006_l204Co0P3oo`Oo000Jo`03
0?oo04?o0P3oo`Oo000Jo`030?oo04Oo1004o`@0@Ol500?o1004o`@0??l500?o1004o`@0>ol500Co
1004o`@00ol001[o00<0ool0A_l00`3oo`02o`040?oo00Co00<0ool0@?l00`3oo`02o`030?oo00;o
00@0ool01?l00`3oo`0ko`030?oo00;o00<0ool00_l0103oo`04o`030?oo03So00D0oooo0003o`03
0?oo00;o00@0ool01?l1007o0Ol001[o00<0ool0Bol0103oo`04o`030?oo043o00<0ool00_l00`3o
o`02o`040?oo00Co00<0ool0>ol00`3oo`07o`040?oo00Co00<0ool0>Ol00`3oo`04o`030?oo00;o
00@0ool01?l1007o0Ol001[o00<0ool0@Ol200So00@0ool01?l00`3oo`10o`030?oo00;o00<0ool0
0_l0103oo`04o`030?oo03_o00<0ool01ol0103oo`04o`030?oo03[o00<0ool00ol00`3oo`02o`04
0?oo00Co0@01o`7o000Jo`030?oo047o0P04o`@00ol00`3oo`02o`030?oo043o00<0ool00_l00`3o
o`02o`040?oo00Co00<0ool0>ol00`3oo`03o`@00ol00`3oo`02o`030?oo03_o00<0ool00_l00`3o
o`02o`040?oo00Co0@01o`7o000Jo`030?oo04Oo00<0ool01?l00`3oo`02o`030?oo043o00<0ool0
0_l00`3oo`02o`040?oo00Co00<0ool0>ol00`3oo`03o`030?oo00Co00<0ool00_l00`3oo`0lo`05
0?ooo`001?l0103oo`04o`400Ol1o`006_l204So00<0ool01?l00`3oo`02o`030?oo03ko0`04o`03
0?oo00;o00@0ool01?l00`3oo`0io`<01Ol00`3oo`04o`030?oo00;o00<0ool0>?l01@3oool000?o
00<0ool00_l0103oo`04o`400Ol1o`006_l00`3oo`10o`801Ol500?o1013o`030?oo00?o1004o`@0
?_l00`3oo`03o`D00ol403co0`05o`@01?l400?o000Jo`030?oo043o0P3oo`[o000Jo`030?oo03ko
0P3oo`co000Jo`030?oo03ko0P3oo`co000Jo`030?oo03go0P3oo`go000Jo`030?oo03_o103oo`go
000Jo`030?oo03So1@3oo`oo000Jo`030?oo033o2`3ooa7o000Bool0D`04o`006_lc00go00<0ool0
3Ol00`3oo`0>o`030?oo00go00<0ool03Ol00`3oo`0=o`030?oo00go00<0ool03Ol00`3oo`0=o`03
0?oo00go00<0ool03Ol00`3oo`0=o`030?oo00go00<0ool03Ol00`3oo`0=o`030?oo00go00<0ool0
3Ol00`3oo`0:o`006_l00`3oo`1=o`030?oo04ko00<0ool0COl00`3oo`1=o`030?oo00[o000Jo`03
0?oo0?ooC?l001[o00<0ool0oom<o`006_l00`3oo`3oodco003oofWo003oofWo003oofWo003oofWo
003oofWo003oofWo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-16.6432, -12.2631, \
0.778736, 0.0730318}}],

Cell[BoxData[
    \({1.9799999999999969`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\(ReflecNPCompiled[angles_, 
        lambda_]\)\(:=\)\(\ \)\(Module[\[IndentingNewLine]{l, \ k, \ f1, \ 
          kp, \ q0, \ DD, \ P, \ T, R, \ 
          M = {{0, 0}, {0, 0}}}, \[IndentingNewLine]l = 
          lambda*10^\(-9\); \  (*\ passage\ en\ SI\ *) \[IndentingNewLine]k = 
          2*Pi/l; \  (*\ moment\ du\ neutron\ *) \[IndentingNewLine]T = {}; 
        R = {}; \[IndentingNewLine]\[IndentingNewLine]Do[\ 
          f1 = angles[\([i]\)]*Pi/180; \  (*\ 
            passage\ en\ degr\[EAcute]s\ *) \[IndentingNewLine]\t
          kp\  = \ k*Cos[f1]; \  (*\ 
            composante\ planaire\ *) \[IndentingNewLine]\t
          q0\  = \ k*Sin[f1]; \ \  (*\ 
            composante\ perpendiculaire\ *) \[IndentingNewLine]\t
          nbrLayers\  = \ \(Dimensions[z]\)[\([1]\)]; \[IndentingNewLine]\t
          Eq = hb*hb*q0*\(q0/2\)/mn*
              Table[1, {nbrLayers}]; \ \[IndentingNewLine]\t (*\ 
            energy\ cinetique\ perpendiculaire\ dans\ chaque\ couche\ \
*) \[IndentingNewLine]\t
          q = \((2*
                  mn*\((Eq - V)\)/\((hb*
                        hb)\))\)^0.5; \ \[IndentingNewLine]\t (*\ \(Print[f1, 
                kp, q0, nbrLayers, Eq, "\<  \>", 
                q];\)\ *) \[IndentingNewLine]\t (*\ 
            perpendicular\ wavevector\ in\ each\ layer\ \
*) \[IndentingNewLine]\t
          Do[\ \ M = 
              Iteration[k, nbrLayers, q[\([k]\)], z[\([k]\)], 
                M]\[IndentingNewLine]\t, {k, 
              nbrLayers}\[IndentingNewLine]\t]; \[IndentingNewLine]\t
          AppendTo[T, Abs[1/M[\([1, 1]\)]]^2]; \[IndentingNewLine]\t
          AppendTo[R, 
            Abs[M[\([2, 1]\)]/
                  M[\([1, 1]\)]]^2\ ]\ \[IndentingNewLine], {i, \(Dimensions[
                angles]\)[\([1]\)]}\[IndentingNewLine]]; \[IndentingNewLine] \
(*\ \(ListPlot[
              Log[R]];\)\ \
*) \[IndentingNewLine]]\)\(\[IndentingNewLine]\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ReflecNPCompiled[angles, 0.4];\)\  // Timing\)], "Input"],

Cell[BoxData[
    \({1.430000000000291`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\(Iteration2 = 
        Compile[{{nbrLayers, \ _Integer}, {q, _Complex, 1}, {z, _Real, 
              1}}, \[IndentingNewLine]Module[{DD = {\ {I, 0}, {0, 0}}, 
              P = {\ {I, 0}, \ {\ 0, 0\ }}, \ 
              M = {{I, 0}, {0, 0}}}, \ \[IndentingNewLine]Do[ (*\ 
                initialisation\ of\ the\ D\ matrix\ *) \[IndentingNewLine]\t
              DD = {\ {1, 
                    1}, {q[\([k]\)], \(-q[\([k]\)]\)}}; \[IndentingNewLine]\t \
(*\ initialisation\ of\ the\ propagation\ matrix\ *) \[IndentingNewLine]\t
              P = {\ {\ Exp[\(-I\)*q[\([k]\)]*z[\([k]\)]\ ], 0}, \ {\ 0, 
                    Exp[I*q[\([k]\)]*z[\([k]\)]]\ }}; \[IndentingNewLine]\t
              If[\ k \[Equal] 1, 
                M = N[Inverse[DD]], \[IndentingNewLine]\t\t\tIf[\ 
                  k \[Equal] nbrLayers, M = N[M . DD], 
                  M = N[M . DD . P . 
                        Inverse[DD]]]];\[IndentingNewLine]\t, {k, 
                nbrLayers}\[IndentingNewLine]\t]; \[IndentingNewLine]\t
            M\[IndentingNewLine]]\[IndentingNewLine]];\)\(\[IndentingNewLine]\
\)\)\)], "Input"],

Cell[BoxData[
    \(\(\(ReflecNPCompiled2[angles_, 
        lambda_]\)\(:=\)\(\ \)\(Module[\[IndentingNewLine]{l, \ k, \ f1, \ 
          kp, \ q0, \ DD, \ P, \ T, R, \ 
          M = {{I, 0}, {0, 0}}}, \[IndentingNewLine]l = 
          lambda*10^\(-9\); \  (*\ passage\ en\ SI\ *) \[IndentingNewLine]k = 
          2*Pi/l; \  (*\ moment\ du\ neutron\ *) \[IndentingNewLine]T = {}; \ 
        R = {}; \[IndentingNewLine]Do[\ 
          f1 = angles[\([i]\)]*Pi/180; \  (*\ 
            passage\ en\ degr\[EAcute]s\ *) \[IndentingNewLine]\t
          kp\  = \ k*Cos[f1]; \  (*\ 
            composante\ planaire\ *) \[IndentingNewLine]\t
          q0\  = \ k*Sin[f1]; \ \  (*\ 
            composante\ perpendiculaire\ *) \[IndentingNewLine]\t
          nbrLayers\  = \ \(Dimensions[z]\)[\([1]\)]; \[IndentingNewLine]\t
          Eq = hb*hb*q0*\(q0/2\)/mn*
              Table[1, {nbrLayers}]; \ \[IndentingNewLine]\t (*\ 
            energy\ cinetique\ perpendiculaire\ dans\ chaque\ couche\ \
*) \[IndentingNewLine]\t
          q = \((2*
                  mn*\((Eq - V)\)/\((hb*
                        hb)\))\)^0.5; \ \[IndentingNewLine]\t (*\ \(Print[f1, 
                kp, q0, nbrLayers, Eq, "\<  \>", 
                q];\)\ *) \[IndentingNewLine]\t (*\ 
            perpendicular\ wavevector\ in\ each\ layer\ \
*) \[IndentingNewLine]\tM = Iteration2[nbrLayers, q, z]; \[IndentingNewLine]\t
          AppendTo[T, Abs[1/M[\([1, 1]\)]]^2]; \[IndentingNewLine]\t
          AppendTo[R, 
            Abs[M[\([2, 1]\)]/
                  M[\([1, 1]\)]]^2\ ]\ \[IndentingNewLine], {i, \(Dimensions[
                angles]\)[\([1]\)]}\[IndentingNewLine]]; \[IndentingNewLine]\ \
\ ListPlot[
          Log[10, R]];\ \[IndentingNewLine]]\)\(\[IndentingNewLine]\)\)\)], \
"Input"],

Cell[BoxData[
    \(\[AliasDelimiter]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ReflecNPCompiled2[angles, 0.4];\)\  // Timing\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.603319 0.116916 [
[.2619 .59082 -6 -9 ]
[.2619 .59082 6 0 ]
[.5 .59082 -9 -9 ]
[.5 .59082 9 0 ]
[.7381 .59082 -9 -9 ]
[.7381 .59082 9 0 ]
[.97619 .59082 -9 -9 ]
[.97619 .59082 9 0 ]
[.01131 .01874 -12 -4.5 ]
[.01131 .01874 0 4.5 ]
[.01131 .13565 -12 -4.5 ]
[.01131 .13565 0 4.5 ]
[.01131 .25257 -12 -4.5 ]
[.01131 .25257 0 4.5 ]
[.01131 .36949 -12 -4.5 ]
[.01131 .36949 0 4.5 ]
[.01131 .4864 -12 -4.5 ]
[.01131 .4864 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .60332 m
.2619 .60957 L
s
[(50)] .2619 .59082 0 1 Mshowa
.5 .60332 m
.5 .60957 L
s
[(100)] .5 .59082 0 1 Mshowa
.7381 .60332 m
.7381 .60957 L
s
[(150)] .7381 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(200)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.21429 .60332 m
.21429 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.40476 .60332 m
.40476 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.59524 .60332 m
.59524 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.78571 .60332 m
.78571 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .01874 m
.03006 .01874 L
s
[(-5)] .01131 .01874 1 0 Mshowa
.02381 .13565 m
.03006 .13565 L
s
[(-4)] .01131 .13565 1 0 Mshowa
.02381 .25257 m
.03006 .25257 L
s
[(-3)] .01131 .25257 1 0 Mshowa
.02381 .36949 m
.03006 .36949 L
s
[(-2)] .01131 .36949 1 0 Mshowa
.02381 .4864 m
.03006 .4864 L
s
[(-1)] .01131 .4864 1 0 Mshowa
.125 Mabswid
.02381 .04212 m
.02756 .04212 L
s
.02381 .06551 m
.02756 .06551 L
s
.02381 .08889 m
.02756 .08889 L
s
.02381 .11227 m
.02756 .11227 L
s
.02381 .15904 m
.02756 .15904 L
s
.02381 .18242 m
.02756 .18242 L
s
.02381 .2058 m
.02756 .2058 L
s
.02381 .22919 m
.02756 .22919 L
s
.02381 .27595 m
.02756 .27595 L
s
.02381 .29934 m
.02756 .29934 L
s
.02381 .32272 m
.02756 .32272 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39287 m
.02756 .39287 L
s
.02381 .41625 m
.02756 .41625 L
s
.02381 .43964 m
.02756 .43964 L
s
.02381 .46302 m
.02756 .46302 L
s
.02381 .50979 m
.02756 .50979 L
s
.02381 .53317 m
.02756 .53317 L
s
.02381 .55655 m
.02756 .55655 L
s
.02381 .57994 m
.02756 .57994 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .60332 Mdot
.03333 .60332 Mdot
.0381 .60332 Mdot
.04286 .60332 Mdot
.04762 .60332 Mdot
.05238 .60332 Mdot
.05714 .60332 Mdot
.0619 .60332 Mdot
.06667 .60332 Mdot
.07143 .60332 Mdot
.07619 .60332 Mdot
.08095 .60332 Mdot
.08571 .60332 Mdot
.09048 .60332 Mdot
.09524 .60332 Mdot
.1 .60332 Mdot
.10476 .60332 Mdot
.10952 .60332 Mdot
.11429 .6033 Mdot
.11905 .60328 Mdot
.12381 .60326 Mdot
.12857 .60323 Mdot
.13333 .60321 Mdot
.1381 .60317 Mdot
.14286 .60313 Mdot
.14762 .60307 Mdot
.15238 .603 Mdot
.15714 .60291 Mdot
.1619 .6028 Mdot
.16667 .60265 Mdot
.17143 .60246 Mdot
.17619 .6022 Mdot
.18095 .60186 Mdot
.18571 .60141 Mdot
.19048 .60079 Mdot
.19524 .59994 Mdot
.2 .59875 Mdot
.20476 .59708 Mdot
.20952 .5947 Mdot
.21429 .59126 Mdot
.21905 .58625 Mdot
.22381 .57893 Mdot
.22857 .56824 Mdot
.23333 .55274 Mdot
.2381 .53052 Mdot
.24286 .49885 Mdot
.24762 .45262 Mdot
.25238 .37792 Mdot
.25714 .27451 Mdot
.2619 .36713 Mdot
.26667 .41809 Mdot
.27143 .44509 Mdot
.27619 .46091 Mdot
.28095 .47027 Mdot
.28571 .47536 Mdot
.29048 .47733 Mdot
.29524 .47681 Mdot
.3 .47414 Mdot
.30476 .46948 Mdot
.30952 .46288 Mdot
.31429 .45428 Mdot
.31905 .44349 Mdot
.32381 .43024 Mdot
.32857 .41403 Mdot
.33333 .39412 Mdot
.3381 .3692 Mdot
.34286 .33697 Mdot
.34762 .29289 Mdot
.35238 .23077 Mdot
.35714 .20406 Mdot
.3619 .26003 Mdot
.36667 .30285 Mdot
.37143 .3312 Mdot
.37619 .35092 Mdot
.38095 .36504 Mdot
.38571 .3752 Mdot
.39048 .38236 Mdot
.39524 .3871 Mdot
.4 .3898 Mdot
.40476 .39072 Mdot
.40952 .39 Mdot
.41429 .38774 Mdot
.41905 .38396 Mdot
.42381 .37866 Mdot
.42857 .37176 Mdot
.43333 .36312 Mdot
.4381 .35256 Mdot
.44286 .33974 Mdot
.44762 .32419 Mdot
.45238 .30516 Mdot
.45714 .28142 Mdot
.4619 .25085 Mdot
.46667 .20982 Mdot
.47143 .15658 Mdot
.47619 .13934 Mdot
.48095 .18612 Mdot
.48571 .22668 Mdot
.49048 .25532 Mdot
.49524 .27611 Mdot
.5 .29164 Mdot
.50476 .30338 Mdot
.50952 .31222 Mdot
.51429 .31873 Mdot
.51905 .32326 Mdot
.52381 .32609 Mdot
.52857 .32736 Mdot
.53333 .32718 Mdot
.5381 .32562 Mdot
.54286 .32269 Mdot
.54762 .31837 Mdot
.55238 .31261 Mdot
.55714 .30528 Mdot
.5619 .29624 Mdot
.56667 .28522 Mdot
.57143 .27186 Mdot
.57619 .2556 Mdot
.58095 .23555 Mdot
.58571 .21026 Mdot
.59048 .1773 Mdot
.59524 .1333 Mdot
.6 .08742 Mdot
.60476 .10238 Mdot
.60952 .14789 Mdot
.61429 .18301 Mdot
.61905 .20855 Mdot
.62381 .22765 Mdot
.62857 .24227 Mdot
.63333 .25355 Mdot
.6381 .26223 Mdot
.64286 .26877 Mdot
.64762 .27348 Mdot
.65238 .27658 Mdot
.65714 .27822 Mdot
.6619 .27848 Mdot
.66667 .27742 Mdot
.67143 .27506 Mdot
.67619 .27138 Mdot
.68095 .26632 Mdot
.68571 .25978 Mdot
.69048 .25163 Mdot
.69524 .24164 Mdot
.7 .2295 Mdot
.70476 .21473 Mdot
.70952 .19658 Mdot
.71429 .1739 Mdot
.71905 .14474 Mdot
.72381 .10612 Mdot
.72857 .05879 Mdot
.73333 .04614 Mdot
.7381 .08807 Mdot
.74286 .12722 Mdot
.74762 .15605 Mdot
.75238 .17758 Mdot
.75714 .19408 Mdot
.7619 .20692 Mdot
.76667 .21694 Mdot
.77143 .2247 Mdot
.77619 .23054 Mdot
.78095 .23472 Mdot
.78571 .23741 Mdot
.79048 .23871 Mdot
.79524 .23871 Mdot
.8 .23743 Mdot
.80476 .23487 Mdot
.80952 .23101 Mdot
.81429 .22578 Mdot
.81905 .21906 Mdot
.82381 .21071 Mdot
.82857 .20048 Mdot
.83333 .18802 Mdot
.8381 .17282 Mdot
.84286 .15406 Mdot
.84762 .13048 Mdot
.85238 .09995 Mdot
.85714 .05958 Mdot
.8619 .01472 Mdot
.86667 .01787 Mdot
.87143 .06136 Mdot
.87619 .09802 Mdot
.88095 .12515 Mdot
.88571 .14566 Mdot
.89048 .16152 Mdot
.89524 .17397 Mdot
.9 .18375 Mdot
.90476 .19136 Mdot
.90952 .19713 Mdot
.91429 .2013 Mdot
.91905 .20401 Mdot
.92381 .20537 Mdot
.92857 .20545 Mdot
.93333 .20427 Mdot
.9381 .20183 Mdot
.94286 .19811 Mdot
.94762 .19302 Mdot
.95238 .18648 Mdot
.95714 .17831 Mdot
.9619 .16828 Mdot
.96667 .15604 Mdot
.97143 .14109 Mdot
.97619 .12264 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gPP10`40000100000800002008200000
P800P020P<30`8f9HL:oYL3L`:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV
09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000
<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI
<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0
I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<
IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHc
VITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<
VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01V
c3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Ko
c9Woc<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2I
oc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D5
1@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5?okl0000000000000000000
00000>7PdZ2PY820P?l0003o0?oo0000ool0o`3oooooooooJOl00?ooJOl00?ooJOl00?ooJOl001?o
00<0ool0oomCo`004ol00`3oo`3ooe?o000Co`030?oo0?ooDol001?o00<0ool0oomCo`002Ol400Ko
00<0ool0oomCo`002?l00`3oo`02o`030?oo00?o00<0ool0oolNo`80<ol000go00<0ool00ol00`3o
o`3ooako100ao`001P07o`030?oo00?o0`3oob3o0P0ao`002Ol400Ko00<0ool0oomCo`002Ol00`3o
o`07o`030?oo0?ooDol000Wo00<0ool01ol00`3oo`3ooe?o0009o`D01Ol00`3oo`3ooe?o000Co`03
0?oo0?ooDol001?o00<0ool0oomCo`004ol00`3oo`3ooe?o000Co`80oomDo`004ol00`3oo`3ao`80
Gol001?o00<0ool0lOl205oo000Co`030?oo0?ooDol001?o00<0ool0oomCo`004ol00`3oo`3_o`80
HOl001?o00<0ool0kol202[o0P03o`80<?l001?o00<0ool0oolLo`800ol2033o000Co`80oomDo`00
4ol00`3oo`3ooe?o000Co`030?oo0?ooDol001?o00<0ool0oomCo`004ol00`3oo`3ooe?o000Co`03
0?oo0?ooDol001?o00<0ool0oomCo`004ol00`3oo`33o`80;Ol205ko000Co`80a?l202go0P1No`00
4ol00`3oo`3ooe?o000Co`030?oo0?ooDol001?o00<0ool0oolSo`80;_l001?o00<0ool0a?l205Co
0P06o`80;_l001?o00<0ool0a?l205Co0P0fo`004ol00`3oo`3]o`80Hol001?o00<0ool0kOl206?o
000Co`80oomDo`004ol00`3oo`3ooe?o000Co`030?oo0?ooDol001?o00<0ool0oom5o`803?l001?o
00<0ool0oolUo`807_l200co000;o`<01Ol00`3oo`3do`80;_l202co000<o`030?oo00Co00<0ool0
m?l202;o0P0ho`003?l00`3oo`04o`030?oo0<7o0P1Eo`80>?l000H00_l600Go0`31o`80Sol000Wo
00@0ool01_l00`3oo`2Ho`80^?l000Wo00@0ool01_l00`3oo`2Ho`80ZOl200go000:o`030?l000Ko
00<0ool0k?l203Oo0P0Lo`803Ol000_o0P06o`030?oo0<Ko0P0To`80=ol202_o000Co`030?oo0<Ko
0P2:o`004ol00`3oo`3ooaOo0P0jo`004ol00`3oo`2Fo`80G_l201ko0P0Yo`803ol001?o0P2Go`80
G_l204Wo0P0?o`004ol00`3oo`3oobSo0P0Yo`004ol00`3oo`3oobSo0P0Yo`004ol00`3oo`3ood3o
0P0Ao`004ol00`3oo`3ood3o0P0Ao`004ol00`3oo`3Zo`80:Ol2017o0P0Xo`004ol00`3oo`2oo`80
:Ol200_o0P0Lo`804Ol202So000Co`030?oo0;oo0P0fo`80AOl201;o000Co`80bOl2063o0P0Bo`80
4_l001?o00<0ool0V_l202co0P1Po`804?l201Co000Co`030?oo09[o0P1go`809ol201Co000Co`03
0?oo0?oo5?l201Oo0P0To`004ol00`3oo`3io`80<Ol200go0P0Eo`004ol00`3oo`3Xo`803ol203;o
0P0:o`@05Ol001?o00<0ool0j?l202Oo0P0Jo`802_l201Oo000Co`030?oo06oo0P2Po`807?l400Co
0P0Io`004ol2073o0P29o`80<ol:01Wo000Co`030?oo09Go0P0bo`80;ol203Ko1P0Jo`004ol00`3o
o`2Eo`809ol200Wo0P15o`80@?l001?o00<0ool0__l202Oo0P0Wo`80@?l001?o00<0ool0iol201?o
0P1Do`004ol00`3oo`3lo`804?l204;o000Co`030?oo0?oo3ol204;o000Co`030?oo09_o0P1Qo`80
3Ol204?o000Co`80W?l202ko0P0Ho`805ol200go0P13o`004ol00`3oo`1]o`80G?l201So0P0Ho`80
2_l204Go000Co`030?oo06go0P1=o`80@Ol400Ko1015o`004ol00`3oo`2lo`80@ol:04Oo000Co`03
0?oo0>?o0P0No`L0B?l000Wo0`07o`030?oo0<co0P0Eo`80KOl000So00D0oooo0006o`030?oo0<co
0P24o`003?l00`3oo`04o`030?oo0?ooDol000H01_l00`3oo`04o`<0Tol204go0P1^o`002_l200Oo
00<0ool0Tol200So0P0Ko`804_l201;o0P1^o`003?l00`3oo`04o`030?oo09go0P0Ko`804_l208;o
0008o`050?ooo`001_l00`3oo`1ao`80KOl2073o0009o`<01ol00`3oo`1ao`80GOl200ko0P1`o`00
4ol00`3oo`3@o`803Ol2077o000Co`030?oo0=7o0P0<o`80LOl001?o00<0ool0^Ol201Ko1008o`80
Lol001?o0P1=o`80DOl201So0P0Ho`801_l407?o000Co`030?oo04co0P1Ao`80=?l807Go000Co`03
0?oo097o0P12o`L0M_l001?o00<0ool0TOl202Co0P2Io`004ol00`3oo`2go`80VOl001?o00<0ool0
oomCo`004ol00`3oo`1/o`80<_l20;3o000Co`030?oo06co0P0bo`805?l209[o000Co`80]ol209[o
000Co`030?oo0?ooDol001?o00<0ool0L_l201co0P0@o`804?l209co000Co`030?oo07;o0P0Lo`80
4?l2013o0P2Lo`004ol00`3oo`3ooe?o000Co`030?oo0:?o0P0=o`80W_l001?o00<0ool0Xol200go
0P2No`004ol00`3oo`2Uo`802_l209oo000Co`030?oo0:Go0P08o`@0Wol001?o0P2?o`805ol200Co
102Qo`004ol00`3oo`2>o`805ol80:?o000Co`030?oo07Co0P0bo`H0Y?l001?o00<0ool0M?l20=co
000Co`030?oo06[o0P3Vo`004ol00`3oo`1Zo`808?l20<Co000Co`030?oo08co0P34o`004ol00`3o
o`3ooe?o000Co`80oomDo`004ol00`3oo`1eo`80fol001?o00<0ool0MOl201Co0P35o`004ol00`3o
o`2;o`80aOl001?o00<0ool0oomCo`002?l500Ko00<0ool0ROl20<Oo0008o`050?ooo`001_l00`3o
o`1go`804?l20<Oo0009o`030?oo00Oo00<0ool0C_l201So0P0=o`80fOl000H01?l00`3oo`06o`<0
C_l201So0P0No`80b?l000_o00<0ool01Ol00`3oo`28o`80b?l000co00<0ool01?l00`3oo`1;o`80
;?l20=Oo0008o`050?ooo`001_l00`3oo`1;o`80;?l200_o0P3:o`002Ol300Oo00<0ool0N_l200[o
0P3:o`004ol00`3oo`1jo`802?l20<co000Co`030?oo07co0P05o`<0c?l001?o00<0ool0O?l90<go
000Co`80J?l201Go1@3?o`004ol00`3oo`1Wo`80jOl001?o00<0ool0oomCo`004ol00`3oo`3ooe?o
000Co`030?oo0?ooDol001?o00<0ool0oomCo`004ol00`3oo`3ooe?o000Co`030?oo06Go0P3[o`00
4ol2057o0P0Co`80jol001?o00<0ool0D?l20?oo0Ol001?o00<0ool0oomCo`004ol00`3oo`3ooe?o
000Co`030?oo06?o0P3]o`004ol00`3oo`1So`80kOl001?o00<0ool0oomCo`004ol00`3oo`3ooe?o
000Co`80oomDo`004ol00`3oo`1Ro`80k_l001?o00<0ool0DOl200oo0P3^o`004ol00`3oo`1Ao`80
ool001?o00<0ool0BOl20?oo2?l001?o00<0ool0BOl201Go0P3`o`004ol00`3oo`1Po`80l?l001?o
00<0ool0Dol20?go000Co`80E?l200Wo0P3bo`004ol00`3oo`1No`80l_l001?o00<0ool0EOl200Ko
0P3co`004ol00`3oo`1Eo`801_l20??o000Co`030?oo05Ko0P03o`80mOl000Wo1@05o`030?oo05Ko
1`3eo`002ol00`3oo`05o`030?oo05So103fo`002ol00`3oo`05o`030?oo0?ooDol000H01Ol00`3o
o`05o`<0oomCo`002ol00`3oo`05o`030?oo0?ooDol000_o00<0ool01Ol00`3oo`3ooe?o0009o`<0
1ol00`3oo`3ooe?o000;o`030?oo00Go00<0ool0Aol20?oo2_l001?o00<0ool0Aol20?oo2_l001?o
00<0ool0oomCo`004ol00`3oo`3ooe?o000Co`80oomDo`004ol00`3oo`3ooe?o000Co`030?oo0?oo
Dol001?o00<0ool0oomCo`004ol00`3oo`3ooe?o000Co`030?oo0?ooDol001?o00<0ool0oomCo`00
4ol00`3oo`16o`80ool;o`004ol204Oo0P3oo`_o000Co`030?oo0?ooDol001?o00<0ool0oomCo`00
4ol00`3oo`3ooe?o000Co`030?oo0?ooDol001?o00<0ool0oomCo`004ol00`3oo`3ooe?o000Co`03
0?oo04Co0P3oo`go000Co`80AOl20?oo3Ol001?o00<0ool0BOl400Co1012o`D00ol400Co100no`D0
0ol400Co100mo`D01?l400Co1003o`004ol00`3oo`18o`030?oo00;o00@0ool01?l00`3oo`11o`03
0?oo00;o00<0ool00_l0103oo`04o`030?oo03go00<0ool00_l00`3oo`02o`040?oo00Co00<0ool0
>_l01@3oool000?o00<0ool00_l0103oo`04o`400Ol1o`004ol00`3oo`1=o`040?oo00Co00<0ool0
@Ol00`3oo`02o`030?oo00;o00@0ool01?l00`3oo`0mo`030?oo00Oo00@0ool01?l00`3oo`0ko`03
0?oo00Co00<0ool00_l0103oo`04o`400Ol1o`004ol00`3oo`13o`802?l0103oo`04o`030?oo047o
00<0ool00_l00`3oo`02o`040?oo00Co00<0ool0?Ol00`3oo`07o`040?oo00Co00<0ool0??l00`3o
o`03o`030?oo00;o00@0ool01?l1007o0Ol001?o00<0ool0@ol200Co1003o`030?oo00;o00<0ool0
@Ol00`3oo`02o`030?oo00;o00@0ool01?l00`3oo`0mo`030?oo00?o1003o`030?oo00;o00<0ool0
?Ol00`3oo`02o`030?oo00;o00@0ool01?l1007o0Ol001?o00<0ool0BOl00`3oo`04o`030?oo00;o
00<0ool0@Ol00`3oo`02o`030?oo00;o00@0ool01?l00`3oo`0mo`030?oo00?o00<0ool01?l00`3o
o`02o`030?oo03ko00D0oooo0004o`040?oo00Co0@01o`7o000Co`030?oo04Wo00<0ool01?l00`3o
o`02o`030?oo03oo0`04o`030?oo00;o00@0ool01?l00`3oo`0ko`<01Ol00`3oo`04o`030?oo00;o
00<0ool0>_l01@3oool000?o00<0ool00_l0103oo`04o`400Ol1o`004ol204;o0P06o`D00ol404Co
00<0ool00ol400Co1010o`030?oo00?o1@03o`@0?_l300Go1004o`@00ol001?o00<0ool0@Ol20?oo
4?l001?o00<0ool0?ol20?oo4_l001?o00<0ool0?ol20?oo4_l001?o00<0ool0?_l20?oo4ol001?o
00<0ool0??l40?oo4ol001?o00<0ool0>_l40?oo5Ol001?o00<0ool0=Ol70?oo5ol000_oo`1J00Co
000CocT02Ol00`3oo`0=o`030?oo00go00<0ool03_l00`3oo`0=o`030?oo00ko00<0ool03Ol00`3o
o`0=o`030?oo00ko00<0ool03Ol00`3oo`0>o`030?oo00go00<0ool03_l00`3oo`0=o`030?oo00go
00<0ool03_l00`3oo`0=o`030?oo00[o000Co`030?oo00go00<0ool03_l00`3oo`0=o`030?oo00ko
00<0ool03Ol00`3oo`0=o`030?oo00ko00<0ool03Ol00`3oo`0>o`030?oo00go00<0ool03Ol00`3o
o`0>o`030?oo00go00<0ool03_l00`3oo`0=o`030?oo00ko00<0ool03Ol00`3oo`0=o`030?oo00ko
00<0ool03Ol00`3oo`0:o`004ol00`3oo`3ooe?o000Co`030?oo0?ooDol001?o00<0ool0oomCo`00
oomYo`00oomYo`00oomYo`00oomYo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-11.7601, -5.26249, \
0.761183, 0.0310024}}],

Cell[BoxData[
    \({1.3699999999998909`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(ReflecNPCompiled3 = 
        Compile[\[IndentingNewLine]{{\ 
              lambda, \ _Real}, \ {angles, \ _Real, \ 1}, \ {z, _Real, 
              1}, \ {V, \ _Complex, 
              1}}, \[IndentingNewLine]Module[\[IndentingNewLine]{\ 
              hb2over2mn, \ aux, nbrLayers, nbrPoints, 
              k, \ \ \[IndentingNewLine]q = {I}, \ qq, \ q0, \ Eq0, 
              Eq, \[IndentingNewLine]DD = {\ {I, 0}, {0, 0}}, 
              P = {\ {I, 0}, \ {\ 0, 0\ }}, \ M = {{I, 0}, {0, 0}}, \ R, \ 
              T}, \ \[IndentingNewLine]nbrLayers\  = \ \(Dimensions[
                  z]\)[\([1]\)]; \[IndentingNewLine]nbrPoints\  = \ \
\(Dimensions[angles]\)[\([1]\)]; \[IndentingNewLine]k = 
              2*Pi/\((lambda*10^\(-9\))\); \  (*\ 
              moment\ du\ neutron\ en\ SI\ *) \[IndentingNewLine]hb2over2mn = \
\(hb2/2\)/mn; \[IndentingNewLine]R = 
              Table[1.0, {nbrPoints}]; \[IndentingNewLine]T = 
              Table[1.0, {nbrPoints}]; \[IndentingNewLine]Eq0\  = \ 
              hb2over2mn*
                Table[1, {nbrLayers}]; \[IndentingNewLine]Do[\ \
\[IndentingNewLine]\t
              q0 = \ k*Sin[angles[\([i]\)]*Deg];  (*\ 
                comp . \ perp . \ du\ vecteur\ d' 
                  onde\ *) \[IndentingNewLine]\t
              Eq = q0*q0*Eq0; \  (*\ 
                energy\ cinetique\ perp . \ 
                    dans\ chaque\ couche\ *) \[IndentingNewLine]\t
              q = \((\((Eq - 
                          V)\)/\((hb2over2mn)\))\)^0.5; \ \ \
\[IndentingNewLine]\t (*\ 
                perp . \ 
                    wavevectors\ in\ each\ layer\ *) \[IndentingNewLine]\t
              Do[\ \[IndentingNewLine]\t\tqq = q[\([k]\)];  (*\ 
                  initialisation\ of\ the\ D\ matrix\ *) \[IndentingNewLine]\t\
\tDD = {\ {1, 1}, {qq, \(-qq\)}}; \[IndentingNewLine]\t\t (*\ 
                  initialisation\ of\ the\ propagation\ matrix\ \
*) \[IndentingNewLine]\t\taux = 
                  Exp[\(-I\)*qq*
                      z[\([k]\)]\ ]; \[IndentingNewLine]\t\tP = {\ {aux, 
                      0}, \ {\ 0, 1/aux\ }}; \[IndentingNewLine]\t\tIf[\ 
                  k \[Equal] 1, 
                  M = Inverse[DD], \[IndentingNewLine]\t\t\tIf[\ 
                    k \[Equal] nbrLayers, M = M . DD, 
                    M = M . DD . P . Inverse[DD]]];\[IndentingNewLine]\t, {k, 
                  nbrLayers}\[IndentingNewLine]\t]; \[IndentingNewLine]\t
              T[\([i]\)] = \((1/Abs[M[\([1, 1]\)]])\)^2; \[IndentingNewLine]\t
              R[\([i]\)] = \((Abs[M[\([2, 1]\)]]/
                      Abs[M[\([1, 1]\)]])\)^2\[IndentingNewLine], {i, 
                nbrPoints}\[IndentingNewLine]]; \[IndentingNewLine]ListPlot[
              Log[10, R]];\[IndentingNewLine]]\[IndentingNewLine]];\)\)], \
"Input"],

Cell[BoxData[
    \(\(angles = Table[i, {i, 0.01, 6, 0.01}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ReflecNPCompiled3[0.4, angles, z, \ V];\)\  // Timing\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0015873 0.603319 0.0825504 [
[.18254 .59082 -9 -9 ]
[.18254 .59082 9 0 ]
[.34127 .59082 -9 -9 ]
[.34127 .59082 9 0 ]
[.5 .59082 -9 -9 ]
[.5 .59082 9 0 ]
[.65873 .59082 -9 -9 ]
[.65873 .59082 9 0 ]
[.81746 .59082 -9 -9 ]
[.81746 .59082 9 0 ]
[.97619 .59082 -9 -9 ]
[.97619 .59082 9 0 ]
[.01131 .02547 -12 -4.5 ]
[.01131 .02547 0 4.5 ]
[.01131 .10802 -12 -4.5 ]
[.01131 .10802 0 4.5 ]
[.01131 .19057 -12 -4.5 ]
[.01131 .19057 0 4.5 ]
[.01131 .27312 -12 -4.5 ]
[.01131 .27312 0 4.5 ]
[.01131 .35567 -12 -4.5 ]
[.01131 .35567 0 4.5 ]
[.01131 .43822 -12 -4.5 ]
[.01131 .43822 0 4.5 ]
[.01131 .52077 -12 -4.5 ]
[.01131 .52077 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .60332 m
.18254 .60957 L
s
[(100)] .18254 .59082 0 1 Mshowa
.34127 .60332 m
.34127 .60957 L
s
[(200)] .34127 .59082 0 1 Mshowa
.5 .60332 m
.5 .60957 L
s
[(300)] .5 .59082 0 1 Mshowa
.65873 .60332 m
.65873 .60957 L
s
[(400)] .65873 .59082 0 1 Mshowa
.81746 .60332 m
.81746 .60957 L
s
[(500)] .81746 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(600)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.05556 .60332 m
.05556 .60707 L
s
.0873 .60332 m
.0873 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.15079 .60332 m
.15079 .60707 L
s
.21429 .60332 m
.21429 .60707 L
s
.24603 .60332 m
.24603 .60707 L
s
.27778 .60332 m
.27778 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.37302 .60332 m
.37302 .60707 L
s
.40476 .60332 m
.40476 .60707 L
s
.43651 .60332 m
.43651 .60707 L
s
.46825 .60332 m
.46825 .60707 L
s
.53175 .60332 m
.53175 .60707 L
s
.56349 .60332 m
.56349 .60707 L
s
.59524 .60332 m
.59524 .60707 L
s
.62698 .60332 m
.62698 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.72222 .60332 m
.72222 .60707 L
s
.75397 .60332 m
.75397 .60707 L
s
.78571 .60332 m
.78571 .60707 L
s
.84921 .60332 m
.84921 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.9127 .60332 m
.9127 .60707 L
s
.94444 .60332 m
.94444 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .02547 m
.03006 .02547 L
s
[(-7)] .01131 .02547 1 0 Mshowa
.02381 .10802 m
.03006 .10802 L
s
[(-6)] .01131 .10802 1 0 Mshowa
.02381 .19057 m
.03006 .19057 L
s
[(-5)] .01131 .19057 1 0 Mshowa
.02381 .27312 m
.03006 .27312 L
s
[(-4)] .01131 .27312 1 0 Mshowa
.02381 .35567 m
.03006 .35567 L
s
[(-3)] .01131 .35567 1 0 Mshowa
.02381 .43822 m
.03006 .43822 L
s
[(-2)] .01131 .43822 1 0 Mshowa
.02381 .52077 m
.03006 .52077 L
s
[(-1)] .01131 .52077 1 0 Mshowa
.125 Mabswid
.02381 .04198 m
.02756 .04198 L
s
.02381 .05849 m
.02756 .05849 L
s
.02381 .075 m
.02756 .075 L
s
.02381 .09151 m
.02756 .09151 L
s
.02381 .12453 m
.02756 .12453 L
s
.02381 .14104 m
.02756 .14104 L
s
.02381 .15755 m
.02756 .15755 L
s
.02381 .17406 m
.02756 .17406 L
s
.02381 .20708 m
.02756 .20708 L
s
.02381 .22359 m
.02756 .22359 L
s
.02381 .2401 m
.02756 .2401 L
s
.02381 .25661 m
.02756 .25661 L
s
.02381 .28963 m
.02756 .28963 L
s
.02381 .30614 m
.02756 .30614 L
s
.02381 .32265 m
.02756 .32265 L
s
.02381 .33916 m
.02756 .33916 L
s
.02381 .37218 m
.02756 .37218 L
s
.02381 .38869 m
.02756 .38869 L
s
.02381 .4052 m
.02756 .4052 L
s
.02381 .42171 m
.02756 .42171 L
s
.02381 .45473 m
.02756 .45473 L
s
.02381 .47124 m
.02756 .47124 L
s
.02381 .48775 m
.02756 .48775 L
s
.02381 .50426 m
.02756 .50426 L
s
.02381 .53728 m
.02756 .53728 L
s
.02381 .55379 m
.02756 .55379 L
s
.02381 .5703 m
.02756 .5703 L
s
.02381 .58681 m
.02756 .58681 L
s
.02381 .00896 m
.02756 .00896 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.0254 .60332 Mdot
.02698 .60332 Mdot
.02857 .60332 Mdot
.03016 .60332 Mdot
.03175 .60332 Mdot
.03333 .60332 Mdot
.03492 .60332 Mdot
.03651 .60332 Mdot
.0381 .60332 Mdot
.03968 .60332 Mdot
.04127 .60332 Mdot
.04286 .60332 Mdot
.04444 .60332 Mdot
.04603 .60332 Mdot
.04762 .60332 Mdot
.04921 .60332 Mdot
.05079 .60332 Mdot
.05238 .60332 Mdot
.05397 .60331 Mdot
.05556 .60329 Mdot
.05714 .60328 Mdot
.05873 .60326 Mdot
.06032 .60324 Mdot
.0619 .60321 Mdot
.06349 .60318 Mdot
.06508 .60314 Mdot
.06667 .60309 Mdot
.06825 .60303 Mdot
.06984 .60295 Mdot
.07143 .60285 Mdot
.07302 .60271 Mdot
.0746 .60253 Mdot
.07619 .60229 Mdot
.07778 .60197 Mdot
.07937 .60153 Mdot
.08095 .60093 Mdot
.08254 .60009 Mdot
.08413 .59891 Mdot
.08571 .59723 Mdot
.0873 .5948 Mdot
.08889 .59127 Mdot
.09048 .5861 Mdot
.09206 .57855 Mdot
.09365 .5676 Mdot
.09524 .55192 Mdot
.09683 .52956 Mdot
.09841 .49692 Mdot
.1 .44417 Mdot
.10159 .37116 Mdot
.10317 .43656 Mdot
.10476 .47254 Mdot
.10635 .4916 Mdot
.10794 .50277 Mdot
.10952 .50938 Mdot
.11111 .51297 Mdot
.1127 .51436 Mdot
.11429 .51399 Mdot
.11587 .51211 Mdot
.11746 .50882 Mdot
.11905 .50416 Mdot
.12063 .49809 Mdot
.12222 .49047 Mdot
.12381 .48111 Mdot
.1254 .46967 Mdot
.12698 .45561 Mdot
.12857 .43802 Mdot
.13016 .41526 Mdot
.13175 .38413 Mdot
.13333 .34028 Mdot
.13492 .32142 Mdot
.13651 .36093 Mdot
.1381 .39117 Mdot
.13968 .41119 Mdot
.14127 .42511 Mdot
.14286 .43508 Mdot
.14444 .44226 Mdot
.14603 .44731 Mdot
.14762 .45065 Mdot
.14921 .45256 Mdot
.15079 .45321 Mdot
.15238 .4527 Mdot
.15397 .4511 Mdot
.15556 .44844 Mdot
.15714 .44469 Mdot
.15873 .43982 Mdot
.16032 .43373 Mdot
.1619 .42626 Mdot
.16349 .41721 Mdot
.16508 .40623 Mdot
.16667 .3928 Mdot
.16825 .37604 Mdot
.16984 .35445 Mdot
.17143 .32548 Mdot
.17302 .28789 Mdot
.1746 .27572 Mdot
.17619 .30875 Mdot
.17778 .33739 Mdot
.17937 .35761 Mdot
.18095 .37229 Mdot
.18254 .38325 Mdot
.18413 .39154 Mdot
.18571 .39779 Mdot
.1873 .40238 Mdot
.18889 .40558 Mdot
.19048 .40757 Mdot
.19206 .40847 Mdot
.19365 .40835 Mdot
.19524 .40725 Mdot
.19683 .40518 Mdot
.19841 .40213 Mdot
.2 .39806 Mdot
.20159 .39289 Mdot
.20317 .3865 Mdot
.20476 .37872 Mdot
.20635 .36929 Mdot
.20794 .35781 Mdot
.20952 .34365 Mdot
.21111 .32579 Mdot
.2127 .30252 Mdot
.21429 .27145 Mdot
.21587 .23906 Mdot
.21746 .24962 Mdot
.21905 .28175 Mdot
.22063 .30655 Mdot
.22222 .32459 Mdot
.22381 .33808 Mdot
.2254 .34839 Mdot
.22698 .35636 Mdot
.22857 .36249 Mdot
.23016 .3671 Mdot
.23175 .37043 Mdot
.23333 .37262 Mdot
.23492 .37378 Mdot
.23651 .37396 Mdot
.2381 .37322 Mdot
.23968 .37155 Mdot
.24127 .36895 Mdot
.24286 .36537 Mdot
.24444 .36076 Mdot
.24603 .355 Mdot
.24762 .34795 Mdot
.24921 .33938 Mdot
.25079 .32895 Mdot
.25238 .31614 Mdot
.25397 .30012 Mdot
.25556 .27953 Mdot
.25714 .25226 Mdot
.25873 .21885 Mdot
.26032 .20992 Mdot
.2619 .23952 Mdot
.26349 .26716 Mdot
.26508 .28752 Mdot
.26667 .30272 Mdot
.26825 .31437 Mdot
.26984 .32343 Mdot
.27143 .33051 Mdot
.27302 .33599 Mdot
.2746 .34011 Mdot
.27619 .34306 Mdot
.27778 .34496 Mdot
.27937 .34588 Mdot
.28095 .34588 Mdot
.28254 .34498 Mdot
.28413 .34317 Mdot
.28571 .34044 Mdot
.2873 .33675 Mdot
.28889 .33201 Mdot
.29048 .32611 Mdot
.29206 .31889 Mdot
.29365 .31009 Mdot
.29524 .29936 Mdot
.29683 .28612 Mdot
.29841 .26946 Mdot
.3 .24791 Mdot
.30159 .2194 Mdot
.30317 .18773 Mdot
.30476 .18996 Mdot
.30635 .22066 Mdot
.30794 .24654 Mdot
.30952 .2657 Mdot
.31111 .28018 Mdot
.3127 .29138 Mdot
.31429 .30017 Mdot
.31587 .30708 Mdot
.31746 .31245 Mdot
.31905 .31653 Mdot
.32063 .31947 Mdot
.32222 .32138 Mdot
.32381 .32234 Mdot
.3254 .3224 Mdot
.32698 .32156 Mdot
.32857 .31984 Mdot
.33016 .31721 Mdot
.33175 .31362 Mdot
.33333 .309 Mdot
.33492 .30323 Mdot
.33651 .29615 Mdot
.3381 .28751 Mdot
.33968 .27696 Mdot
.34127 .26393 Mdot
.34286 .24754 Mdot
.34444 .22634 Mdot
.34603 .19837 Mdot
.34762 .16703 Mdot
.34921 .16782 Mdot
.35079 .19809 Mdot
.35238 .22416 Mdot
.35397 .24356 Mdot
.35556 .25827 Mdot
.35714 .26968 Mdot
.35873 .27866 Mdot
.36032 .28576 Mdot
.3619 .29132 Mdot
.36349 .29558 Mdot
.36508 .29871 Mdot
.36667 .30081 Mdot
.36825 .30197 Mdot
.36984 .30222 Mdot
.37143 .30159 Mdot
.37302 .30009 Mdot
.3746 .29769 Mdot
.37619 .29435 Mdot
.37778 .28999 Mdot
.37937 .28452 Mdot
.38095 .27778 Mdot
.38254 .26954 Mdot
.38413 .25947 Mdot
.38571 .24706 Mdot
.3873 .2315 Mdot
.38889 .21148 Mdot
.39048 .1851 Mdot
.39206 .15338 Mdot
.39365 .14512 Mdot
.39524 .17349 Mdot
.39683 .20092 Mdot
.39841 .22148 Mdot
.4 .23702 Mdot
.40159 .24907 Mdot
.40317 .25856 Mdot
.40476 .26608 Mdot
.40635 .27202 Mdot
.40794 .27662 Mdot
.40952 .28007 Mdot
.41111 .28247 Mdot
.4127 .28392 Mdot
.41429 .28447 Mdot
.41587 .28414 Mdot
.41746 .28294 Mdot
.41905 .28085 Mdot
.42063 .27785 Mdot
.42222 .27386 Mdot
.42381 .26879 Mdot
.4254 .26251 Mdot
.42698 .25481 Mdot
.42857 .24539 Mdot
.43016 .23382 Mdot
.43175 .21939 Mdot
.43333 .20098 Mdot
.43492 .17683 Mdot
.43651 .14597 Mdot
.4381 .12562 Mdot
.43968 .14747 Mdot
.44127 .1768 Mdot
.44286 .19928 Mdot
.44444 .21619 Mdot
.44603 .22923 Mdot
.44762 .23948 Mdot
.44921 .24763 Mdot
.45079 .25409 Mdot
.45238 .25915 Mdot
.45397 .26301 Mdot
.45556 .26581 Mdot
.45714 .26763 Mdot
.45873 .26853 Mdot
.46032 .26856 Mdot
.4619 .26772 Mdot
.46349 .26601 Mdot
.46508 .2634 Mdot
.46667 .25984 Mdot
.46825 .25524 Mdot
.46984 .24948 Mdot
.47143 .2424 Mdot
.47302 .23373 Mdot
.4746 .22309 Mdot
.47619 .20991 Mdot
.47778 .19324 Mdot
.47937 .1716 Mdot
.48095 .14318 Mdot
.48254 .11408 Mdot
.48413 .12117 Mdot
.48571 .15144 Mdot
.4873 .17656 Mdot
.48889 .19539 Mdot
.49048 .2098 Mdot
.49206 .22107 Mdot
.49365 .23002 Mdot
.49524 .23714 Mdot
.49683 .24277 Mdot
.49841 .24714 Mdot
.5 .25039 Mdot
.50159 .25264 Mdot
.50317 .25397 Mdot
.50476 .2544 Mdot
.50635 .25397 Mdot
.50794 .25267 Mdot
.50952 .2505 Mdot
.51111 .24739 Mdot
.5127 .2433 Mdot
.51429 .23811 Mdot
.51587 .23167 Mdot
.51746 .22378 Mdot
.51905 .21411 Mdot
.52063 .20219 Mdot
.52222 .18726 Mdot
.52381 .16809 Mdot
.5254 .14288 Mdot
.52698 .11177 Mdot
.52857 .09856 Mdot
.53016 .12462 Mdot
.53175 .15283 Mdot
.53333 .17421 Mdot
.53492 .19041 Mdot
.53651 .20299 Mdot
.5381 .21293 Mdot
.53968 .22086 Mdot
.54127 .22717 Mdot
.54286 .23212 Mdot
.54444 .23591 Mdot
.54603 .23865 Mdot
.54762 .24043 Mdot
.54921 .24131 Mdot
.55079 .24132 Mdot
.55238 .24047 Mdot
.55397 .23876 Mdot
.55556 .23614 Mdot
.55714 .23257 Mdot
.55873 .22796 Mdot
.56032 .22219 Mdot
.5619 .21508 Mdot
.56349 .20636 Mdot
.56508 .19566 Mdot
.56667 .18235 Mdot
.56825 .1655 Mdot
.56984 .14355 Mdot
.57143 .11484 Mdot
.57302 .0871 Mdot
.5746 .09728 Mdot
.57619 .12749 Mdot
.57778 .15214 Mdot
.57937 .17067 Mdot
.58095 .1849 Mdot
.58254 .19608 Mdot
.58413 .20497 Mdot
.58571 .21208 Mdot
.5873 .21771 Mdot
.58889 .22209 Mdot
.59048 .22538 Mdot
.59206 .22767 Mdot
.59365 .22904 Mdot
.59524 .22952 Mdot
.59683 .22915 Mdot
.59841 .22791 Mdot
.6 .2258 Mdot
.60159 .22277 Mdot
.60317 .21875 Mdot
.60476 .21364 Mdot
.60635 .20729 Mdot
.60794 .19949 Mdot
.60952 .18993 Mdot
.61111 .17812 Mdot
.6127 .16333 Mdot
.61429 .14435 Mdot
.61587 .1194 Mdot
.61746 .08851 Mdot
.61905 .07467 Mdot
.62063 .10025 Mdot
.62222 .12856 Mdot
.62381 .15011 Mdot
.6254 .16645 Mdot
.62698 .17916 Mdot
.62857 .18922 Mdot
.63016 .19726 Mdot
.63175 .20368 Mdot
.63333 .20874 Mdot
.63492 .21263 Mdot
.63651 .21547 Mdot
.6381 .21736 Mdot
.63968 .21835 Mdot
.64127 .21847 Mdot
.64286 .21774 Mdot
.64444 .21615 Mdot
.64603 .21366 Mdot
.64762 .21023 Mdot
.64921 .20577 Mdot
.65079 .20016 Mdot
.65238 .19324 Mdot
.65397 .18474 Mdot
.65556 .1743 Mdot
.65714 .16133 Mdot
.65873 .14493 Mdot
.66032 .12362 Mdot
.6619 .09567 Mdot
.66349 .06676 Mdot
.66508 .07276 Mdot
.66667 .10284 Mdot
.66825 .12816 Mdot
.66984 .14723 Mdot
.67143 .16185 Mdot
.67302 .17334 Mdot
.6746 .18249 Mdot
.67619 .18981 Mdot
.67778 .19564 Mdot
.67937 .20021 Mdot
.68095 .20366 Mdot
.68254 .20611 Mdot
.68413 .20764 Mdot
.68571 .20829 Mdot
.6873 .20808 Mdot
.68889 .20701 Mdot
.69048 .20508 Mdot
.69206 .20223 Mdot
.69365 .19841 Mdot
.69524 .19352 Mdot
.69683 .18742 Mdot
.69841 .17992 Mdot
.7 .1707 Mdot
.70159 .15934 Mdot
.70317 .14514 Mdot
.70476 .12699 Mdot
.70635 .10318 Mdot
.70794 .07291 Mdot
.70952 .05333 Mdot
.71111 .07494 Mdot
.7127 .10414 Mdot
.71429 .12672 Mdot
.71587 .1438 Mdot
.71746 .15705 Mdot
.71905 .16754 Mdot
.72063 .17592 Mdot
.72222 .18263 Mdot
.72381 .18795 Mdot
.7254 .19208 Mdot
.72698 .19515 Mdot
.72857 .19725 Mdot
.73016 .19845 Mdot
.73175 .19877 Mdot
.73333 .19825 Mdot
.73492 .19687 Mdot
.73651 .19461 Mdot
.7381 .19142 Mdot
.73968 .18722 Mdot
.74127 .18191 Mdot
.74286 .17532 Mdot
.74444 .16723 Mdot
.74603 .15728 Mdot
.74762 .14497 Mdot
.74921 .12945 Mdot
.75079 .10941 Mdot
.75238 .08303 Mdot
.75397 .05256 Mdot
.75556 .04863 Mdot
.75714 .07742 Mdot
.75873 .10426 Mdot
.76032 .12453 Mdot
.7619 .14002 Mdot
.76349 .15215 Mdot
.76508 .1618 Mdot
.76667 .16953 Mdot
.76825 .17571 Mdot
.76984 .18058 Mdot
.77143 .18432 Mdot
.77302 .18704 Mdot
.7746 .18882 Mdot
.77619 .18971 Mdot
.77778 .18975 Mdot
.77937 .18893 Mdot
.78095 .18726 Mdot
.78254 .18468 Mdot
.78413 .18116 Mdot
.78571 .1766 Mdot
.7873 .17087 Mdot
.78889 .1638 Mdot
.79048 .15511 Mdot
.79206 .14441 Mdot
.79365 .1311 Mdot
.79524 .11418 Mdot
.79683 .09213 Mdot
.79841 .06338 Mdot
.8 .03689 Mdot
.80159 .049 Mdot
.80317 .07907 Mdot
.80476 .10344 Mdot
.80635 .12184 Mdot
.80794 .13602 Mdot
.80952 .14721 Mdot
.81111 .15615 Mdot
.8127 .16331 Mdot
.81429 .16903 Mdot
.81587 .17351 Mdot
.81746 .1769 Mdot
.81905 .1793 Mdot
.82063 .18079 Mdot
.82222 .1814 Mdot
.82381 .18116 Mdot
.8254 .18007 Mdot
.82698 .17811 Mdot
.82857 .17524 Mdot
.83016 .1714 Mdot
.83175 .16648 Mdot
.83333 .16034 Mdot
.83492 .15278 Mdot
.83651 .1435 Mdot
.8381 .13203 Mdot
.83968 .11767 Mdot
.84127 .09928 Mdot
.84286 .07513 Mdot
.84444 .04477 Mdot
.84603 .0276 Mdot
.84762 .05089 Mdot
.84921 .07973 Mdot
.85079 .10193 Mdot
.85238 .11877 Mdot
.85397 .13187 Mdot
.85556 .14227 Mdot
.85714 .15059 Mdot
.85873 .15727 Mdot
.86032 .16258 Mdot
.8619 .1667 Mdot
.86349 .16978 Mdot
.86508 .17189 Mdot
.86667 .17311 Mdot
.86825 .17346 Mdot
.86984 .17297 Mdot
.87143 .17162 Mdot
.87302 .1694 Mdot
.8746 .16625 Mdot
.87619 .16209 Mdot
.87778 .15683 Mdot
.87937 .15029 Mdot
.88095 .14225 Mdot
.88254 .13236 Mdot
.88413 .12011 Mdot
.88571 .10467 Mdot
.8873 .08472 Mdot
.88889 .05848 Mdot
.89048 .02814 Mdot
.89206 .02399 Mdot
.89365 .05265 Mdot
.89524 .07953 Mdot
.89683 .09988 Mdot
.89841 .11544 Mdot
.9 .12763 Mdot
.90159 .13735 Mdot
.90317 .14515 Mdot
.90476 .15139 Mdot
.90635 .15634 Mdot
.90794 .16014 Mdot
.90952 .16294 Mdot
.91111 .16479 Mdot
.9127 .16576 Mdot
.91429 .16587 Mdot
.91587 .16514 Mdot
.91746 .16355 Mdot
.91905 .16108 Mdot
.92063 .15766 Mdot
.92222 .1532 Mdot
.92381 .1476 Mdot
.9254 .14067 Mdot
.92698 .13215 Mdot
.92857 .12166 Mdot
.93016 .10861 Mdot
.93175 .09206 Mdot
.93333 .07051 Mdot
.93492 .04234 Mdot
.93651 .01472 Mdot
.9381 .02367 Mdot
.93968 .05372 Mdot
.94127 .07861 Mdot
.94286 .09742 Mdot
.94444 .11191 Mdot
.94603 .12333 Mdot
.94762 .13247 Mdot
.94921 .13981 Mdot
.95079 .14567 Mdot
.95238 .15029 Mdot
.95397 .15382 Mdot
.95556 .15635 Mdot
.95714 .15797 Mdot
.95873 .15871 Mdot
.96032 .15861 Mdot
.9619 .15765 Mdot
.96349 .15584 Mdot
.96508 .15312 Mdot
.96667 .14945 Mdot
.96825 .14471 Mdot
.96984 .13878 Mdot
.97143 .13147 Mdot
.97302 .12248 Mdot
.9746 .11139 Mdot
.97619 .09753 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gPP10`40000100000800002008200000
P800P020P<30`8f9HL:oYL3L`:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV
09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000
<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI
<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0
I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<
IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHc
VITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<
VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01V
c3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Ko
c9Woc<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2I
oc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D5
1@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5?okl0000000000000000000
00000>7PdZ2PY820P?l0003o0?oo0000ool0o`3oooooooooJOl00?ooJOl00?ooJOl00?ooJOl001?o
00<0ool0oomCo`004ol00`3oo`3ooe?o000Co`030?oo0?ooDol001?o0P3ooeCo000Co`030?oo0?oo
Dol001?o00<0ool0oolho`806Ol000_o00<0ool01Ol00`3oo`3oocSo0P0Io`002ol00`3oo`05o`03
0?oo0?ooDol000_o00<0ool01Ol00`3oo`3oobSo0P0>o`806Ol000H01_l00`3oo`04o`<0oolXo`80
3_l201Wo000<o`030?oo00Co00<0ool0oolHo`803_l202Wo000=o`030?oo00?o00<0ool0oolHo`80
3_l202Wo0008o`030?oo00;o00<0ool00ol00`3oo`3ooe?o0008o`H01Ol00`3oo`3oo`Wo0P18o`00
4ol00`3oo`3oo`Wo0P18o`004ol20?oo>?l201[o000Co`030?oo0?oo6?l201go0P0Jo`004ol00`3o
o`3ho`803_l200go0P0io`004ol00`3oo`3ho`803_l200ko0P0>o`80:?l001?o00<0ool0j?l200ko
0P0No`803_l200ko0P0Ho`004ol20>Wo0P0lo`804?l201So000Co`030?oo0?oo9ol202[o000Co`03
0?oo0?oo2?l204Wo000Co`030?oo0=Wo0P0/o`80BOl001?o00<0ool0fOl205_o0P0Jo`004ol00`3o
o`3Io`803Ol204co0P0Jo`004ol20<[o0P0>o`803Ol302_o0P0jo`004ol00`3oo`39o`807_l200ko
0P0>o`802ol2023o0P0Ho`004ol00`3oo`3io`803_l200ko0P0=o`803_l201So000Co`030?oo0?Oo
0P0Po`802ol402So000Co`030?oo0;Wo0P0lo`80;Ol202[o000Co`030?oo0;Wo0P0>o`80Qol001?o
0P3:o`80??l202co0P0Ko`004ol00`3oo`3Ho`80;Ol202co0P0Ko`002_l300Ko00<0ool0Z_l200ko
0P0Lo`80??l2027o0P09o`803?l000Wo00D0oooo0005o`030?oo0:[o0P0>o`803_l204[o0P000ol0
000>o`803_l200Wo0P0<o`002Ol01@3oool000Go00<0ool0b_l200ko0P0;o`8000?o00003Ol200ko
0P0>o`802_l200;o0P0Wo`001P03o`050?ooo`001Ol30=[o0P0;o`8000?o00003Ol200ko0P0Jo`80
:ol000Wo1006o`030?oo0?Oo0P0lo`806ol000Wo00<0ool01ol00`3oo`2Jo`803Ol204co0P0=o`80
;Ol200;o0P09o`803?l000[o00<0ool01_l00`3oo`2Jo`803Ol200ko0P1;o`808_l200go0P09o`80
3?l000_o0`05o`030?oo0;Wo0P0=o`80Bol200?o0P0>o`809_l001?o00<0ool0Vol202_o0P10o`80
2Ol200?o0P09o`803Ol200go0P0=o`004ol208co0P0>o`803_l202[o0P0Qo`803_l201Wo0P0=o`80
1?l200Oo0P0=o`004ol00`3oo`2;o`807_l200go0P0>o`802ol20003o`0000_o0P000ol0000>o`80
;_l200ko0P0Fo`004ol00`3oo`2jo`803_l200ko0P0;o`8000?o00002_l200go0P0So`805ol200go
000Co`030?oo0?Ko0P0=o`803_l200?o0P08o`803Ol200Ko0P06o`803Ol001?o00<0ool0ool;o`80
2Ol200?o0P08o`801Ol200Ko0P06o`805Ol001?o00<0ool0n_l200ko0P0Oo`803_l200Go0P0>o`00
4ol209_o0P0=o`80Col201oo0P07o`803Ol200Ko0P05o`803_l001?o00<0ool0Nol200go0P0>o`80
3Ol200go0P0>o`803Ol200go0P03o`802Ol200go0P0=o`801Ol200Oo0P05o`801_l200Oo0P04o`80
3_l001?o00<0ool0Nol200go0`0[o`803_l200go0P02o`802Ol200?o0P09o`803Ol200Co0P07o`80
5Ol200Go0P08o`801?l200ko000Co`030?oo08_o0P0>o`80;_l200ko0P0^o`803_l200Ko0P07o`80
1?l200So0P03o`803ol001?o00<0ool0Nol201ko0P0>o`803_l200ko0P0^o`805ol200Go0P06o`80
1ol200Co0P08o`<00_l200oo000Co`030?oo07_o0P0^o`803_l202ko0P08o`801?l200Oo0P05o`80
1ol200Ko0P04o`802?l200?o0`09o`H03ol001?o0P3Wo`800ol200So0P0=o`801Ol200Ko0P07o`80
1?l200So0`02o`802_l5013o000Co`030?oo0<Oo0P0=o`800ol200Wo0P0Do`803_l200Go0P07o`80
1?l200Wo0P02o`802ol3017o000Co`030?oo0;So0P0=o`803Ol200?o0P0Oo`801_l200Ko0P0>o`80
0ol300Wo1P0Oo`004ol00`3oo`1/o`80>_l200ko0P0Ao`807ol200Ko0P0>o`801ol200Co0P08o`80
0_l200_o100Po`004ol00`3oo`1/o`80:ol200go0P0Bo`803Ol201So0P05o`801_l200Ko0P05o`80
2?l200?o0`08o`H0;ol001?o0P1mo`806ol2017o0P0>o`806?l200Co0P07o`805Ol200Go0P08o`80
0ol200[o1@0_o`004ol00`3oo`1lo`803?l400ko0P0>o`80:?l200Co0P0>o`801_l200Oo0P04o`80
2?l30003o`0000co0`0`o`004ol00`3oo`2:o`@03_l202So0P04o`805ol200Go0P06o`801ol200Co
0P09o`D0?ol000Wo1006o`030?oo0;Oo0P0=o`801?l200ko0P07o`801_l200Co0P08o`800ol200[o
1@0oo`002?l00`3oo`02o`030?oo00?o00<0ool0N_l203_o0P03o`805ol200Go0P0?o`801?l200Wo
0P02o`802ol3043o000=o`030?oo00?o00<0ool0G?l201co0P0/o`804_l200ko0P07o`803Ol200Oo
0P04o`802Ol604ko000600Oo00<0ool00ol305co0`19o`800_l201So0P04o`803ol200Go0P07o`<0
0_l300Wo1@1?o`002Ol400Ko00<0ool0GOl203Wo0P0Bo`806?l200go0P06o`801?l200Wo0P02o`80
2ol3053o0009o`030?oo00Oo00<0ool0KOl202Wo0P02o`806Ol200Co0P0>o`801_l200Ko0P04o`80
2Ol605ko0009o`030?oo00Oo00<0ool0Jol400ko0P0:o`8000?o00003_l201Wo0P04o`801_l200Ko
0P05o`801ol300?o0P0:o`@0Gol000Wo1@05o`030?oo06_o0P0@o`802_l20003o`0001Wo0P04o`80
5_l200Oo0P04o`802?l30004o`0000_o0P1Po`004ol00`3oo`2Wo`801?l200Oo0P05o`803ol200Co
0P09o`8000?o0000K_l001?o0P2No`805ol200Go0P06o`801ol200Co0P09o`D0K_l001?o00<0ool0
C_l202[o0P0Lo`800ol201oo0P05o`801ol300;o0P0;o`<0Kol001?o00<0ool0C_l202[o0P0Lo`80
3Ol200Co0P07o`801_l200Co0P09o`800_l207go000Co`030?oo08go0P0Ho`801?l200Oo0P06o`80
1?l200Wo1P1mo`004ol00`3oo`1=o`803Ol301ko0P0:o`800_l200ko0P0?o`803_l200Co0P0:o`@0
O_l001?o0P1>o`803Ol300ko0P0>o`802_l200co0P04o`801ol200Ko0P05o`802?l200;o0`2<o`00
4ol00`3oo`1[o`@0:?l200go0P06o`801Ol200So0P02o`80SOl001?o00<0ool0Jol2027o0P0>o`80
3_l200Co0P09o`H0SOl001?o00<0ool0NOl201?o0P0>o`801_l200Oo0P03o`802_l408ko000Co`03
0?oo07Wo0P0=o`803Ol200go0P07o`800ol209co000Co`030?oo07ko0P08o`803Ol200Ko0P04o`80
2?l30003o`0009go000Co`80?ol200ko0P0^o`803_l200oo0P04o`802Ol509go000Co`030?oo03ko
0P0>o`807_l201ko0P06o`801ol200Co0P0:o`<0W_l001?o00<0ool0G_l200[o0P02o`802Ol200go
0P0<o`801ol300;o0`2[o`004ol00`3oo`0oo`806_l20003o`0000[o0P0=o`800ol200So0P05o`80
1Ol200So0P02o`80[?l001?o00<0ool0?ol200_o0P0=o`808Ol200oo0P05o`802?l50:go000Co`03
0?oo04co0P0io`801_l200Co0P0:o`@0[Ol001?o0P1_o`803ol200Ko0P06o`<00ol200[o0`2^o`00
4ol00`3oo`1^o`802?l200Go0P0?o`800ol20;_o000;o`<01Ol00`3oo`1Yo`803Ol200co0P08o`80
0_l30;_o000<o`030?oo00Co00<0ool0Col200go0P09o`805?l200Go0P08o`H0_?l000co00<0ool0
1?l00`3oo`1?o`802_l20003o`0000oo0P07o`801Ol200Go0P09o`D0_?l000H00_l600Go0`0no`80
6ol201;o0P07o`801_l200Co0P0:o`80__l000Wo00@0ool01_l00`3oo`0`o`803?l2043o0P03o`80
bol000Wo00@0ool01_l00`3oo`0`o`80=ol200Co0P06o`801ol200?o0P3;o`002_l00`3o0006o`03
0?oo03oo0P0;o`804Ol200So0P04o`801_l200Oo0`001?l0003;o`002ol200Ko00<0ool0?ol200_o
0P0Ao`805_l200So1@3<o`004ol00`3oo`0_o`807_l200Wo0P0<o`801_l200Go0P09o`@0c?l001?o
0P0`o`807_l200Wo0P0<o`801_l200Co0P3Jo`004ol00`3oo`1Po`803ol200?o0P3Jo`004ol00`3o
o`1Po`801_l200Oo0P02o`80fol001?o00<0ool0F_l200co0P07o`<000?o0000fol001?o00<0ool0
?Ol200co0P0=o`801?l2013o1@3Ko`004ol00`3oo`0mo`803?l200?o0P0>o`801Ol200Wo103Lo`00
4ol2047o0P0>o`803ol200Co0P3Yo`004ol00`3oo`0`o`803_l201Oo0P06o`801?l20>Wo000Co`03
0?oo033o0P0Wo`801_l200?o0`3Yo`004ol00`3oo`1;o`800ol200oo0`02o`80j_l001?o00<0ool0
Bol200?o0P06o`802?l20004o`000>[o000Co`030?oo02;o0P0do`802?l60>[o000Co`808ol200_o
0P0<o`8000?o00003ol2013o0`3/o`004ol00`3oo`0_o`803?l20003o`0000oo0P05o`80n?l001?o
00<0ool0B_l200Go0P05o`80n?l001?o00<0ool0B_l200Go0P04o`80nOl001?o00<0ool0<Ol201oo
0P03o`80nOl001?o0P0So`803Ol200ko0P07o`801_l200?o0P3io`004ol00`3oo`0Ro`807Ol200Oo
0P06o`<000?o0000n_l001?o00<0ool0??l201Go1@3jo`002Ol300Oo00<0ool0??l200?o0P06o`80
2Ol30?_o0008o`050?ooo`001_l00`3oo`11o`801_l20?oo2?l000co00<0ool01?l00`3oo`0^o`80
oolSo`001P06o`030?oo00Co0`0^o`800_l200ko0P05o`80ool8o`002_l200Oo00<0ool0<_l200Oo
0P05o`801Ol20?oo2?l000co00<0ool01?l00`3oo`0So`805_l200Ko0P03o`80ool9o`002?l01@3o
ool000Ko00<0ool08ol201ko0P02o`<0ool9o`002Ol300Oo00<0ool0>ol200Ko0P02o`80ool:o`00
4ol00`3oo`0Go`808_l200Ko1P3oo`[o000Co`806?l201Wo0P0@o`@0ool;o`004ol00`3oo`0^o`80
0_l2013o103oo`_o000Co`030?oo02ko0P0:o`80oolGo`004ol00`3oo`0co`801Ol20?oo5ol001?o
00<0ool08Ol2013o0P05o`80oolGo`004ol202;o0P0Go`80oolGo`004ol00`3oo`0So`803_l20?oo
7_l001?o00<0ool08ol200So0P04o`801?l20?oo6?l001?o00<0ool0;Ol200Go0P03o`80oolHo`00
4ol00`3oo`0do`800ol20?oo6?l001?o00<0ool0=?l200;o0P3ooaWo000Co`80;_l200Go0`000ol0
003ooaWo000Co`030?oo02go0P06o`D0oolIo`004ol00`3oo`0To`803ol40?oo6_l001?o00<0ool0
8Ol20003o`000?oo;Ol001?o00<0ool08Ol200Wo0P3oobGo000Co`030?oo02co0P3oobGo000Co`80
oomDo`004ol00`3oo`0To`801_l20?oo9Ol000So1@06o`030?oo02Co0P06o`80oolUo`002?l01@3o
ool000Ko00<0ool0oomCo`002Ol00`3oo`07o`030?oo02Go0P04o`80oolVo`001P04o`030?oo00Ko
0`0Go`801ol200?o0P04o`80oolVo`002ol00`3oo`05o`030?oo01Oo0P07o`802?l20?oo9ol000co
00<0ool01?l00`3oo`0Fo`803_l200;o0P3oobOo0008o`050?ooo`001_l00`3oo`0Fo`803_l200;o
0P3oobOo0009o`<01ol00`3oo`0Vo`8000?o0000oolXo`004ol00`3oo`0Wo`@0oolXo`004ol2027o
0P05o`@0oolXo`004ol00`3oo`0Po`80oolao`004ol00`3oo`3ooe?o000Co`030?oo0?ooDol001?o
00<0ool0oomCo`004ol00`3oo`0Oo`80oolbo`004ol201Wo0P05o`80oolbo`004ol00`3oo`0Ho`80
oolio`004ol00`3oo`3ooe?o000Co`030?oo01ko0P3ooc?o000Co`030?oo01ko0P3ooc?o000Co`80
oomDo`004ol00`3oo`0No`80oolco`004ol00`3oo`0Ho`801?l20?oo<ol001?o00<0ool05_l40?oo
>Ol001?o00<0ool05_l200Go0P3oocCo000Co`030?oo01go0P3oocCo000Co`806_l200;o0P3oocCo
000Co`030?oo01Wo0P02o`80ooldo`004ol00`3oo`0Io`8000?o0000ooleo`002Ol500Go00<0ool0
6Ol50?oo=Ol000_o00<0ool01Ol00`3oo`0Jo`@0ooleo`002ol00`3oo`05o`030?oo01_o0P3oocKo
000600Go00<0ool01Ol30?ooDol000_o00<0ool01Ol00`3oo`3ooe?o000;o`030?oo00Go00<0ool0
oomCo`002Ol300Oo00<0ool05Ol20?oo??l000_o00<0ool01Ol00`3oo`0Eo`80oollo`004ol00`3o
o`3ooe?o000Co`80oomDo`004ol00`3oo`3ooe?o000Co`030?oo0?ooDol001?o00<0ool0oomCo`00
4ol00`3oo`0Eo`80oollo`004ol201Ko0P3oocco000Co`030?oo0?ooDol001?o00<0ool0:_l500?o
1004o`@08Ol500Co1004o`@08ol300Go1004o`@09Ol300?o1004o`@08ol400Co1004o`@08ol300Co
1004o`@00ol001?o00<0ool0;?l00`3oo`02o`030?oo00;o00@0ool01?l00`3oo`0No`050?ooo`00
0ol00`3oo`02o`040?oo00Co00<0ool07ol01@3oool000?o00<0ool00_l0103oo`04o`030?oo02?o
00D0oooo0004o`040?oo00Co00<0ool07ol00`3oo`02o`040?oo00Co00@0ool01?l00`3oo`0Oo`05
0?ooo`000_l00`3oo`02o`040?oo00Co0@01o`7o000Co`030?oo02co00<0ool00_l00`3oo`02o`04
0?oo00Co00<0ool07ol00`3oo`04o`030?oo00;o00@0ool01?l00`3oo`0So`050?ooo`001?l0103o
o`04o`030?oo02?o00D0oooo0004o`040?oo00Co00<0ool09?l0103oo`04o`040?oo00Co00<0ool0
7ol01@3oool000;o00<0ool00_l0103oo`04o`400Ol1o`004ol00`3oo`0Do`805_l00`3oo`02o`03
0?oo00;o00@0ool01?l00`3oo`0Po`030?oo00?o00<0ool00_l0103oo`04o`030?oo02?o00D0oooo
0004o`040?oo00Co00<0ool07ol600;o00<0ool00_l0103oo`04o`030?oo02Co00@0ool01?l0103o
o`04o`030?oo01oo00D0oooo0002o`030?oo00;o00@0ool01?l1007o0Ol001?o0P0Eo`805_l00`3o
o`02o`030?oo00;o00@0ool01?l00`3oo`0Qo`030?oo00;o00<0ool00_l0103oo`04o`030?oo027o
0P04o`030?oo00;o00@0ool01?l00`3oo`0Po`040?oo00?o00<0ool00_l0103oo`04o`030?oo023o
1003o`030?oo00;o00@0ool01?l00`3oo`0Oo`@00ol00`3oo`02o`040?oo00Co0@01o`7o000Co`03
0?oo02co00<0ool00_l00`3oo`02o`040?oo00Co00<0ool08_l01@3oool000Co00@0ool01?l00`3o
o`0So`050?ooo`001?l0103oo`04o`030?oo023o00@0ool00ol00`3oo`02o`040?oo00Co00<0ool0
8?l00`3oo`04o`030?oo00;o00@0ool01?l00`3oo`0Oo`030?oo00Co00<0ool00_l0103oo`04o`40
0Ol1o`004ol00`3oo`0Zo`<01?l00`3oo`02o`040?oo00Co00<0ool07_l01@3oool000?o00<0ool0
0_l0103oo`04o`030?oo01oo00D0oooo0003o`030?oo00;o00@0ool01?l00`3oo`0Qo`030?l000?o
00<0ool00_l0103oo`04o`030?oo023o00<0ool01?l00`3oo`02o`040?oo00Co00<0ool08?l00`3o
o`03o`030?oo00;o00@0ool01?l1007o0Ol001?o00<0ool04ol201Oo00<0ool00ol400Co100Ro`<0
1Ol400Co100So`<01Ol400Co100Uo`801?l400Co100So`D00ol400Co100To`<00ol400Co1003o`00
4ol00`3oo`0Co`80oolno`004ol00`3oo`0Co`80oolno`004ol201Co0P3oocko000Co`030?oo01;o
0P3oocoo000Co`030?oo01;o0P3oocoo000Co`030?oo017o0`3oocoo000Co`030?oo013o0`3ood3o
000;ool0FP04o`004_lE00;o00<0ool02?l00`3oo`08o`030?oo00So00<0ool02?l00`3oo`07o`03
0?oo00So00<0ool02?l00`3oo`08o`030?oo00So00<0ool02?l00`3oo`08o`030?oo00So00<0ool0
2?l00`3oo`08o`030?oo00So00<0ool02?l00`3oo`08o`030?oo00So00<0ool02?l00`3oo`08o`03
0?oo00So00<0ool02?l00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`08o`030?oo00So00<0ool0
2?l00`3oo`0:o`004ol00`3oo`08o`030?oo00So00<0ool02?l00`3oo`08o`030?oo00So00<0ool0
2?l00`3oo`07o`030?oo00So00<0ool02?l00`3oo`08o`030?oo00So00<0ool02?l00`3oo`08o`03
0?oo00So00<0ool02?l00`3oo`08o`030?oo00So00<0ool02?l00`3oo`08o`030?oo00So00<0ool0
2?l00`3oo`08o`030?oo00So00<0ool02?l00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`08o`03
0?oo00So00<0ool02?l00`3oo`0:o`004ol00`3oo`3ooe?o000Co`030?oo0?ooDol001?o00<0ool0
oomCo`00oomYo`00oomYo`00oomYo`00oomYo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-35.2803, -7.45326, 2.28355, \
0.0439087}}],

Cell[BoxData[
    \({1.5399999999999636`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Layers\)], "Input"],

Cell[BoxData[
    \({{0, 0, 0, 0, 0}, {40, 10.3`, 0, 0, 9.15`}, {0, 4.15`, 0, 0, 
        5.`}}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1600}, {0, 1127}},
WindowToolbars->"EditBar",
WindowSize->{801, 582},
WindowMargins->{{Automatic, 0}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Default.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 90, 1, 185, "Title"],

Cell[CellGroupData[{
Cell[1854, 56, 60, 0, 66, "Section"],
Cell[1917, 58, 1025, 19, 224, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2979, 82, 122, 3, 66, "Section"],
Cell[3104, 87, 76, 1, 35, "Input"],
Cell[3183, 90, 335, 7, 122, "Text"],

Cell[CellGroupData[{
Cell[3543, 101, 84, 1, 35, "Input"],
Cell[3630, 104, 185, 3, 51, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3852, 112, 39, 1, 35, "Input"],
Cell[3894, 115, 109, 2, 35, "Output"]
}, Open  ]],
Cell[4018, 120, 496, 9, 119, "Input"],

Cell[CellGroupData[{
Cell[4539, 133, 34, 1, 35, "Input"],
Cell[4576, 136, 88, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4701, 142, 42, 0, 57, "Subsection"],
Cell[4746, 144, 643, 11, 224, "Input"],

Cell[CellGroupData[{
Cell[5414, 159, 75, 1, 35, "Input"],
Cell[5492, 162, 305, 5, 35, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5846, 173, 77, 0, 57, "Subsection"],
Cell[5926, 175, 233, 5, 80, "Text"],
Cell[6162, 182, 2654, 49, 707, "Input"],
Cell[8819, 233, 75, 1, 35, "Input"],

Cell[CellGroupData[{
Cell[8919, 238, 71, 1, 35, "Input"],
Cell[8993, 241, 14882, 513, 233, 6602, 406, "GraphicsData", "PostScript", \
"Graphics"],
Cell[23878, 756, 69, 1, 35, "Output"]
}, Open  ]],
Cell[23962, 760, 1948, 37, 539, "Input"],

Cell[CellGroupData[{
Cell[25935, 801, 79, 1, 35, "Input"],
Cell[26017, 804, 68, 1, 35, "Output"]
}, Open  ]],
Cell[26100, 808, 1135, 19, 329, "Input"],
Cell[27238, 829, 1777, 33, 476, "Input"],
Cell[29018, 864, 50, 1, 35, "Input"],

Cell[CellGroupData[{
Cell[29093, 869, 80, 1, 35, "Input"],
Cell[29176, 872, 14956, 519, 233, 6664, 412, "GraphicsData", "PostScript", \
"Graphics"],
Cell[44135, 1393, 69, 1, 35, "Output"]
}, Open  ]],
Cell[44219, 1397, 2815, 50, 770, "Input"],
Cell[47037, 1449, 75, 1, 35, "Input"],

Cell[CellGroupData[{
Cell[47137, 1454, 88, 1, 35, "Input"],
Cell[47228, 1457, 27745, 1046, 233, 15234, 887, "GraphicsData", "PostScript", \
"Graphics"],
Cell[74976, 2505, 69, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[75082, 2511, 39, 1, 35, "Input"],
Cell[75124, 2514, 109, 2, 35, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

