(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     87294,       2953]*)
(*NotebookOutlinePosition[     88029,       2979]*)
(*  CellTagsIndexPosition[     87985,       2975]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Calcul de reflectivit\[EAcute] sur un syst\[EGrave]me de couches \
minces", "Title"],

Cell[CellGroupData[{

Cell["D\[EAcute]finition de quelques constantes", "Section"],

Cell[BoxData[{
    \(\(me = 
        9.109*10^\(-31\);\)\ \ \ \t\ \ \ \ \ \  (*\ \ electron\ mass\ *) \), \
"\[IndentingNewLine]", 
    \(\(mn = 1.675*10^\(-27\);\)\ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      neutron\ mass\ *) \), "\[IndentingNewLine]", 
    \(\(hp = 6.626*10^\(-34\);\)\ \ \ \ \ \ \ \ \ \ \  (*\ 
      Planck' s\ contant\ *) \), "\[IndentingNewLine]", 
    \(hb = 1.0546*10^\(-34\); \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Planck' s\ constant\ h\ bar\ *) \[IndentingNewLine]hb2 = \ 
      1.1121811600000002*10^\(-68\);\), "\[IndentingNewLine]", 
    \(\(mu0 = 4*pi*10^\(-7\);\)\ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      vacuum\ permitivitty\ *) \), "\[IndentingNewLine]", 
    \(\(muB = \(-9.27408\)*10^\(-24\);\)\ \ \ \ \ \ \  (*\ 
      magneton\ de\ Bohr\ *) \), "\[IndentingNewLine]", 
    \(\(mun = \(-1.91\)*5.05082*10^\(-27\);\)\ \ \  (*\ %  
        neutron\ moment\ *) \ \ \), "\[IndentingNewLine]", 
    \(\(Deg = \ Pi/180;\)\  (*\ 
      facteur\ de\ conversion\ en\ radians\ *) \[IndentingNewLine]\)}], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Trac\[EAcute] d'une courbe de r\[EAcute]flectivit\[EAcute] a partir du \
fichier \"layers.txt\"\
\>", "Section"],

Cell[BoxData[
    \(\(SetDirectory["\<F:/Simul/reflecMCA\>"];\)\)], "Input"],

Cell["\<\
% colonne 1 contains the thickness in nm
% colonne 2 contains the diffusion length in fm
% colonne 3 contains the magnetic field in \[Micro]B per atom
% colonne 4 contains the direction of the magnetic field (always supposed to \
be in the plane of th layers)
% colonne 5 contains the atomic density in atoms/m3\
\>", "Text"],

Cell[BoxData[
    \(\(Layers = Import["\<layers.txt\>", "\<Table\>"];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Layers\)], "Input"],

Cell[OutputFormData["\<\
{{0, 0, 0, 0, 0}, {40, 10.3, 0, 0, 9.15}, 
 {0, 4.15, 0, 0, 5.}}\
\>", "\<\
{{0, 0, 0, 0, 0}, {40, 10.3, 0, 0, 9.15}, 
 
  {0, 4.15, 0, 0, 5.}}\
\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(z = Layers[\([All, 1]\)]*10^\(-9\);\)\  (*\ 
      vecteur\ des\ epaisseurs\ *) \), "\[IndentingNewLine]", 
    \(\(b = Layers[\([All, 2]\)]*10^\(-15\);\)\ \ \ \ \ \  (*\ 
      vecteur\ des\ longueur\ de\ diffusion\ *) \), "\[IndentingNewLine]", 
    \(\(d = 
        Layers[\([All, 
              5]\)]*10^28;\)\[IndentingNewLine] (*\ \ \(calculation\ of\ the\ \
potential\ in\ each\ layer;\)\ *) \), "\[IndentingNewLine]", 
    \(\(V = 2*Pi*hb*hb*d*b/mn;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(V\)], "Input"],

Cell[OutputFormData["\<\
{0, 3.9318678225792994*^-26, 8.656826072313698*^-27}\
\>", "\<\
              -26            -27
{0, 3.93187 10   , 8.65683 10   }\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Subroutine de calcul", "Subsection"],

Cell[BoxData[
    \(\(Iteration = 
        Compile[{{k, _Integer}, {nbrLayers, \ _Integer}, {q, _Complex}, {z, \
_Real}, \ {M, _Complex, 
              2}}, \[IndentingNewLine]Module[{DD = {\ {1, 1}, {q, \(-q\)}}, 
              P = {\ {\ Exp[\(-I\)*q*z], 0}, \ {\ 0, Exp[I*q*z]\ }}, \ 
              MM = {{I, 0}, {0, 0}}}, \ \[IndentingNewLine]\t
            If[\ k \[Equal] 1, 
              MM = Inverse[DD], \[IndentingNewLine]\t\tIf[\ 
                k \[Equal] nbrLayers, MM = N[M . DD], 
                MM = N[M . DD . P . Inverse[DD]]]]; \ \[IndentingNewLine]\t
            MM\[IndentingNewLine]]\[IndentingNewLine]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Iteration[1, 3, 1.1, 10, {{0, 0}, {0, 0}}]\)], "Input"],

Cell[BoxData[
    \({{\(\(0.5`\)\(\[InvisibleSpace]\)\) + 
          0.`\ \[ImaginaryI], \(\(0.45454545454545453`\)\(\[InvisibleSpace]\)\
\) + 0.`\ \[ImaginaryI]}, {\(\(0.5`\)\(\[InvisibleSpace]\)\) + 
          0.`\ \[ImaginaryI], \(-0.45454545454545453`\) + 
          0.`\ \[ImaginaryI]}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Function de calcul d'une courbe de reflectivit\[EAcute]", "Subsection"],

Cell["\<\
(* INPUT: \tangles_ : \ta table of angles en degr\[EAcute]s *)
(*        \tlambda_ : \tthe neutron wavelength (nm) *)
(* OUTPUT:\tRef_   : \ta Table of the reflectivities for the different \
incidence angle *)\
\>", "Text"],

Cell[BoxData[
    \(\(\(ReflecNP[angles_, 
        lambda_]\)\(:=\)\(\ \)\(Module[\[IndentingNewLine]{l, \ k, \ f1, \ 
          kp, \ q0, \ DD, \ P, \ T, R, \ M}, \[IndentingNewLine]l = 
          lambda*10^\(-9\); \  (*\ passage\ en\ SI\ *) \[IndentingNewLine]k = 
          2*Pi/l; \  (*\ moment\ du\ neutron\ *) \[IndentingNewLine]T = {}; 
        R = {}; \[IndentingNewLine]\[IndentingNewLine]Do[\ 
          f1 = angles[\([i]\)]*Pi/180; \  (*\ 
            passage\ en\ degr\[EAcute]s\ *) \[IndentingNewLine]\t
          kp\  = \ k*Cos[f1]; \  (*\ 
            composante\ planaire\ *) \[IndentingNewLine]\t
          q0\  = \ k*Sin[f1]; \ \  (*\ 
            composante\ perpendiculaire\ *) \[IndentingNewLine]\t
          nbrLayers\  = \ \(Dimensions[z]\)[\([1]\)]; \[IndentingNewLine]\t
          Eq = hb2*q0*\(q0/2\)/mn*
              Table[1, {nbrLayers}]; \ \[IndentingNewLine]\t (*\ 
            energy\ cinetique\ perpendiculaire\ dans\ chaque\ couche\ \
*) \[IndentingNewLine]\t
          q = \((2*
                  mn*\((Eq - 
                        V)\)/\((hb2)\))\)^0.5; \ \[IndentingNewLine]\t (*\ \
\(Print[f1, kp, q0, nbrLayers, Eq, "\<  \>", 
                q];\)\ *) \[IndentingNewLine]\t (*\ 
            perpendicular\ wavevector\ in\ each\ layer\ \
*) \[IndentingNewLine]\t
          Do[\ \  (*\ 
              initialisation\ of\ the\ D\ matrix\ *) \[IndentingNewLine]\t\t\
DD = {\ {1, 1}, {q[\([k]\)], \(-q[\([k]\)]\)}}; \[IndentingNewLine]\t\t (*\ 
              initialisation\ of\ the\ propagation\ matrix\ \
*) \[IndentingNewLine]\t\tP = {\ {\ Exp[\(-I\)*q[\([k]\)]*z[\([k]\)]\ ], 
                  0}, \ {\ 0, 
                  Exp[I*q[\([k]\)]*
                      z[\([k]\)]]\ }}; \[IndentingNewLine]\t\t (*\ \(Print[
                  q[\([k]\)], z[\([k]\)]];\)\ *) \[IndentingNewLine]\t\t (*\ 
              Print[k]; Print[DD]; Print[P];\ *) \[IndentingNewLine]\t\tIf[\ 
              k \[Equal] 1, 
              M = N[Inverse[DD]], \[IndentingNewLine]\t\t\tIf[\ 
                k \[Equal] nbrLayers, M = N[M . DD], 
                M = N[M . DD . P . Inverse[DD]]]];\[IndentingNewLine]\t\t (*\ 
              Print[M]\ *) \[IndentingNewLine]\t, {k, 
              nbrLayers}\[IndentingNewLine]\t]; \[IndentingNewLine]\t
          AppendTo[T, Abs[1/M[\([1, 1]\)]]^2]; \[IndentingNewLine]\t
          AppendTo[R, 
            Abs[M[\([2, 1]\)]/
                  M[\([1, 1]\)]]^2\ ]\[IndentingNewLine], {i, \(Dimensions[
                
                angles]\)[\([1]\)]}\[IndentingNewLine]]; \
\[IndentingNewLine]ListPlot[
          Log[R]];\ \[IndentingNewLine]]\)\(\[IndentingNewLine]\)\)\)], \
"Input"],

Cell[BoxData[
    \(\(angles = Table[i, {i, 0.01, 2, 0.01}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ReflecNP[angles, 0.4];\)\  // Timing\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.603319 0.050776 [
[.2619 .59082 -6 -9 ]
[.2619 .59082 6 0 ]
[.5 .59082 -9 -9 ]
[.5 .59082 9 0 ]
[.7381 .59082 -9 -9 ]
[.7381 .59082 9 0 ]
[.97619 .59082 -9 -9 ]
[.97619 .59082 9 0 ]
[.01131 .09556 -18 -4.5 ]
[.01131 .09556 0 4.5 ]
[.01131 .19711 -12 -4.5 ]
[.01131 .19711 0 4.5 ]
[.01131 .29866 -12 -4.5 ]
[.01131 .29866 0 4.5 ]
[.01131 .40021 -12 -4.5 ]
[.01131 .40021 0 4.5 ]
[.01131 .50177 -12 -4.5 ]
[.01131 .50177 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .60332 m
.2619 .60957 L
s
[(50)] .2619 .59082 0 1 Mshowa
.5 .60332 m
.5 .60957 L
s
[(100)] .5 .59082 0 1 Mshowa
.7381 .60332 m
.7381 .60957 L
s
[(150)] .7381 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(200)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.21429 .60332 m
.21429 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.40476 .60332 m
.40476 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.59524 .60332 m
.59524 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.78571 .60332 m
.78571 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .09556 m
.03006 .09556 L
s
[(-10)] .01131 .09556 1 0 Mshowa
.02381 .19711 m
.03006 .19711 L
s
[(-8)] .01131 .19711 1 0 Mshowa
.02381 .29866 m
.03006 .29866 L
s
[(-6)] .01131 .29866 1 0 Mshowa
.02381 .40021 m
.03006 .40021 L
s
[(-4)] .01131 .40021 1 0 Mshowa
.02381 .50177 m
.03006 .50177 L
s
[(-2)] .01131 .50177 1 0 Mshowa
.125 Mabswid
.02381 .12095 m
.02756 .12095 L
s
.02381 .14633 m
.02756 .14633 L
s
.02381 .17172 m
.02756 .17172 L
s
.02381 .2225 m
.02756 .2225 L
s
.02381 .24789 m
.02756 .24789 L
s
.02381 .27327 m
.02756 .27327 L
s
.02381 .32405 m
.02756 .32405 L
s
.02381 .34944 m
.02756 .34944 L
s
.02381 .37483 m
.02756 .37483 L
s
.02381 .4256 m
.02756 .4256 L
s
.02381 .45099 m
.02756 .45099 L
s
.02381 .47638 m
.02756 .47638 L
s
.02381 .52715 m
.02756 .52715 L
s
.02381 .55254 m
.02756 .55254 L
s
.02381 .57793 m
.02756 .57793 L
s
.02381 .07017 m
.02756 .07017 L
s
.02381 .04478 m
.02756 .04478 L
s
.02381 .01939 m
.02756 .01939 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .60332 Mdot
.03333 .60332 Mdot
.0381 .60332 Mdot
.04286 .60332 Mdot
.04762 .60332 Mdot
.05238 .60332 Mdot
.05714 .60332 Mdot
.0619 .60332 Mdot
.06667 .60332 Mdot
.07143 .60332 Mdot
.07619 .60332 Mdot
.08095 .60332 Mdot
.08571 .60332 Mdot
.09048 .60332 Mdot
.09524 .60332 Mdot
.1 .60332 Mdot
.10476 .60332 Mdot
.10952 .60332 Mdot
.11429 .6033 Mdot
.11905 .60328 Mdot
.12381 .60326 Mdot
.12857 .60323 Mdot
.13333 .60321 Mdot
.1381 .60317 Mdot
.14286 .60313 Mdot
.14762 .60307 Mdot
.15238 .603 Mdot
.15714 .60291 Mdot
.1619 .6028 Mdot
.16667 .60265 Mdot
.17143 .60246 Mdot
.17619 .6022 Mdot
.18095 .60186 Mdot
.18571 .60141 Mdot
.19048 .60079 Mdot
.19524 .59994 Mdot
.2 .59875 Mdot
.20476 .59708 Mdot
.20952 .5947 Mdot
.21429 .59126 Mdot
.21905 .58625 Mdot
.22381 .57893 Mdot
.22857 .56824 Mdot
.23333 .55274 Mdot
.2381 .53052 Mdot
.24286 .49885 Mdot
.24762 .45262 Mdot
.25238 .37792 Mdot
.25714 .27451 Mdot
.2619 .36713 Mdot
.26667 .41809 Mdot
.27143 .44509 Mdot
.27619 .46091 Mdot
.28095 .47027 Mdot
.28571 .47536 Mdot
.29048 .47733 Mdot
.29524 .47681 Mdot
.3 .47414 Mdot
.30476 .46948 Mdot
.30952 .46288 Mdot
.31429 .45428 Mdot
.31905 .44349 Mdot
.32381 .43024 Mdot
.32857 .41403 Mdot
.33333 .39412 Mdot
.3381 .3692 Mdot
.34286 .33697 Mdot
.34762 .29289 Mdot
.35238 .23077 Mdot
.35714 .20406 Mdot
.3619 .26003 Mdot
.36667 .30285 Mdot
.37143 .3312 Mdot
.37619 .35092 Mdot
.38095 .36504 Mdot
.38571 .3752 Mdot
.39048 .38236 Mdot
.39524 .3871 Mdot
.4 .3898 Mdot
.40476 .39072 Mdot
.40952 .39 Mdot
.41429 .38774 Mdot
.41905 .38396 Mdot
.42381 .37866 Mdot
.42857 .37176 Mdot
.43333 .36312 Mdot
.4381 .35256 Mdot
.44286 .33974 Mdot
.44762 .32419 Mdot
.45238 .30516 Mdot
.45714 .28142 Mdot
.4619 .25085 Mdot
.46667 .20982 Mdot
.47143 .15658 Mdot
.47619 .13934 Mdot
.48095 .18612 Mdot
.48571 .22668 Mdot
.49048 .25532 Mdot
.49524 .27611 Mdot
.5 .29164 Mdot
.50476 .30338 Mdot
.50952 .31222 Mdot
.51429 .31873 Mdot
.51905 .32326 Mdot
.52381 .32609 Mdot
.52857 .32736 Mdot
.53333 .32718 Mdot
.5381 .32562 Mdot
.54286 .32269 Mdot
.54762 .31837 Mdot
.55238 .31261 Mdot
.55714 .30528 Mdot
.5619 .29624 Mdot
.56667 .28522 Mdot
.57143 .27186 Mdot
.57619 .2556 Mdot
.58095 .23555 Mdot
.58571 .21026 Mdot
.59048 .1773 Mdot
.59524 .1333 Mdot
.6 .08742 Mdot
.60476 .10238 Mdot
.60952 .14789 Mdot
.61429 .18301 Mdot
.61905 .20855 Mdot
.62381 .22765 Mdot
.62857 .24227 Mdot
.63333 .25355 Mdot
.6381 .26223 Mdot
.64286 .26877 Mdot
.64762 .27348 Mdot
.65238 .27658 Mdot
.65714 .27822 Mdot
.6619 .27848 Mdot
.66667 .27742 Mdot
.67143 .27506 Mdot
.67619 .27138 Mdot
.68095 .26632 Mdot
.68571 .25978 Mdot
.69048 .25163 Mdot
.69524 .24164 Mdot
.7 .2295 Mdot
.70476 .21473 Mdot
.70952 .19658 Mdot
.71429 .1739 Mdot
.71905 .14474 Mdot
.72381 .10612 Mdot
.72857 .05879 Mdot
.73333 .04614 Mdot
.7381 .08807 Mdot
.74286 .12722 Mdot
.74762 .15605 Mdot
.75238 .17758 Mdot
.75714 .19408 Mdot
.7619 .20692 Mdot
.76667 .21694 Mdot
.77143 .2247 Mdot
.77619 .23054 Mdot
.78095 .23472 Mdot
.78571 .23741 Mdot
.79048 .23871 Mdot
.79524 .23871 Mdot
.8 .23743 Mdot
.80476 .23487 Mdot
.80952 .23101 Mdot
.81429 .22578 Mdot
.81905 .21906 Mdot
.82381 .21071 Mdot
.82857 .20048 Mdot
.83333 .18802 Mdot
.8381 .17282 Mdot
.84286 .15406 Mdot
.84762 .13048 Mdot
.85238 .09995 Mdot
.85714 .05958 Mdot
.8619 .01472 Mdot
.86667 .01787 Mdot
.87143 .06136 Mdot
.87619 .09802 Mdot
.88095 .12515 Mdot
.88571 .14566 Mdot
.89048 .16152 Mdot
.89524 .17397 Mdot
.9 .18375 Mdot
.90476 .19136 Mdot
.90952 .19713 Mdot
.91429 .2013 Mdot
.91905 .20401 Mdot
.92381 .20537 Mdot
.92857 .20545 Mdot
.93333 .20427 Mdot
.9381 .20183 Mdot
.94286 .19811 Mdot
.94762 .19302 Mdot
.95238 .18648 Mdot
.95714 .17831 Mdot
.9619 .16828 Mdot
.96667 .15604 Mdot
.97143 .14109 Mdot
.97619 .12264 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gPP10`40000100000800002008200000
P800P020P<30`8f9HL:oYL3L`:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV
09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000
<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI
<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0
I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<
IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHc
VITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<
VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01V
c3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Ko
c9Woc<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2I
oc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D5
1@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5?okl0000000000000000000
00000>7PdZ2PY820P?l0003o0?oo0000ool0o`3oooooooooJOl00?ooJOl00?ooJOl00?ooJOl00?oo
JOl00?ooJOl00?ooJOl001[o00<0ool0oom<o`006_l00`3oo`3oodco000Jo`030?oo0?ooC?l001[o
00<0ool0oom<o`006_l00`3oo`3ooaSo0P0bo`006_l00`3oo`3ooaSo100`o`006_l20?oo6ol2033o
000Jo`030?oo0?ooC?l001[o00<0ool0oom<o`006_l00`3oo`3oodco000Jo`030?oo0?ooC?l001[o
00<0ool0oom<o`006_l00`3oo`3oodco000Jo`030?oo0?ooC?l001[o00<0ool0oom<o`006_l20>go
0P1Mo`006_l00`3oo`3/o`80GOl001[o00<0ool0oom<o`006_l00`3oo`3oodco000Jo`030?oo0>[o
0P1Oo`006_l00`3oo`3Zo`80:Ol200?o0P0_o`006_l00`3oo`3ooaKo0P03o`80;ol001[o00<0ool0
oom<o`006_l20?ooCOl001[o00<0ool0oom<o`006_l00`3oo`3oodco000Jo`030?oo0?ooC?l001[o
00<0ool0oom<o`006_l00`3oo`3oodco0008o`D00ol400Ko00<0ool0_ol202co0P1Lo`002_l00`3o
o`02o`030?oo00;o00<0ool00ol00`3oo`2oo`80;?l205co000:o`030?oo00;o00<0ool00_l00`3o
o`03o`030?oo0?ooC?l000D01Ol00`3oo`02o`030?oo00;o00<0ool00ol30?oo7Ol202go000:o`03
0?oo00;o00<0ool00_l00`3oo`03o`030?oo0?oo5Ol200Ko0P0]o`002_l00`3oo`02o`030?oo00;o
00<0ool00ol00`3oo`30o`80D_l203Go0008o`<01?l00`3oo`02o`030?oo00?o00<0ool0`?l202Ko
0P1Qo`002_l00`3oo`03o`@01_l00`3oo`3Xo`80HOl001[o00<0ool0oom<o`006_l00`3oo`3oodco
000Jo`030?oo0?ooC?l001[o0P3oodgo000Jo`030?oo0?oo?_l200co000Jo`030?oo0>oo0P0/o`80
7_l200co000Jo`030?oo0>oo0P0Qo`802Ol202co000Jo`030?oo0;go0P1Co`80=ol001[o00<0ool0
_Ol208co000Jo`030?oo09Go0P2do`006_l00`3oo`2Eo`80YOl200go000Jo`030?oo0>Oo0P1Co`80
3Ol001[o0P33o`808ol203Ko0P0Zo`006_l00`3oo`32o`80Fol202[o000Jo`030?oo0?oo4Ol203Wo
000Jo`030?oo09?o0P1Ko`807_l202So0P0?o`006_l00`3oo`2Co`80Fol204So0P0?o`006_l00`3o
o`3oob;o0P0Xo`006_l00`3oo`3oob;o0P0Xo`006_l00`3oo`3ooc[o0P0@o`006_l00`3oo`3ooc[o
0P0@o`006_l20>Ko0P0Xo`804Ol202Oo000Jo`030?oo0;_o0P0Xo`802ol201_o0P0Ao`809ol001[o
00<0ool0^ol203Go0P13o`804_l001[o00<0ool0`ol205oo0P0Ao`804_l001[o00<0ool0U_l202_o
0P1Oo`803ol201Co000@o`@01_l00`3oo`2Fo`80MOl202Ko0P0Do`003ol00`3oo`02o`030?oo00?o
00<0ool0ool>o`805_l202Co000?o`030?oo00;o00<0ool00ol00`3oo`3do`80;ol200go0P0Eo`00
1ol600;o00<0ool00_l00`3oo`03o`<0i?l200ko0P0ao`802Ol401Go000@o`@01_l00`3oo`3To`80
9_l201Wo1006o`<05ol000oo00<0ool00_l00`3oo`03o`030?oo06go0P2Mo`806ol300?o100Ho`00
3ol00`3oo`02o`030?oo00?o00<0ool0KOl208Ko0P0co`L06_l0013o1006o`030?oo09;o0P0Vo`80
2Ol202ko0P0Co`808?l301co000Jo`030?oo09;o0P0Vo`802Ol204?o0P0oo`006_l00`3oo`3Ro`80
Iol001[o00<0ool0h_l201?o0P0?o`80@Ol001[o00<0ool0mol200oo0P11o`006_l20?Wo0P1Ao`00
6_l00`3oo`2Ho`80;Ol202oo0P0=o`80@_l001[o00<0ool0Jol202_o0P0]o`805ol201So0P09o`@0
@_l001[o00<0ool0Jol207?o0P0Ho`802Ol204Co000Jo`030?oo0;So0P12o`<00ol404Go000Jo`03
0?oo0;So0P12o`X0AOl001[o00<0ool0b?l201Go0P0No`<0BOl001[o00<0ool0b?l201Go0P1Zo`00
6_l20?ooCOl001[o00<0ool0T?l204_o0P1/o`006_l00`3oo`2@o`80>?l2017o0P1/o`006_l00`3o
o`2Jo`806ol2017o0P1oo`006_l00`3oo`1^o`80:_l201_o0P0So`80KOl001[o00<0ool0K_l205_o
0P0?o`80KOl001[o00<0ool0bol200go0P1_o`006_l00`3oo`3=o`802ol206oo000Jo`030?oo0;Go
0P0Fo`802Ol2077o000Jo`80C?l206So0P0Ho`801_l3077o000Jo`030?oo04_o0P1>o`80<_l:07;o
000Jo`030?oo08ko0P0;o`80<ol707Co000Jo`030?oo08ko0P2ko`006_l00`3oo`2co`80U_l0017o
0`06o`030?oo0;?o0P2Fo`004?l01@3oool000Go00<0ool0J_l2037o0P2/o`004?l01@3oool000Go
00<0ool0J_l2037o0P0Co`80Uol000Oo1P03o`050?ooo`001Ol30;;o0P2Go`004?l400Ko00<0ool0
oom<o`004?l00`3oo`07o`030?oo073o0P0Ko`804?l200oo0P2Io`004Ol00`3oo`06o`030?oo073o
0P0Ko`804?l200oo0P2Io`004_l300Go00<0ool0oom<o`006_l00`3oo`2Po`803Ol209[o000Jo`03
0?oo0:3o0P0=o`80V_l001[o00<0ool0X_l200Wo0P2Lo`006_l00`3oo`2Ro`<01_l409co000Jo`80
S?l201Ko1003o`<0W_l001[o00<0ool0Rol201So1`2Oo`006_l00`3oo`1bo`80<ol30:7o000Jo`03
0?oo07;o0P3Go`006_l00`3oo`1Xo`80hOl001[o00<0ool0J?l2023o0P2oo`006_l00`3oo`2:o`80
_ol001[o00<0ool0oom<o`006_l20?ooCOl001[o00<0ool0Lol201?o0P31o`006_l00`3oo`1co`80
4ol20<7o000Jo`030?oo0?ooC?l001[o00<0ool0oom<o`006_l00`3oo`26o`80`ol001[o00<0ool0
COl202Ko0P0?o`80`ol001[o00<0ool0COl201Oo0P0=o`80e?l001[o00<0ool0I_l201go0P34o`00
6_l207Oo0P0=o`80a?l001[o00<0ool0BOl202_o0P0;o`80a_l001[o00<0ool0BOl202go0P09o`80
a_l001[o00<0ool0N?l200So0P37o`006_l00`3oo`1jo`801?l40<Oo000Jo`030?oo07[o2039o`00
4_l300Go00<0ool0IOl201Co1@3;o`004ol00`3oo`04o`030?oo06Go0P3To`004ol00`3oo`04o`03
0?oo0?ooC?l000Oo1P02o`H01Ol30?ooC?l0013o00@0ool01_l00`3oo`3oodco000@o`040?oo00Ko
00<0ool0oom<o`004Ol00`3o0006o`030?oo0?ooC?l001;o0P06o`030?oo06?o0P3Vo`006_l00`3o
o`1>o`804ol20>Ko000Jo`030?oo04ko0P3ko`006_l00`3oo`3oodco000Jo`80oom=o`006_l00`3o
o`1Ro`80iol001[o00<0ool0H_l20>Oo000Jo`030?oo0?ooC?l001[o00<0ool0oom<o`006_l00`3o
o`3oodco000Jo`030?oo053o0P0>o`80jOl001[o00<0ool0D?l200ko0P3Yo`006_l00`3oo`3oodco
000Jo`80BOl20?oo0_l001[o00<0ool0B?l201Co0P3[o`006_l00`3oo`1No`80jol001[o00<0ool0
DOl200[o0P3/o`006_l00`3oo`1Ao`802_l20>co000Jo`030?oo0?ooC?l001[o00<0ool0Dol200Ko
0P3^o`006_l00`3oo`1Co`801Ol30>ko000Jo`80E_l70>oo000Jo`030?oo05Go1@3ao`006_l00`3o
o`3oodco000Jo`030?oo0?ooC?l001[o00<0ool0oom<o`006_l00`3oo`3oodco000?o`D01_l00`3o
o`3oodco000?o`050?ooo`001_l00`3oo`3oodco000@o`030?oo00Oo00<0ool0A_l20?oo1?l000Oo
1P04o`030?oo00Ko0`16o`80ool4o`004_l00`3oo`05o`030?oo0?ooC?l001?o00<0ool01?l00`3o
o`3oodco000?o`050?ooo`001_l00`3oo`3oodco000@o`<01ol00`3oo`3oodco000Jo`030?oo0?oo
C?l001[o00<0ool0oom<o`006_l00`3oo`3oodco000Jo`80oom=o`006_l00`3oo`15o`80ool5o`00
6_l00`3oo`15o`80ool5o`006_l00`3oo`3oodco000Jo`030?oo0?ooC?l001[o00<0ool0oom<o`00
6_l00`3oo`3oodco000Jo`030?oo0?ooC?l001[o00<0ool0oom<o`006_l204Co0P3oo`Oo000Jo`03
0?oo04?o0P3oo`Oo000Jo`030?oo04Oo1004o`@0@Ol500?o1004o`@0??l500?o1004o`@0>ol500Co
1004o`@00ol001[o00<0ool0A_l00`3oo`02o`040?oo00Co00<0ool0@?l00`3oo`02o`030?oo00;o
00@0ool01?l00`3oo`0ko`030?oo00;o00<0ool00_l0103oo`04o`030?oo03So00D0oooo0003o`03
0?oo00;o00@0ool01?l1007o0Ol001[o00<0ool0Bol0103oo`04o`030?oo043o00<0ool00_l00`3o
o`02o`040?oo00Co00<0ool0>ol00`3oo`07o`040?oo00Co00<0ool0>Ol00`3oo`04o`030?oo00;o
00@0ool01?l1007o0Ol001[o00<0ool0@Ol200So00@0ool01?l00`3oo`10o`030?oo00;o00<0ool0
0_l0103oo`04o`030?oo03_o00<0ool01ol0103oo`04o`030?oo03[o00<0ool00ol00`3oo`02o`04
0?oo00Co0@01o`7o000Jo`030?oo047o0P04o`@00ol00`3oo`02o`030?oo043o00<0ool00_l00`3o
o`02o`040?oo00Co00<0ool0>ol00`3oo`03o`@00ol00`3oo`02o`030?oo03_o00<0ool00_l00`3o
o`02o`040?oo00Co0@01o`7o000Jo`030?oo04Oo00<0ool01?l00`3oo`02o`030?oo043o00<0ool0
0_l00`3oo`02o`040?oo00Co00<0ool0>ol00`3oo`03o`030?oo00Co00<0ool00_l00`3oo`0lo`05
0?ooo`001?l0103oo`04o`400Ol1o`006_l204So00<0ool01?l00`3oo`02o`030?oo03ko0`04o`03
0?oo00;o00@0ool01?l00`3oo`0io`<01Ol00`3oo`04o`030?oo00;o00<0ool0>?l01@3oool000?o
00<0ool00_l0103oo`04o`400Ol1o`006_l00`3oo`10o`801Ol500?o1013o`030?oo00?o1004o`@0
?_l00`3oo`03o`D00ol403co0`05o`@01?l400?o000Jo`030?oo043o0P3oo`[o000Jo`030?oo03ko
0P3oo`co000Jo`030?oo03ko0P3oo`co000Jo`030?oo03go0P3oo`go000Jo`030?oo03_o103oo`go
000Jo`030?oo03So1@3oo`oo000Jo`030?oo033o2`3ooa7o000Bool0D`04o`006_lc00go00<0ool0
3Ol00`3oo`0>o`030?oo00go00<0ool03Ol00`3oo`0=o`030?oo00go00<0ool03Ol00`3oo`0=o`03
0?oo00go00<0ool03Ol00`3oo`0=o`030?oo00go00<0ool03Ol00`3oo`0=o`030?oo00go00<0ool0
3Ol00`3oo`0:o`006_l00`3oo`1=o`030?oo04ko00<0ool0COl00`3oo`1=o`030?oo00[o000Jo`03
0?oo0?ooC?l001[o00<0ool0oom<o`006_l00`3oo`3oodco003oofWo003oofWo003oofWo003oofWo
003oofWo003oofWo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-16.6432, -12.2631, \
0.778736, 0.0730318}}],

Cell[BoxData[
    \({1.9799999999999969`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\(ReflecNPCompiled[angles_, 
        lambda_]\)\(:=\)\(\ \)\(Module[\[IndentingNewLine]{l, \ k, \ f1, \ 
          kp, \ q0, \ DD, \ P, \ T, R, \ 
          M = {{0, 0}, {0, 0}}}, \[IndentingNewLine]l = 
          lambda*10^\(-9\); \  (*\ passage\ en\ SI\ *) \[IndentingNewLine]k = 
          2*Pi/l; \  (*\ moment\ du\ neutron\ *) \[IndentingNewLine]T = {}; 
        R = {}; \[IndentingNewLine]\[IndentingNewLine]Do[\ 
          f1 = angles[\([i]\)]*Pi/180; \  (*\ 
            passage\ en\ degr\[EAcute]s\ *) \[IndentingNewLine]\t
          kp\  = \ k*Cos[f1]; \  (*\ 
            composante\ planaire\ *) \[IndentingNewLine]\t
          q0\  = \ k*Sin[f1]; \ \  (*\ 
            composante\ perpendiculaire\ *) \[IndentingNewLine]\t
          nbrLayers\  = \ \(Dimensions[z]\)[\([1]\)]; \[IndentingNewLine]\t
          Eq = hb*hb*q0*\(q0/2\)/mn*
              Table[1, {nbrLayers}]; \ \[IndentingNewLine]\t (*\ 
            energy\ cinetique\ perpendiculaire\ dans\ chaque\ couche\ \
*) \[IndentingNewLine]\t
          q = \((2*
                  mn*\((Eq - V)\)/\((hb*
                        hb)\))\)^0.5; \ \[IndentingNewLine]\t (*\ \(Print[f1, 
                kp, q0, nbrLayers, Eq, "\<  \>", 
                q];\)\ *) \[IndentingNewLine]\t (*\ 
            perpendicular\ wavevector\ in\ each\ layer\ \
*) \[IndentingNewLine]\t
          Do[\ \ M = 
              Iteration[k, nbrLayers, q[\([k]\)], z[\([k]\)], 
                M]\[IndentingNewLine]\t, {k, 
              nbrLayers}\[IndentingNewLine]\t]; \[IndentingNewLine]\t
          AppendTo[T, Abs[1/M[\([1, 1]\)]]^2]; \[IndentingNewLine]\t
          AppendTo[R, 
            Abs[M[\([2, 1]\)]/
                  M[\([1, 1]\)]]^2\ ]\ \[IndentingNewLine], {i, \(Dimensions[
                angles]\)[\([1]\)]}\[IndentingNewLine]]; \[IndentingNewLine] \
(*\ \(ListPlot[
              Log[R]];\)\ \
*) \[IndentingNewLine]]\)\(\[IndentingNewLine]\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ReflecNPCompiled[angles, 0.4];\)\  // Timing\)], "Input"],

Cell[BoxData[
    \({1.430000000000291`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\(Iteration2 = 
        Compile[{{nbrLayers, \ _Integer}, {q, _Complex, 1}, {z, _Real, 
              1}}, \[IndentingNewLine]Module[{DD = {\ {I, 0}, {0, 0}}, 
              P = {\ {I, 0}, \ {\ 0, 0\ }}, \ 
              M = {{I, 0}, {0, 0}}}, \ \[IndentingNewLine]Do[ (*\ 
                initialisation\ of\ the\ D\ matrix\ *) \[IndentingNewLine]\t
              DD = {\ {1, 
                    1}, {q[\([k]\)], \(-q[\([k]\)]\)}}; \[IndentingNewLine]\t \
(*\ initialisation\ of\ the\ propagation\ matrix\ *) \[IndentingNewLine]\t
              P = {\ {\ Exp[\(-I\)*q[\([k]\)]*z[\([k]\)]\ ], 0}, \ {\ 0, 
                    Exp[I*q[\([k]\)]*z[\([k]\)]]\ }}; \[IndentingNewLine]\t
              If[\ k \[Equal] 1, 
                M = N[Inverse[DD]], \[IndentingNewLine]\t\t\tIf[\ 
                  k \[Equal] nbrLayers, M = N[M . DD], 
                  M = N[M . DD . P . 
                        Inverse[DD]]]];\[IndentingNewLine]\t, {k, 
                nbrLayers}\[IndentingNewLine]\t]; \[IndentingNewLine]\t
            M\[IndentingNewLine]]\[IndentingNewLine]];\)\(\[IndentingNewLine]\
\)\)\)], "Input"],

Cell[BoxData[
    \(\(\(ReflecNPCompiled2[angles_, 
        lambda_]\)\(:=\)\(\ \)\(Module[\[IndentingNewLine]{l, \ k, \ f1, \ 
          kp, \ q0, \ DD, \ P, \ T, R, \ 
          M = {{I, 0}, {0, 0}}}, \[IndentingNewLine]l = 
          lambda*10^\(-9\); \  (*\ passage\ en\ SI\ *) \[IndentingNewLine]k = 
          2*Pi/l; \  (*\ moment\ du\ neutron\ *) \[IndentingNewLine]T = {}; \ 
        R = {}; \[IndentingNewLine]Do[\ 
          f1 = angles[\([i]\)]*Pi/180; \  (*\ 
            passage\ en\ degr\[EAcute]s\ *) \[IndentingNewLine]\t
          kp\  = \ k*Cos[f1]; \  (*\ 
            composante\ planaire\ *) \[IndentingNewLine]\t
          q0\  = \ k*Sin[f1]; \ \  (*\ 
            composante\ perpendiculaire\ *) \[IndentingNewLine]\t
          nbrLayers\  = \ \(Dimensions[z]\)[\([1]\)]; \[IndentingNewLine]\t
          Eq = hb*hb*q0*\(q0/2\)/mn*
              Table[1, {nbrLayers}]; \ \[IndentingNewLine]\t (*\ 
            energy\ cinetique\ perpendiculaire\ dans\ chaque\ couche\ \
*) \[IndentingNewLine]\t
          q = \((2*
                  mn*\((Eq - V)\)/\((hb*
                        hb)\))\)^0.5; \ \[IndentingNewLine]\t (*\ \(Print[f1, 
                kp, q0, nbrLayers, Eq, "\<  \>", 
                q];\)\ *) \[IndentingNewLine]\t (*\ 
            perpendicular\ wavevector\ in\ each\ layer\ \
*) \[IndentingNewLine]\tM = Iteration2[nbrLayers, q, z]; \[IndentingNewLine]\t
          AppendTo[T, Abs[1/M[\([1, 1]\)]]^2]; \[IndentingNewLine]\t
          AppendTo[R, 
            Abs[M[\([2, 1]\)]/
                  M[\([1, 1]\)]]^2\ ]\ \[IndentingNewLine], {i, \(Dimensions[
                angles]\)[\([1]\)]}\[IndentingNewLine]]; \[IndentingNewLine]\ \
\ ListPlot[
          Log[10, R]];\ \[IndentingNewLine]]\)\(\[IndentingNewLine]\)\)\)], \
"Input"],

Cell[BoxData[
    \(\[AliasDelimiter]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ReflecNPCompiled2[angles, 0.4];\)\  // Timing\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.603319 0.116916 [
[.2619 .59082 -6 -9 ]
[.2619 .59082 6 0 ]
[.5 .59082 -9 -9 ]
[.5 .59082 9 0 ]
[.7381 .59082 -9 -9 ]
[.7381 .59082 9 0 ]
[.97619 .59082 -9 -9 ]
[.97619 .59082 9 0 ]
[.01131 .01874 -12 -4.5 ]
[.01131 .01874 0 4.5 ]
[.01131 .13565 -12 -4.5 ]
[.01131 .13565 0 4.5 ]
[.01131 .25257 -12 -4.5 ]
[.01131 .25257 0 4.5 ]
[.01131 .36949 -12 -4.5 ]
[.01131 .36949 0 4.5 ]
[.01131 .4864 -12 -4.5 ]
[.01131 .4864 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .60332 m
.2619 .60957 L
s
[(50)] .2619 .59082 0 1 Mshowa
.5 .60332 m
.5 .60957 L
s
[(100)] .5 .59082 0 1 Mshowa
.7381 .60332 m
.7381 .60957 L
s
[(150)] .7381 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(200)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.21429 .60332 m
.21429 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.40476 .60332 m
.40476 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.59524 .60332 m
.59524 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.78571 .60332 m
.78571 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .01874 m
.03006 .01874 L
s
[(-5)] .01131 .01874 1 0 Mshowa
.02381 .13565 m
.03006 .13565 L
s
[(-4)] .01131 .13565 1 0 Mshowa
.02381 .25257 m
.03006 .25257 L
s
[(-3)] .01131 .25257 1 0 Mshowa
.02381 .36949 m
.03006 .36949 L
s
[(-2)] .01131 .36949 1 0 Mshowa
.02381 .4864 m
.03006 .4864 L
s
[(-1)] .01131 .4864 1 0 Mshowa
.125 Mabswid
.02381 .04212 m
.02756 .04212 L
s
.02381 .06551 m
.02756 .06551 L
s
.02381 .08889 m
.02756 .08889 L
s
.02381 .11227 m
.02756 .11227 L
s
.02381 .15904 m
.02756 .15904 L
s
.02381 .18242 m
.02756 .18242 L
s
.02381 .2058 m
.02756 .2058 L
s
.02381 .22919 m
.02756 .22919 L
s
.02381 .27595 m
.02756 .27595 L
s
.02381 .29934 m
.02756 .29934 L
s
.02381 .32272 m
.02756 .32272 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39287 m
.02756 .39287 L
s
.02381 .41625 m
.02756 .41625 L
s
.02381 .43964 m
.02756 .43964 L
s
.02381 .46302 m
.02756 .46302 L
s
.02381 .50979 m
.02756 .50979 L
s
.02381 .53317 m
.02756 .53317 L
s
.02381 .55655 m
.02756 .55655 L
s
.02381 .57994 m
.02756 .57994 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .60332 Mdot
.03333 .60332 Mdot
.0381 .60332 Mdot
.04286 .60332 Mdot
.04762 .60332 Mdot
.05238 .60332 Mdot
.05714 .60332 Mdot
.0619 .60332 Mdot
.06667 .60332 Mdot
.07143 .60332 Mdot
.07619 .60332 Mdot
.08095 .60332 Mdot
.08571 .60332 Mdot
.09048 .60332 Mdot
.09524 .60332 Mdot
.1 .60332 Mdot
.10476 .60332 Mdot
.10952 .60332 Mdot
.11429 .6033 Mdot
.11905 .60328 Mdot
.12381 .60326 Mdot
.12857 .60323 Mdot
.13333 .60321 Mdot
.1381 .60317 Mdot
.14286 .60313 Mdot
.14762 .60307 Mdot
.15238 .603 Mdot
.15714 .60291 Mdot
.1619 .6028 Mdot
.16667 .60265 Mdot
.17143 .60246 Mdot
.17619 .6022 Mdot
.18095 .60186 Mdot
.18571 .60141 Mdot
.19048 .60079 Mdot
.19524 .59994 Mdot
.2 .59875 Mdot
.20476 .59708 Mdot
.20952 .5947 Mdot
.21429 .59126 Mdot
.21905 .58625 Mdot
.22381 .57893 Mdot
.22857 .56824 Mdot
.23333 .55274 Mdot
.2381 .53052 Mdot
.24286 .49885 Mdot
.24762 .45262 Mdot
.25238 .37792 Mdot
.25714 .27451 Mdot
.2619 .36713 Mdot
.26667 .41809 Mdot
.27143 .44509 Mdot
.27619 .46091 Mdot
.28095 .47027 Mdot
.28571 .47536 Mdot
.29048 .47733 Mdot
.29524 .47681 Mdot
.3 .47414 Mdot
.30476 .46948 Mdot
.30952 .46288 Mdot
.31429 .45428 Mdot
.31905 .44349 Mdot
.32381 .43024 Mdot
.32857 .41403 Mdot
.33333 .39412 Mdot
.3381 .3692 Mdot
.34286 .33697 Mdot
.34762 .29289 Mdot
.35238 .23077 Mdot
.35714 .20406 Mdot
.3619 .26003 Mdot
.36667 .30285 Mdot
.37143 .3312 Mdot
.37619 .35092 Mdot
.38095 .36504 Mdot
.38571 .3752 Mdot
.39048 .38236 Mdot
.39524 .3871 Mdot
.4 .3898 Mdot
.40476 .39072 Mdot
.40952 .39 Mdot
.41429 .38774 Mdot
.41905 .38396 Mdot
.42381 .37866 Mdot
.42857 .37176 Mdot
.43333 .36312 Mdot
.4381 .35256 Mdot
.44286 .33974 Mdot
.44762 .32419 Mdot
.45238 .30516 Mdot
.45714 .28142 Mdot
.4619 .25085 Mdot
.46667 .20982 Mdot
.47143 .15658 Mdot
.47619 .13934 Mdot
.48095 .18612 Mdot
.48571 .22668 Mdot
.49048 .25532 Mdot
.49524 .27611 Mdot
.5 .29164 Mdot
.50476 .30338 Mdot
.50952 .31222 Mdot
.51429 .31873 Mdot
.51905 .32326 Mdot
.52381 .32609 Mdot
.52857 .32736 Mdot
.53333 .32718 Mdot
.5381 .32562 Mdot
.54286 .32269 Mdot
.54762 .31837 Mdot
.55238 .31261 Mdot
.55714 .30528 Mdot
.5619 .29624 Mdot
.56667 .28522 Mdot
.57143 .27186 Mdot
.57619 .2556 Mdot
.58095 .23555 Mdot
.58571 .21026 Mdot
.59048 .1773 Mdot
.59524 .1333 Mdot
.6 .08742 Mdot
.60476 .10238 Mdot
.60952 .14789 Mdot
.61429 .18301 Mdot
.61905 .20855 Mdot
.62381 .22765 Mdot
.62857 .24227 Mdot
.63333 .25355 Mdot
.6381 .26223 Mdot
.64286 .26877 Mdot
.64762 .27348 Mdot
.65238 .27658 Mdot
.65714 .27822 Mdot
.6619 .27848 Mdot
.66667 .27742 Mdot
.67143 .27506 Mdot
.67619 .27138 Mdot
.68095 .26632 Mdot
.68571 .25978 Mdot
.69048 .25163 Mdot
.69524 .24164 Mdot
.7 .2295 Mdot
.70476 .21473 Mdot
.70952 .19658 Mdot
.71429 .1739 Mdot
.71905 .14474 Mdot
.72381 .10612 Mdot
.72857 .05879 Mdot
.73333 .04614 Mdot
.7381 .08807 Mdot
.74286 .12722 Mdot
.74762 .15605 Mdot
.75238 .17758 Mdot
.75714 .19408 Mdot
.7619 .20692 Mdot
.76667 .21694 Mdot
.77143 .2247 Mdot
.77619 .23054 Mdot
.78095 .23472 Mdot
.78571 .23741 Mdot
.79048 .23871 Mdot
.79524 .23871 Mdot
.8 .23743 Mdot
.80476 .23487 Mdot
.80952 .23101 Mdot
.81429 .22578 Mdot
.81905 .21906 Mdot
.82381 .21071 Mdot
.82857 .20048 Mdot
.83333 .18802 Mdot
.8381 .17282 Mdot
.84286 .15406 Mdot
.84762 .13048 Mdot
.85238 .09995 Mdot
.85714 .05958 Mdot
.8619 .01472 Mdot
.86667 .01787 Mdot
.87143 .06136 Mdot
.87619 .09802 Mdot
.88095 .12515 Mdot
.88571 .14566 Mdot
.89048 .16152 Mdot
.89524 .17397 Mdot
.9 .18375 Mdot
.90476 .19136 Mdot
.90952 .19713 Mdot
.91429 .2013 Mdot
.91905 .20401 Mdot
.92381 .20537 Mdot
.92857 .20545 Mdot
.93333 .20427 Mdot
.9381 .20183 Mdot
.94286 .19811 Mdot
.94762 .19302 Mdot
.95238 .18648 Mdot
.95714 .17831 Mdot
.9619 .16828 Mdot
.96667 .15604 Mdot
.97143 .14109 Mdot
.97619 .12264 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gPP10`40000100000800002008200000
P800P020P<30`8f9HL:oYL3L`:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV
09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000
<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI
<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0
I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<
IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHc
VITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<
VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01V
c3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Ko
c9Woc<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2I
oc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D5
1@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5?okl0000000000000000000
00000>7PdZ2PY820P?l0003o0?oo0000ool0o`3oooooooooJOl00?ooJOl00?ooJOl00?ooJOl001?o
00<0ool0oomCo`004ol00`3oo`3ooe?o000Co`030?oo0?ooDol001?o00<0ool0oomCo`002Ol400Ko
00<0ool0oomCo`002?l00`3oo`02o`030?oo00?o00<0ool0oolNo`80<ol000go00<0ool00ol00`3o
o`3ooako100ao`001P07o`030?oo00?o0`3oob3o0P0ao`002Ol400Ko00<0ool0oomCo`002Ol00`3o
o`07o`030?oo0?ooDol000Wo00<0ool01ol00`3oo`3ooe?o0009o`D01Ol00`3oo`3ooe?o000Co`03
0?oo0?ooDol001?o00<0ool0oomCo`004ol00`3oo`3ooe?o000Co`80oomDo`004ol00`3oo`3ao`80
Gol001?o00<0ool0lOl205oo000Co`030?oo0?ooDol001?o00<0ool0oomCo`004ol00`3oo`3_o`80
HOl001?o00<0ool0kol202[o0P03o`80<?l001?o00<0ool0oolLo`800ol2033o000Co`80oomDo`00
4ol00`3oo`3ooe?o000Co`030?oo0?ooDol001?o00<0ool0oomCo`004ol00`3oo`3ooe?o000Co`03
0?oo0?ooDol001?o00<0ool0oomCo`004ol00`3oo`33o`80;Ol205ko000Co`80a?l202go0P1No`00
4ol00`3oo`3ooe?o000Co`030?oo0?ooDol001?o00<0ool0oolSo`80;_l001?o00<0ool0a?l205Co
0P06o`80;_l001?o00<0ool0a?l205Co0P0fo`004ol00`3oo`3]o`80Hol001?o00<0ool0kOl206?o
000Co`80oomDo`004ol00`3oo`3ooe?o000Co`030?oo0?ooDol001?o00<0ool0oom5o`803?l001?o
00<0ool0oolUo`807_l200co000;o`<01Ol00`3oo`3do`80;_l202co000<o`030?oo00Co00<0ool0
m?l202;o0P0ho`003?l00`3oo`04o`030?oo0<7o0P1Eo`80>?l000H00_l600Go0`31o`80Sol000Wo
00@0ool01_l00`3oo`2Ho`80^?l000Wo00@0ool01_l00`3oo`2Ho`80ZOl200go000:o`030?l000Ko
00<0ool0k?l203Oo0P0Lo`803Ol000_o0P06o`030?oo0<Ko0P0To`80=ol202_o000Co`030?oo0<Ko
0P2:o`004ol00`3oo`3ooaOo0P0jo`004ol00`3oo`2Fo`80G_l201ko0P0Yo`803ol001?o0P2Go`80
G_l204Wo0P0?o`004ol00`3oo`3oobSo0P0Yo`004ol00`3oo`3oobSo0P0Yo`004ol00`3oo`3ood3o
0P0Ao`004ol00`3oo`3ood3o0P0Ao`004ol00`3oo`3Zo`80:Ol2017o0P0Xo`004ol00`3oo`2oo`80
:Ol200_o0P0Lo`804Ol202So000Co`030?oo0;oo0P0fo`80AOl201;o000Co`80bOl2063o0P0Bo`80
4_l001?o00<0ool0V_l202co0P1Po`804?l201Co000Co`030?oo09[o0P1go`809ol201Co000Co`03
0?oo0?oo5?l201Oo0P0To`004ol00`3oo`3io`80<Ol200go0P0Eo`004ol00`3oo`3Xo`803ol203;o
0P0:o`@05Ol001?o00<0ool0j?l202Oo0P0Jo`802_l201Oo000Co`030?oo06oo0P2Po`807?l400Co
0P0Io`004ol2073o0P29o`80<ol:01Wo000Co`030?oo09Go0P0bo`80;ol203Ko1P0Jo`004ol00`3o
o`2Eo`809ol200Wo0P15o`80@?l001?o00<0ool0__l202Oo0P0Wo`80@?l001?o00<0ool0iol201?o
0P1Do`004ol00`3oo`3lo`804?l204;o000Co`030?oo0?oo3ol204;o000Co`030?oo09_o0P1Qo`80
3Ol204?o000Co`80W?l202ko0P0Ho`805ol200go0P13o`004ol00`3oo`1]o`80G?l201So0P0Ho`80
2_l204Go000Co`030?oo06go0P1=o`80@Ol400Ko1015o`004ol00`3oo`2lo`80@ol:04Oo000Co`03
0?oo0>?o0P0No`L0B?l000Wo0`07o`030?oo0<co0P0Eo`80KOl000So00D0oooo0006o`030?oo0<co
0P24o`003?l00`3oo`04o`030?oo0?ooDol000H01_l00`3oo`04o`<0Tol204go0P1^o`002_l200Oo
00<0ool0Tol200So0P0Ko`804_l201;o0P1^o`003?l00`3oo`04o`030?oo09go0P0Ko`804_l208;o
0008o`050?ooo`001_l00`3oo`1ao`80KOl2073o0009o`<01ol00`3oo`1ao`80GOl200ko0P1`o`00
4ol00`3oo`3@o`803Ol2077o000Co`030?oo0=7o0P0<o`80LOl001?o00<0ool0^Ol201Ko1008o`80
Lol001?o0P1=o`80DOl201So0P0Ho`801_l407?o000Co`030?oo04co0P1Ao`80=?l807Go000Co`03
0?oo097o0P12o`L0M_l001?o00<0ool0TOl202Co0P2Io`004ol00`3oo`2go`80VOl001?o00<0ool0
oomCo`004ol00`3oo`1/o`80<_l20;3o000Co`030?oo06co0P0bo`805?l209[o000Co`80]ol209[o
000Co`030?oo0?ooDol001?o00<0ool0L_l201co0P0@o`804?l209co000Co`030?oo07;o0P0Lo`80
4?l2013o0P2Lo`004ol00`3oo`3ooe?o000Co`030?oo0:?o0P0=o`80W_l001?o00<0ool0Xol200go
0P2No`004ol00`3oo`2Uo`802_l209oo000Co`030?oo0:Go0P08o`@0Wol001?o0P2?o`805ol200Co
102Qo`004ol00`3oo`2>o`805ol80:?o000Co`030?oo07Co0P0bo`H0Y?l001?o00<0ool0M?l20=co
000Co`030?oo06[o0P3Vo`004ol00`3oo`1Zo`808?l20<Co000Co`030?oo08co0P34o`004ol00`3o
o`3ooe?o000Co`80oomDo`004ol00`3oo`1eo`80fol001?o00<0ool0MOl201Co0P35o`004ol00`3o
o`2;o`80aOl001?o00<0ool0oomCo`002?l500Ko00<0ool0ROl20<Oo0008o`050?ooo`001_l00`3o
o`1go`804?l20<Oo0009o`030?oo00Oo00<0ool0C_l201So0P0=o`80fOl000H01?l00`3oo`06o`<0
C_l201So0P0No`80b?l000_o00<0ool01Ol00`3oo`28o`80b?l000co00<0ool01?l00`3oo`1;o`80
;?l20=Oo0008o`050?ooo`001_l00`3oo`1;o`80;?l200_o0P3:o`002Ol300Oo00<0ool0N_l200[o
0P3:o`004ol00`3oo`1jo`802?l20<co000Co`030?oo07co0P05o`<0c?l001?o00<0ool0O?l90<go
000Co`80J?l201Go1@3?o`004ol00`3oo`1Wo`80jOl001?o00<0ool0oomCo`004ol00`3oo`3ooe?o
000Co`030?oo0?ooDol001?o00<0ool0oomCo`004ol00`3oo`3ooe?o000Co`030?oo06Go0P3[o`00
4ol2057o0P0Co`80jol001?o00<0ool0D?l20?oo0Ol001?o00<0ool0oomCo`004ol00`3oo`3ooe?o
000Co`030?oo06?o0P3]o`004ol00`3oo`1So`80kOl001?o00<0ool0oomCo`004ol00`3oo`3ooe?o
000Co`80oomDo`004ol00`3oo`1Ro`80k_l001?o00<0ool0DOl200oo0P3^o`004ol00`3oo`1Ao`80
ool001?o00<0ool0BOl20?oo2?l001?o00<0ool0BOl201Go0P3`o`004ol00`3oo`1Po`80l?l001?o
00<0ool0Dol20?go000Co`80E?l200Wo0P3bo`004ol00`3oo`1No`80l_l001?o00<0ool0EOl200Ko
0P3co`004ol00`3oo`1Eo`801_l20??o000Co`030?oo05Ko0P03o`80mOl000Wo1@05o`030?oo05Ko
1`3eo`002ol00`3oo`05o`030?oo05So103fo`002ol00`3oo`05o`030?oo0?ooDol000H01Ol00`3o
o`05o`<0oomCo`002ol00`3oo`05o`030?oo0?ooDol000_o00<0ool01Ol00`3oo`3ooe?o0009o`<0
1ol00`3oo`3ooe?o000;o`030?oo00Go00<0ool0Aol20?oo2_l001?o00<0ool0Aol20?oo2_l001?o
00<0ool0oomCo`004ol00`3oo`3ooe?o000Co`80oomDo`004ol00`3oo`3ooe?o000Co`030?oo0?oo
Dol001?o00<0ool0oomCo`004ol00`3oo`3ooe?o000Co`030?oo0?ooDol001?o00<0ool0oomCo`00
4ol00`3oo`16o`80ool;o`004ol204Oo0P3oo`_o000Co`030?oo0?ooDol001?o00<0ool0oomCo`00
4ol00`3oo`3ooe?o000Co`030?oo0?ooDol001?o00<0ool0oomCo`004ol00`3oo`3ooe?o000Co`03
0?oo04Co0P3oo`go000Co`80AOl20?oo3Ol001?o00<0ool0BOl400Co1012o`D00ol400Co100no`D0
0ol400Co100mo`D01?l400Co1003o`004ol00`3oo`18o`030?oo00;o00@0ool01?l00`3oo`11o`03
0?oo00;o00<0ool00_l0103oo`04o`030?oo03go00<0ool00_l00`3oo`02o`040?oo00Co00<0ool0
>_l01@3oool000?o00<0ool00_l0103oo`04o`400Ol1o`004ol00`3oo`1=o`040?oo00Co00<0ool0
@Ol00`3oo`02o`030?oo00;o00@0ool01?l00`3oo`0mo`030?oo00Oo00@0ool01?l00`3oo`0ko`03
0?oo00Co00<0ool00_l0103oo`04o`400Ol1o`004ol00`3oo`13o`802?l0103oo`04o`030?oo047o
00<0ool00_l00`3oo`02o`040?oo00Co00<0ool0?Ol00`3oo`07o`040?oo00Co00<0ool0??l00`3o
o`03o`030?oo00;o00@0ool01?l1007o0Ol001?o00<0ool0@ol200Co1003o`030?oo00;o00<0ool0
@Ol00`3oo`02o`030?oo00;o00@0ool01?l00`3oo`0mo`030?oo00?o1003o`030?oo00;o00<0ool0
?Ol00`3oo`02o`030?oo00;o00@0ool01?l1007o0Ol001?o00<0ool0BOl00`3oo`04o`030?oo00;o
00<0ool0@Ol00`3oo`02o`030?oo00;o00@0ool01?l00`3oo`0mo`030?oo00?o00<0ool01?l00`3o
o`02o`030?oo03ko00D0oooo0004o`040?oo00Co0@01o`7o000Co`030?oo04Wo00<0ool01?l00`3o
o`02o`030?oo03oo0`04o`030?oo00;o00@0ool01?l00`3oo`0ko`<01Ol00`3oo`04o`030?oo00;o
00<0ool0>_l01@3oool000?o00<0ool00_l0103oo`04o`400Ol1o`004ol204;o0P06o`D00ol404Co
00<0ool00ol400Co1010o`030?oo00?o1@03o`@0?_l300Go1004o`@00ol001?o00<0ool0@Ol20?oo
4?l001?o00<0ool0?ol20?oo4_l001?o00<0ool0?ol20?oo4_l001?o00<0ool0?_l20?oo4ol001?o
00<0ool0??l40?oo4ol001?o00<0ool0>_l40?oo5Ol001?o00<0ool0=Ol70?oo5ol000_oo`1J00Co
000CocT02Ol00`3oo`0=o`030?oo00go00<0ool03_l00`3oo`0=o`030?oo00ko00<0ool03Ol00`3o
o`0=o`030?oo00ko00<0ool03Ol00`3oo`0>o`030?oo00go00<0ool03_l00`3oo`0=o`030?oo00go
00<0ool03_l00`3oo`0=o`030?oo00[o000Co`030?oo00go00<0ool03_l00`3oo`0=o`030?oo00ko
00<0ool03Ol00`3oo`0=o`030?oo00ko00<0ool03Ol00`3oo`0>o`030?oo00go00<0ool03Ol00`3o
o`0>o`030?oo00go00<0ool03_l00`3oo`0=o`030?oo00ko00<0ool03Ol00`3oo`0=o`030?oo00ko
00<0ool03Ol00`3oo`0:o`004ol00`3oo`3ooe?o000Co`030?oo0?ooDol001?o00<0ool0oomCo`00
oomYo`00oomYo`00oomYo`00oomYo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-11.7601, -5.26249, \
0.761183, 0.0310024}}],

Cell[BoxData[
    \({1.3699999999998909`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(ReflecNPCompiled3 = 
        Compile[\[IndentingNewLine]{{\ 
              lambda, \ _Real}, \ {angles, \ _Real, \ 1}, \ {z, _Real, 
              1}, \ {V, \ _Complex, 
              1}}, \[IndentingNewLine]Module[\[IndentingNewLine]{\ 
              hb2over2mn, \ aux, nbrLayers, nbrPoints, 
              k, \ \ \[IndentingNewLine]q = {I}, \ qq, \ q0, \ Eq0, 
              Eq, \[IndentingNewLine]DD = {\ {I, 0}, {0, 0}}, 
              P = {\ {I, 0}, \ {\ 0, 0\ }}, \ M = {{I, 0}, {0, 0}}, \ R, \ 
              T}, \ \[IndentingNewLine]nbrLayers\  = \ \(Dimensions[
                  z]\)[\([1]\)]; \[IndentingNewLine]nbrPoints\  = \ \
\(Dimensions[angles]\)[\([1]\)]; \[IndentingNewLine]k = 
              2*Pi/\((lambda*10^\(-9\))\); \  (*\ 
              moment\ du\ neutron\ en\ SI\ *) \[IndentingNewLine]hb2over2mn = \
\(hb2/2\)/mn; \[IndentingNewLine]R = 
              Table[1.0, {nbrPoints}]; \[IndentingNewLine]T = 
              Table[1.0, {nbrPoints}]; \[IndentingNewLine]Eq0\  = \ 
              hb2over2mn*
                Table[1, {nbrLayers}]; \[IndentingNewLine]Do[\ \
\[IndentingNewLine]\t
              q0 = \ k*Sin[angles[\([i]\)]*Deg];  (*\ 
                comp . \ perp . \ du\ vecteur\ d' 
                  onde\ *) \[IndentingNewLine]\t
              Eq = q0*q0*Eq0; \  (*\ 
                energy\ cinetique\ perp . \ 
                    dans\ chaque\ couche\ *) \[IndentingNewLine]\t
              q = \((\((Eq - 
                          V)\)/\((hb2over2mn)\))\)^0.5; \ \ \
\[IndentingNewLine]\t (*\ 
                perp . \ 
                    wavevectors\ in\ each\ layer\ *) \[IndentingNewLine]\t
              Do[\ \[IndentingNewLine]\t\tqq = q[\([k]\)];  (*\ 
                  initialisation\ of\ the\ D\ matrix\ *) \[IndentingNewLine]\t\
\tDD = {\ {1, 1}, {qq, \(-qq\)}}; \[IndentingNewLine]\t\t (*\ 
                  initialisation\ of\ the\ propagation\ matrix\ \
*) \[IndentingNewLine]\t\taux = 
                  Exp[\(-I\)*qq*
                      z[\([k]\)]\ ]; \[IndentingNewLine]\t\tP = {\ {aux, 
                      0}, \ {\ 0, 1/aux\ }}; \[IndentingNewLine]\t\tIf[\ 
                  k \[Equal] 1, 
                  M = {\ {qq, 1}, {qq, \(-1\)}}/\((2*
                          qq)\), \[IndentingNewLine]\t\t\tIf[\ 
                    k \[Equal] nbrLayers, M = M . DD, 
                    M = M . {\ {1, 1}, {qq, \(-qq\)}} . 
                          P . {\ {qq, 1}, {qq, \(-1\)}}/\((2*
                            qq)\)]];\[IndentingNewLine]\t, {k, 
                  nbrLayers}\[IndentingNewLine]\t]; \[IndentingNewLine]\t
              T[\([i]\)] = \((1/Abs[M[\([1, 1]\)]])\)^2; \[IndentingNewLine]\t
              R[\([i]\)] = \((Abs[M[\([2, 1]\)]]/
                      Abs[M[\([1, 1]\)]])\)^2;\[IndentingNewLine], {i, 
                nbrPoints}\[IndentingNewLine]]; \[IndentingNewLine]ListPlot[
              Log[10, R]];\[IndentingNewLine]]\[IndentingNewLine]];\)\)], \
"Input"],

Cell[BoxData[
    \(\(angles = Table[i, {i, 0.01, 10, 0.01}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ReflecNPCompiled3[0.4, angles, z, \ V];\)\  // Timing\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000952381 0.603319 0.073291 [
[.21429 .59082 -9 -9 ]
[.21429 .59082 9 0 ]
[.40476 .59082 -9 -9 ]
[.40476 .59082 9 0 ]
[.59524 .59082 -9 -9 ]
[.59524 .59082 9 0 ]
[.78571 .59082 -9 -9 ]
[.78571 .59082 9 0 ]
[.97619 .59082 -12 -9 ]
[.97619 .59082 12 0 ]
[.01131 .01699 -12 -4.5 ]
[.01131 .01699 0 4.5 ]
[.01131 .16357 -12 -4.5 ]
[.01131 .16357 0 4.5 ]
[.01131 .31015 -12 -4.5 ]
[.01131 .31015 0 4.5 ]
[.01131 .45674 -12 -4.5 ]
[.01131 .45674 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .60332 m
.21429 .60957 L
s
[(200)] .21429 .59082 0 1 Mshowa
.40476 .60332 m
.40476 .60957 L
s
[(400)] .40476 .59082 0 1 Mshowa
.59524 .60332 m
.59524 .60957 L
s
[(600)] .59524 .59082 0 1 Mshowa
.78571 .60332 m
.78571 .60957 L
s
[(800)] .78571 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(1000)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.2619 .60332 m
.2619 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.5 .60332 m
.5 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.7381 .60332 m
.7381 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .01699 m
.03006 .01699 L
s
[(-8)] .01131 .01699 1 0 Mshowa
.02381 .16357 m
.03006 .16357 L
s
[(-6)] .01131 .16357 1 0 Mshowa
.02381 .31015 m
.03006 .31015 L
s
[(-4)] .01131 .31015 1 0 Mshowa
.02381 .45674 m
.03006 .45674 L
s
[(-2)] .01131 .45674 1 0 Mshowa
.125 Mabswid
.02381 .05364 m
.02756 .05364 L
s
.02381 .09028 m
.02756 .09028 L
s
.02381 .12693 m
.02756 .12693 L
s
.02381 .20022 m
.02756 .20022 L
s
.02381 .23686 m
.02756 .23686 L
s
.02381 .27351 m
.02756 .27351 L
s
.02381 .3468 m
.02756 .3468 L
s
.02381 .38345 m
.02756 .38345 L
s
.02381 .42009 m
.02756 .42009 L
s
.02381 .49338 m
.02756 .49338 L
s
.02381 .53003 m
.02756 .53003 L
s
.02381 .56667 m
.02756 .56667 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02476 .60332 Mdot
.02571 .60332 Mdot
.02667 .60332 Mdot
.02762 .60332 Mdot
.02857 .60332 Mdot
.02952 .60332 Mdot
.03048 .60332 Mdot
.03143 .60332 Mdot
.03238 .60332 Mdot
.03333 .60332 Mdot
.03429 .60332 Mdot
.03524 .60332 Mdot
.03619 .60332 Mdot
.03714 .60332 Mdot
.0381 .60332 Mdot
.03905 .60332 Mdot
.04 .60332 Mdot
.04095 .60332 Mdot
.0419 .60331 Mdot
.04286 .60329 Mdot
.04381 .60328 Mdot
.04476 .60327 Mdot
.04571 .60325 Mdot
.04667 .60323 Mdot
.04762 .6032 Mdot
.04857 .60316 Mdot
.04952 .60312 Mdot
.05048 .60306 Mdot
.05143 .60299 Mdot
.05238 .6029 Mdot
.05333 .60278 Mdot
.05429 .60262 Mdot
.05524 .60241 Mdot
.05619 .60212 Mdot
.05714 .60173 Mdot
.0581 .6012 Mdot
.05905 .60046 Mdot
.06 .59941 Mdot
.06095 .59791 Mdot
.0619 .59576 Mdot
.06286 .59262 Mdot
.06381 .58803 Mdot
.06476 .58133 Mdot
.06571 .57161 Mdot
.06667 .55768 Mdot
.06762 .53783 Mdot
.06857 .50885 Mdot
.06952 .46202 Mdot
.07048 .3972 Mdot
.07143 .45526 Mdot
.07238 .48721 Mdot
.07333 .50413 Mdot
.07429 .51404 Mdot
.07524 .51991 Mdot
.07619 .52311 Mdot
.07714 .52434 Mdot
.0781 .52401 Mdot
.07905 .52234 Mdot
.08 .51942 Mdot
.08095 .51528 Mdot
.0819 .50989 Mdot
.08286 .50313 Mdot
.08381 .49482 Mdot
.08476 .48466 Mdot
.08571 .47218 Mdot
.08667 .45656 Mdot
.08762 .43635 Mdot
.08857 .40872 Mdot
.08952 .36978 Mdot
.09048 .35304 Mdot
.09143 .38812 Mdot
.09238 .41496 Mdot
.09333 .43274 Mdot
.09429 .4451 Mdot
.09524 .45395 Mdot
.09619 .46032 Mdot
.09714 .46481 Mdot
.0981 .46778 Mdot
.09905 .46947 Mdot
.1 .47004 Mdot
.10095 .46959 Mdot
.1019 .46818 Mdot
.10286 .46581 Mdot
.10381 .46249 Mdot
.10476 .45816 Mdot
.10571 .45275 Mdot
.10667 .44612 Mdot
.10762 .43809 Mdot
.10857 .42834 Mdot
.10952 .41641 Mdot
.11048 .40153 Mdot
.11143 .38237 Mdot
.11238 .35665 Mdot
.11333 .32327 Mdot
.11429 .31247 Mdot
.11524 .34179 Mdot
.11619 .36722 Mdot
.11714 .38517 Mdot
.1181 .3982 Mdot
.11905 .40794 Mdot
.12 .4153 Mdot
.12095 .42084 Mdot
.1219 .42492 Mdot
.12286 .42776 Mdot
.12381 .42953 Mdot
.12476 .43033 Mdot
.12571 .43022 Mdot
.12667 .42924 Mdot
.12762 .4274 Mdot
.12857 .42469 Mdot
.12952 .42108 Mdot
.13048 .41649 Mdot
.13143 .41082 Mdot
.13238 .40391 Mdot
.13333 .39554 Mdot
.13429 .38534 Mdot
.13524 .37277 Mdot
.13619 .35692 Mdot
.13714 .33626 Mdot
.1381 .30868 Mdot
.13905 .27992 Mdot
.14 .2893 Mdot
.14095 .31782 Mdot
.1419 .33984 Mdot
.14286 .35585 Mdot
.14381 .36783 Mdot
.14476 .37699 Mdot
.14571 .38406 Mdot
.14667 .3895 Mdot
.14762 .3936 Mdot
.14857 .39655 Mdot
.14952 .3985 Mdot
.15048 .39952 Mdot
.15143 .39969 Mdot
.15238 .39903 Mdot
.15333 .39755 Mdot
.15429 .39524 Mdot
.15524 .39206 Mdot
.15619 .38797 Mdot
.15714 .38286 Mdot
.1581 .3766 Mdot
.15905 .36898 Mdot
.16 .35972 Mdot
.16095 .34835 Mdot
.1619 .33413 Mdot
.16286 .31585 Mdot
.16381 .29164 Mdot
.16476 .26197 Mdot
.16571 .25404 Mdot
.16667 .28032 Mdot
.16762 .30487 Mdot
.16857 .32294 Mdot
.16952 .33643 Mdot
.17048 .34678 Mdot
.17143 .35483 Mdot
.17238 .36111 Mdot
.17333 .36597 Mdot
.17429 .36963 Mdot
.17524 .37226 Mdot
.17619 .37394 Mdot
.17714 .37476 Mdot
.1781 .37476 Mdot
.17905 .37395 Mdot
.18 .37235 Mdot
.18095 .36993 Mdot
.1819 .36665 Mdot
.18286 .36244 Mdot
.18381 .35721 Mdot
.18476 .35079 Mdot
.18571 .34298 Mdot
.18667 .33345 Mdot
.18762 .3217 Mdot
.18857 .30691 Mdot
.18952 .28777 Mdot
.19048 .26246 Mdot
.19143 .23434 Mdot
.19238 .23632 Mdot
.19333 .26358 Mdot
.19429 .28656 Mdot
.19524 .30357 Mdot
.19619 .31642 Mdot
.19714 .32637 Mdot
.1981 .33417 Mdot
.19905 .3403 Mdot
.2 .34508 Mdot
.20095 .34869 Mdot
.2019 .3513 Mdot
.20286 .353 Mdot
.20381 .35386 Mdot
.20476 .35391 Mdot
.20571 .35317 Mdot
.20667 .35164 Mdot
.20762 .3493 Mdot
.20857 .34612 Mdot
.20952 .34201 Mdot
.21048 .33689 Mdot
.21143 .3306 Mdot
.21238 .32293 Mdot
.21333 .31356 Mdot
.21429 .302 Mdot
.21524 .28745 Mdot
.21619 .26863 Mdot
.21714 .24379 Mdot
.2181 .21597 Mdot
.21905 .21667 Mdot
.22 .24354 Mdot
.22095 .26669 Mdot
.2219 .28392 Mdot
.22286 .29697 Mdot
.22381 .3071 Mdot
.22476 .31508 Mdot
.22571 .32138 Mdot
.22667 .32631 Mdot
.22762 .3301 Mdot
.22857 .33287 Mdot
.22952 .33474 Mdot
.23048 .33577 Mdot
.23143 .33599 Mdot
.23238 .33544 Mdot
.23333 .3341 Mdot
.23429 .33197 Mdot
.23524 .329 Mdot
.23619 .32514 Mdot
.23714 .32028 Mdot
.2381 .3143 Mdot
.23905 .30698 Mdot
.24 .29804 Mdot
.24095 .28702 Mdot
.2419 .2732 Mdot
.24286 .25544 Mdot
.24381 .23201 Mdot
.24476 .20384 Mdot
.24571 .19652 Mdot
.24667 .2217 Mdot
.24762 .24606 Mdot
.24857 .26431 Mdot
.24952 .27811 Mdot
.25048 .2888 Mdot
.25143 .29723 Mdot
.25238 .30391 Mdot
.25333 .30918 Mdot
.25429 .31327 Mdot
.25524 .31633 Mdot
.25619 .31846 Mdot
.25714 .31975 Mdot
.2581 .32023 Mdot
.25905 .31994 Mdot
.26 .31887 Mdot
.26095 .31702 Mdot
.2619 .31436 Mdot
.26286 .31081 Mdot
.26381 .30632 Mdot
.26476 .30074 Mdot
.26571 .2939 Mdot
.26667 .28554 Mdot
.26762 .27526 Mdot
.26857 .26245 Mdot
.26952 .24611 Mdot
.27048 .22467 Mdot
.27143 .19727 Mdot
.27238 .1792 Mdot
.27333 .1986 Mdot
.27429 .22464 Mdot
.27524 .2446 Mdot
.27619 .25961 Mdot
.27714 .27119 Mdot
.2781 .28029 Mdot
.27905 .28752 Mdot
.28 .29326 Mdot
.28095 .29775 Mdot
.2819 .30118 Mdot
.28286 .30366 Mdot
.28381 .30528 Mdot
.28476 .30609 Mdot
.28571 .30611 Mdot
.28667 .30537 Mdot
.28762 .30385 Mdot
.28857 .30153 Mdot
.28952 .29836 Mdot
.29048 .29428 Mdot
.29143 .28917 Mdot
.29238 .28288 Mdot
.29333 .27518 Mdot
.29429 .26574 Mdot
.29524 .25404 Mdot
.29619 .23924 Mdot
.29714 .22002 Mdot
.2981 .19479 Mdot
.29905 .16896 Mdot
.3 .17525 Mdot
.30095 .20213 Mdot
.3019 .22443 Mdot
.30286 .24115 Mdot
.30381 .25394 Mdot
.30476 .26395 Mdot
.30571 .27189 Mdot
.30667 .27821 Mdot
.30762 .28321 Mdot
.30857 .28709 Mdot
.30952 .28998 Mdot
.31048 .29198 Mdot
.31143 .29315 Mdot
.31238 .29354 Mdot
.31333 .29315 Mdot
.31429 .292 Mdot
.31524 .29007 Mdot
.31619 .28732 Mdot
.31714 .28368 Mdot
.3181 .27907 Mdot
.31905 .27336 Mdot
.32 .26635 Mdot
.32095 .25777 Mdot
.3219 .24718 Mdot
.32286 .23392 Mdot
.32381 .21691 Mdot
.32476 .19453 Mdot
.32571 .1669 Mdot
.32667 .15518 Mdot
.32762 .17832 Mdot
.32857 .20336 Mdot
.32952 .22234 Mdot
.33048 .23673 Mdot
.33143 .24789 Mdot
.33238 .25672 Mdot
.33333 .26376 Mdot
.33429 .26936 Mdot
.33524 .27376 Mdot
.33619 .27712 Mdot
.33714 .27955 Mdot
.3381 .28113 Mdot
.33905 .28192 Mdot
.34 .28193 Mdot
.34095 .28117 Mdot
.3419 .27965 Mdot
.34286 .27733 Mdot
.34381 .27416 Mdot
.34476 .27007 Mdot
.34571 .26494 Mdot
.34667 .25863 Mdot
.34762 .25089 Mdot
.34857 .24138 Mdot
.34952 .22957 Mdot
.35048 .21461 Mdot
.35143 .19512 Mdot
.35238 .16963 Mdot
.35333 .145 Mdot
.35429 .15404 Mdot
.35524 .18086 Mdot
.35619 .20275 Mdot
.35714 .2192 Mdot
.3581 .23183 Mdot
.35905 .24176 Mdot
.36 .24965 Mdot
.36095 .25596 Mdot
.3619 .26096 Mdot
.36286 .26485 Mdot
.36381 .26777 Mdot
.36476 .2698 Mdot
.36571 .27102 Mdot
.36667 .27145 Mdot
.36762 .27112 Mdot
.36857 .27002 Mdot
.36952 .26815 Mdot
.37048 .26545 Mdot
.37143 .26188 Mdot
.37238 .25735 Mdot
.37333 .25171 Mdot
.37429 .24479 Mdot
.37524 .23629 Mdot
.37619 .22581 Mdot
.37714 .21268 Mdot
.3781 .19583 Mdot
.37905 .17368 Mdot
.38 .14626 Mdot
.38095 .13397 Mdot
.3819 .15668 Mdot
.38286 .18181 Mdot
.38381 .20094 Mdot
.38476 .21545 Mdot
.38571 .22673 Mdot
.38667 .23567 Mdot
.38762 .24281 Mdot
.38857 .2485 Mdot
.38952 .25299 Mdot
.39048 .25645 Mdot
.39143 .25898 Mdot
.39238 .26065 Mdot
.39333 .26153 Mdot
.39429 .26164 Mdot
.39524 .26099 Mdot
.39619 .25958 Mdot
.39714 .25737 Mdot
.3981 .25432 Mdot
.39905 .25036 Mdot
.4 .24538 Mdot
.40095 .23923 Mdot
.4019 .23169 Mdot
.40286 .22242 Mdot
.40381 .21091 Mdot
.40476 .19634 Mdot
.40571 .17743 Mdot
.40667 .15261 Mdot
.40762 .12694 Mdot
.40857 .13227 Mdot
.40952 .15897 Mdot
.41048 .18146 Mdot
.41143 .19839 Mdot
.41238 .21137 Mdot
.41333 .22157 Mdot
.41429 .22969 Mdot
.41524 .23619 Mdot
.41619 .24137 Mdot
.41714 .24542 Mdot
.4181 .24849 Mdot
.41905 .25067 Mdot
.42 .25202 Mdot
.42095 .2526 Mdot
.4219 .25241 Mdot
.42286 .25146 Mdot
.42381 .24975 Mdot
.42476 .24722 Mdot
.42571 .24383 Mdot
.42667 .23949 Mdot
.42762 .23407 Mdot
.42857 .22741 Mdot
.42952 .21923 Mdot
.43048 .20914 Mdot
.43143 .19653 Mdot
.43238 .18042 Mdot
.43333 .15928 Mdot
.43429 .13241 Mdot
.43524 .11502 Mdot
.43619 .13421 Mdot
.43714 .16013 Mdot
.4381 .18017 Mdot
.43905 .19534 Mdot
.44 .20711 Mdot
.44095 .21642 Mdot
.4419 .22386 Mdot
.44286 .22982 Mdot
.44381 .23454 Mdot
.44476 .23821 Mdot
.44571 .24093 Mdot
.44667 .2428 Mdot
.44762 .24386 Mdot
.44857 .24415 Mdot
.44952 .24369 Mdot
.45048 .24246 Mdot
.45143 .24045 Mdot
.45238 .23762 Mdot
.45333 .23389 Mdot
.45429 .22918 Mdot
.45524 .22333 Mdot
.45619 .21614 Mdot
.45714 .20731 Mdot
.4581 .19638 Mdot
.45905 .1826 Mdot
.46 .16481 Mdot
.46095 .14139 Mdot
.4619 .11434 Mdot
.46286 .11085 Mdot
.46381 .13641 Mdot
.46476 .16023 Mdot
.46571 .17824 Mdot
.46667 .19199 Mdot
.46762 .20276 Mdot
.46857 .21132 Mdot
.46952 .21819 Mdot
.47048 .22367 Mdot
.47143 .228 Mdot
.47238 .23132 Mdot
.47333 .23373 Mdot
.47429 .23531 Mdot
.47524 .23611 Mdot
.47619 .23614 Mdot
.47714 .23541 Mdot
.4781 .23392 Mdot
.47905 .23164 Mdot
.48 .22851 Mdot
.48095 .22446 Mdot
.4819 .21938 Mdot
.48286 .2131 Mdot
.48381 .20538 Mdot
.48476 .19589 Mdot
.48571 .18406 Mdot
.48667 .16905 Mdot
.48762 .14947 Mdot
.48857 .12395 Mdot
.48952 .10042 Mdot
.49048 .11117 Mdot
.49143 .13787 Mdot
.49238 .15951 Mdot
.49333 .17584 Mdot
.49429 .18844 Mdot
.49524 .19837 Mdot
.49619 .2063 Mdot
.49714 .21267 Mdot
.4981 .21774 Mdot
.49905 .22172 Mdot
.5 .22473 Mdot
.50095 .22686 Mdot
.5019 .22818 Mdot
.50286 .22872 Mdot
.50381 .22851 Mdot
.50476 .22755 Mdot
.50571 .22581 Mdot
.50667 .22326 Mdot
.50762 .21985 Mdot
.50857 .21548 Mdot
.50952 .21003 Mdot
.51048 .20332 Mdot
.51143 .19507 Mdot
.51238 .18489 Mdot
.51333 .17215 Mdot
.51429 .15582 Mdot
.51524 .13437 Mdot
.51619 .10742 Mdot
.51714 .09218 Mdot
.5181 .11286 Mdot
.51905 .13846 Mdot
.52 .15817 Mdot
.52095 .17312 Mdot
.5219 .18475 Mdot
.52286 .19398 Mdot
.52381 .20137 Mdot
.52476 .2073 Mdot
.52571 .21201 Mdot
.52667 .21567 Mdot
.52762 .2184 Mdot
.52857 .22028 Mdot
.52952 .22136 Mdot
.53048 .22168 Mdot
.53143 .22124 Mdot
.53238 .22004 Mdot
.53333 .21807 Mdot
.53429 .21527 Mdot
.53524 .21158 Mdot
.53619 .20691 Mdot
.53714 .2011 Mdot
.5381 .19396 Mdot
.53905 .18518 Mdot
.54 .17431 Mdot
.54095 .1606 Mdot
.5419 .14289 Mdot
.54286 .11959 Mdot
.54381 .09266 Mdot
.54476 .08897 Mdot
.54571 .11441 Mdot
.54667 .13828 Mdot
.54762 .15635 Mdot
.54857 .17016 Mdot
.54952 .18099 Mdot
.55048 .18961 Mdot
.55143 .19654 Mdot
.55238 .20208 Mdot
.55333 .20647 Mdot
.55429 .20985 Mdot
.55524 .21233 Mdot
.55619 .21398 Mdot
.55714 .21484 Mdot
.5581 .21494 Mdot
.55905 .21429 Mdot
.56 .21288 Mdot
.56095 .21068 Mdot
.5619 .20764 Mdot
.56286 .20369 Mdot
.56381 .19872 Mdot
.56476 .19256 Mdot
.56571 .185 Mdot
.56667 .17569 Mdot
.56762 .1641 Mdot
.56857 .1494 Mdot
.56952 .13027 Mdot
.57048 .10526 Mdot
.57143 .08074 Mdot
.57238 .08868 Mdot
.57333 .11536 Mdot
.57429 .13747 Mdot
.57524 .15416 Mdot
.57619 .16703 Mdot
.57714 .17717 Mdot
.5781 .18528 Mdot
.57905 .1918 Mdot
.58 .19701 Mdot
.58095 .20111 Mdot
.5819 .20424 Mdot
.58286 .20649 Mdot
.58381 .20792 Mdot
.58476 .20858 Mdot
.58571 .20849 Mdot
.58667 .20764 Mdot
.58762 .20603 Mdot
.58857 .20362 Mdot
.58952 .20035 Mdot
.59048 .19615 Mdot
.59143 .19089 Mdot
.59238 .1844 Mdot
.59333 .17642 Mdot
.59429 .16657 Mdot
.59524 .15427 Mdot
.59619 .13856 Mdot
.59714 .11799 Mdot
.5981 .09163 Mdot
.59905 .07241 Mdot
.6 .08944 Mdot
.60095 .11563 Mdot
.6019 .13615 Mdot
.60286 .1517 Mdot
.60381 .16376 Mdot
.60476 .17332 Mdot
.60571 .18099 Mdot
.60667 .18715 Mdot
.60762 .19206 Mdot
.60857 .19591 Mdot
.60952 .19881 Mdot
.61048 .20085 Mdot
.61143 .2021 Mdot
.61238 .20257 Mdot
.61333 .2023 Mdot
.61429 .20127 Mdot
.61524 .19947 Mdot
.61619 .19686 Mdot
.61714 .19338 Mdot
.6181 .18894 Mdot
.61905 .1834 Mdot
.62 .17658 Mdot
.62095 .1682 Mdot
.6219 .15782 Mdot
.62286 .1448 Mdot
.62381 .12808 Mdot
.62476 .10608 Mdot
.62571 .07905 Mdot
.62667 .06752 Mdot
.62762 .09022 Mdot
.62857 .11526 Mdot
.62952 .13442 Mdot
.63048 .14901 Mdot
.63143 .1604 Mdot
.63238 .16946 Mdot
.63333 .17674 Mdot
.63429 .18259 Mdot
.63524 .18724 Mdot
.63619 .19086 Mdot
.63714 .19356 Mdot
.6381 .19542 Mdot
.63905 .19649 Mdot
.64 .1968 Mdot
.64095 .19636 Mdot
.6419 .19516 Mdot
.64286 .19319 Mdot
.64381 .1904 Mdot
.64476 .18672 Mdot
.64571 .18205 Mdot
.64667 .17625 Mdot
.64762 .16911 Mdot
.64857 .16034 Mdot
.64952 .14945 Mdot
.65048 .13572 Mdot
.65143 .11798 Mdot
.65238 .09464 Mdot
.65333 .06793 Mdot
.65429 .06507 Mdot
.65524 .09061 Mdot
.65619 .11435 Mdot
.65714 .13235 Mdot
.6581 .14613 Mdot
.65905 .15696 Mdot
.66 .16559 Mdot
.66095 .17254 Mdot
.6619 .17811 Mdot
.66286 .18254 Mdot
.66381 .18596 Mdot
.66476 .18848 Mdot
.66571 .19017 Mdot
.66667 .19108 Mdot
.66762 .19124 Mdot
.66857 .19065 Mdot
.66952 .1893 Mdot
.67048 .18717 Mdot
.67143 .18421 Mdot
.67238 .18034 Mdot
.67333 .17547 Mdot
.67429 .16942 Mdot
.67524 .16199 Mdot
.67619 .15284 Mdot
.67714 .14146 Mdot
.6781 .12704 Mdot
.67905 .10831 Mdot
.68 .08377 Mdot
.68095 .05858 Mdot
.6819 .06392 Mdot
.68286 .09046 Mdot
.68381 .11297 Mdot
.68476 .13 Mdot
.68571 .14311 Mdot
.68667 .15345 Mdot
.68762 .16172 Mdot
.68857 .16838 Mdot
.68952 .17372 Mdot
.69048 .17794 Mdot
.69143 .18118 Mdot
.69238 .18355 Mdot
.69333 .18509 Mdot
.69429 .18587 Mdot
.69524 .18589 Mdot
.69619 .18516 Mdot
.69714 .18368 Mdot
.6981 .18141 Mdot
.69905 .17829 Mdot
.7 .17425 Mdot
.70095 .16918 Mdot
.7019 .16291 Mdot
.70286 .15521 Mdot
.70381 .1457 Mdot
.70476 .13385 Mdot
.70571 .11878 Mdot
.70667 .09911 Mdot
.70762 .07358 Mdot
.70857 .0511 Mdot
.70952 .06322 Mdot
.71048 .08976 Mdot
.71143 .11119 Mdot
.71238 .1274 Mdot
.71333 .13996 Mdot
.71429 .14989 Mdot
.71524 .15785 Mdot
.71619 .16427 Mdot
.71714 .1694 Mdot
.7181 .17345 Mdot
.71905 .17654 Mdot
.72 .17876 Mdot
.72095 .18018 Mdot
.7219 .18083 Mdot
.72286 .18073 Mdot
.72381 .17989 Mdot
.72476 .17829 Mdot
.72571 .17588 Mdot
.72667 .17263 Mdot
.72762 .16844 Mdot
.72857 .1632 Mdot
.72952 .15672 Mdot
.73048 .14876 Mdot
.73143 .13894 Mdot
.73238 .12665 Mdot
.73333 .11097 Mdot
.73429 .09043 Mdot
.73524 .06417 Mdot
.73619 .04529 Mdot
.73714 .06244 Mdot
.7381 .08856 Mdot
.73905 .10905 Mdot
.74 .1246 Mdot
.74095 .13669 Mdot
.7419 .14628 Mdot
.74286 .15399 Mdot
.74381 .16019 Mdot
.74476 .16515 Mdot
.74571 .16905 Mdot
.74667 .17201 Mdot
.74762 .17412 Mdot
.74857 .17542 Mdot
.74952 .17597 Mdot
.75048 .17577 Mdot
.75143 .17482 Mdot
.75238 .17311 Mdot
.75333 .1706 Mdot
.75429 .16723 Mdot
.75524 .16291 Mdot
.75619 .15751 Mdot
.75714 .15085 Mdot
.7581 .14267 Mdot
.75905 .13256 Mdot
.76 .11988 Mdot
.76095 .10364 Mdot
.7619 .08232 Mdot
.76286 .05562 Mdot
.76381 .04076 Mdot
.76476 .06135 Mdot
.76571 .08687 Mdot
.76667 .10659 Mdot
.76762 .12161 Mdot
.76857 .13332 Mdot
.76952 .14263 Mdot
.77048 .15012 Mdot
.77143 .15615 Mdot
.77238 .16097 Mdot
.77333 .16474 Mdot
.77429 .16759 Mdot
.77524 .1696 Mdot
.77619 .17082 Mdot
.77714 .17127 Mdot
.7781 .17099 Mdot
.77905 .16995 Mdot
.78 .16815 Mdot
.78095 .16555 Mdot
.7819 .16208 Mdot
.78286 .15764 Mdot
.78381 .15212 Mdot
.78476 .1453 Mdot
.78571 .13693 Mdot
.78667 .12657 Mdot
.78762 .11355 Mdot
.78857 .09683 Mdot
.78952 .07485 Mdot
.79048 .04798 Mdot
.79143 .03702 Mdot
.79238 .05981 Mdot
.79333 .08475 Mdot
.79429 .10385 Mdot
.79524 .11843 Mdot
.79619 .12984 Mdot
.79714 .13893 Mdot
.7981 .14625 Mdot
.79905 .15214 Mdot
.8 .15684 Mdot
.80095 .16052 Mdot
.8019 .16328 Mdot
.80286 .16521 Mdot
.80381 .16635 Mdot
.80476 .16673 Mdot
.80571 .16638 Mdot
.80667 .16528 Mdot
.80762 .1634 Mdot
.80857 .16072 Mdot
.80952 .15717 Mdot
.81048 .15264 Mdot
.81143 .14701 Mdot
.81238 .14008 Mdot
.81333 .13155 Mdot
.81429 .12098 Mdot
.81524 .10769 Mdot
.81619 .09057 Mdot
.81714 .06806 Mdot
.8181 .04123 Mdot
.81905 .03366 Mdot
.82 .05778 Mdot
.82095 .08221 Mdot
.8219 .10084 Mdot
.82286 .11509 Mdot
.82381 .12627 Mdot
.82476 .13519 Mdot
.82571 .14237 Mdot
.82667 .14816 Mdot
.82762 .15277 Mdot
.82857 .15637 Mdot
.82952 .15907 Mdot
.83048 .16093 Mdot
.83143 .16201 Mdot
.83238 .16235 Mdot
.83333 .16194 Mdot
.83429 .16078 Mdot
.83524 .15886 Mdot
.83619 .15612 Mdot
.83714 .15251 Mdot
.8381 .14791 Mdot
.83905 .14221 Mdot
.84 .13518 Mdot
.84095 .12653 Mdot
.8419 .11581 Mdot
.84286 .10231 Mdot
.84381 .08489 Mdot
.84476 .06199 Mdot
.84571 .03531 Mdot
.84667 .03036 Mdot
.84762 .05524 Mdot
.84857 .07928 Mdot
.84952 .09757 Mdot
.85048 .11159 Mdot
.85143 .1226 Mdot
.85238 .13139 Mdot
.85333 .13848 Mdot
.85429 .14419 Mdot
.85524 .14874 Mdot
.85619 .15229 Mdot
.85714 .15494 Mdot
.8581 .15676 Mdot
.85905 .15781 Mdot
.86 .1581 Mdot
.86095 .15766 Mdot
.8619 .15647 Mdot
.86286 .15451 Mdot
.86381 .15174 Mdot
.86476 .14808 Mdot
.86571 .14345 Mdot
.86667 .13769 Mdot
.86762 .1306 Mdot
.86857 .12188 Mdot
.86952 .11107 Mdot
.87048 .09743 Mdot
.87143 .07982 Mdot
.87238 .05668 Mdot
.87333 .03017 Mdot
.87429 .02691 Mdot
.87524 .05218 Mdot
.87619 .07595 Mdot
.87714 .09403 Mdot
.8781 .10791 Mdot
.87905 .11882 Mdot
.88 .12754 Mdot
.88095 .13457 Mdot
.8819 .14024 Mdot
.88286 .14475 Mdot
.88381 .14827 Mdot
.88476 .15089 Mdot
.88571 .15269 Mdot
.88667 .15372 Mdot
.88762 .15399 Mdot
.88857 .15353 Mdot
.88952 .15233 Mdot
.89048 .15036 Mdot
.89143 .14757 Mdot
.89238 .1439 Mdot
.89333 .13924 Mdot
.89429 .13346 Mdot
.89524 .12635 Mdot
.89619 .1176 Mdot
.89714 .10675 Mdot
.8981 .09306 Mdot
.89905 .07537 Mdot
.9 .05215 Mdot
.90095 .02573 Mdot
.9019 .02318 Mdot
.90286 .04857 Mdot
.90381 .07224 Mdot
.90476 .09024 Mdot
.90571 .10405 Mdot
.90667 .11492 Mdot
.90762 .12362 Mdot
.90857 .13064 Mdot
.90952 .13629 Mdot
.91048 .14079 Mdot
.91143 .1443 Mdot
.91238 .14692 Mdot
.91333 .14872 Mdot
.91429 .14974 Mdot
.91524 .15002 Mdot
.91619 .14956 Mdot
.91714 .14836 Mdot
.9181 .14639 Mdot
.91905 .1436 Mdot
.92 .13994 Mdot
.92095 .1353 Mdot
.9219 .12953 Mdot
.92286 .12243 Mdot
.92381 .1137 Mdot
.92476 .10287 Mdot
.92571 .08921 Mdot
.92667 .07157 Mdot
.92762 .0484 Mdot
.92857 .02199 Mdot
.92952 .01912 Mdot
.93048 .04441 Mdot
.93143 .06812 Mdot
.93238 .08616 Mdot
.93333 .10001 Mdot
.93429 .11091 Mdot
.93524 .11963 Mdot
.93619 .12666 Mdot
.93714 .13233 Mdot
.9381 .13685 Mdot
.93905 .14038 Mdot
.94 .14301 Mdot
.94095 .14483 Mdot
.9419 .14587 Mdot
.94286 .14616 Mdot
.94381 .14573 Mdot
.94476 .14455 Mdot
.94571 .1426 Mdot
.94667 .13984 Mdot
.94762 .13621 Mdot
.94857 .1316 Mdot
.94952 .12587 Mdot
.95048 .11883 Mdot
.95143 .11016 Mdot
.95238 .09941 Mdot
.95333 .08588 Mdot
.95429 .0684 Mdot
.95524 .04546 Mdot
.95619 .01895 Mdot
.95714 .01472 Mdot
.9581 .03967 Mdot
.95905 .06358 Mdot
.96 .08178 Mdot
.96095 .09576 Mdot
.9619 .10675 Mdot
.96286 .11554 Mdot
.96381 .12263 Mdot
.96476 .12835 Mdot
.96571 .13292 Mdot
.96667 .13648 Mdot
.96762 .13916 Mdot
.96857 .14101 Mdot
.96952 .14209 Mdot
.97048 .14242 Mdot
.97143 .14203 Mdot
.97238 .14089 Mdot
.97333 .13899 Mdot
.97429 .13628 Mdot
.97524 .1327 Mdot
.97619 .12815 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gPP10`40000100000800002008200000
P800P020P<30`8f9HL:oYL3L`:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV
09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000
<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI
<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0
I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<
IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHc
VITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<
VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01V
c3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Ko
c9Woc<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2I
oc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D5
1@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5?okl0000000000000000000
00000>7PdZ2PY820P?l0003o0?oo0000ool0o`3oooooooooJOl00?ooJOl00?ooJOl00?ooJOl00?oo
JOl001?o00<0ool0oomCo`004ol00`3oo`3ooe?o000Co`030?oo0?ooDol000Wo1006o`030?oo0?oo
Dol000So00<0ool00_l00`3oo`03o`030?oo0?ooDol000So00<0ool00_l00`3oo`03o`030?oo0?oo
>ol201Ko000600;o00<0ool00_l00`3oo`03o`<0oolko`805_l000Wo1006o`030?oo0?oo<_l200Oo
0P0Fo`002?l00`3oo`02o`030?oo00?o00<0ool0oolXo`801ol300Oo0P0Fo`002?l00`3oo`02o`03
0?oo00?o00<0ool0oolOo`801ol200Oo0P0Po`002Ol400Ko00<0ool0oolOo`801ol202Wo000Co`03
0?oo0?oo5_l200Oo0P0bo`004ol00`3oo`3oo`co0P07o`<01ol203;o000Co`030?oo0?oo0ol200Oo
0P07o`80??l001?o00<0ool0n?l200So0P07o`80;_l201Go000Co`030?oo0?So0P0Ao`809?l200So
0P0Eo`004ol00`3oo`3_o`80@?l200Oo0P0Fo`004ol00`3oo`3_o`804?l202Go0P06o`802?l201Ko
000Co`030?oo0>Go0P0Jo`806ol200Oo0`06o`808?l001?o0P3Vo`804Ol201_o0P07o`801ol202Wo
000Co`030?oo0=co0P0Jo`804Ol200So0P06o`80<ol001?o00<0ool0g?l201_o0P07o`801ol200Oo
0P07o`80<ol001?o00<0ool0dol200Oo0P08o`801ol200So0P07o`804?l202Go0P0Eo`004ol00`3o
o`3:o`801ol200Oo0P08o`801ol201Wo0P0Uo`802?l201Go000Co`030?oo0<[o0P07o`80=Ol202Go
0P06o`805ol001?o00<0ool0`?l202?o0P11o`801_l200Oo0P0Go`004ol00`3oo`30o`808ol201[o
0P0Lo`801Ol400Ko0P0Po`004ol00`3oo`39o`80=_l201;o0P06o`@01Ol202[o000Co`030?oo0;Oo
0P0@o`80;Ol201;o0P07o`801_l201co0P0Eo`004ol00`3oo`2go`808ol201[o0P08o`802?l200Ko
0P0Uo`805Ol001?o00<0ool0]ol202?o0P0Bo`801ol200Oo0P0@o`807?l200Go0P0Go`004ol20:oo
0P07o`801ol200So0P07o`802?l200Oo0P06o`@01ol200oo0P0Lo`801Ol20003o`0000Go0P0Go`00
4ol00`3oo`2To`801ol3013o0P08o`801ol200So0P07o`801_l201[o0P0Co`801Ol400Go0P0Qo`00
4ol00`3oo`2To`801ol2017o0P0@o`80;Ol201[o1005o`804ol201Go000Co`030?oo09_o0P0eo`80
4Ol201[o0P0Bo`801_l201?o0P05o`@05Ol001?o00<0ool0Vol204So0P0Uo`801Ol401So0P000ol0
0005o`805ol001?o00<0ool0]_l2017o0P0/o`802_l200Oo0P05o`805?l200Co0P0Qo`004ol00`3o
o`2To`804?l2017o0P0@o`804ol200Go1008o`801Ol201?o0P05o`8000?o00004Ol201Co000Co`03
0?oo09;o0P07o`801ol203Go0P09o`801_l400Oo0P0?o`802_l200Co0P000ol00005o`802_l200Co
0P02o`805?l001?o00<0ool0R?l200Oo0`07o`801ol200So0P0To`801ol200Oo0P06o`804?l201Co
0P04o`802ol200Co0P000ol00004o`806?l001?o00<0ool0R?l200Oo0P0Ao`802?l200Oo0P06o`@0
1ol200Ko1007o`808Ol200[o0P05o`804?l200;o0P04o`802ol201Co000Co`030?oo0:go0P08o`80
1_l400Oo0P06o`804?l2017o0P0:o`801ol200Go0P0;o`800ol200co0P03o`800_l201Co000Co`03
0?oo0:go0P0eo`804Ol20003o`0000Oo0P04o`802ol200Co0P02o`801ol200Co0P02o`800ol200;o
0P0Do`004ol00`3oo`2Jo`80D_l400So0P04o`801ol200;o0P04o`8000?o00001?l200Oo0P02o`80
1?l200;o0P03o`800_l201Co000Co`80P?l201Wo0P0]o`804?l200[o0P05o`@03_l200_o0P04o`80
2ol200?o0P07o`800ol200?o0P03o`800_l200oo000Co`030?oo07oo0P07o`80;?l2017o0P09o`80
1Ol400So0P0>o`802_l200Co0P0;o`801?l200;o0P08o`800_l200?o0P02o`801?l200;o0P0?o`00
4ol00`3oo`1fo`801ol200Oo0`0Io`804?l201;o0P08o`801ol200Go0P0Ao`8000?o00001ol200Co
0P02o`800ol200;o0P04o`800_l200?o0P03o`800_l200?o0P02o`801?l20003o`00013o000Co`03
0?oo07Ko0P0Ao`801ol200Oo0P07o`<01ol200So0P07o`801ol200Ko0P0@o`802_l200So0P04o`80
2ol200?o0P03o`800_l200?o0P03o`800ol200;o0P04o`8000?o00001?l20003o`00013o000Co`03
0?oo097o0`07o`802?l200Oo0P08o`801Ol400oo0P07o`802_l200Co0P000ol0000>o`800_l200?o
0P0<o`800_l200Co0P000ol00004o`800_l200Co0P000ol00004o`D04?l001?o00<0ool0TOl201[o
0P0@o`806_l20003o`0000Oo0P04o`801ol200;o0P08o`800ol200;o0P03o`800ol200;o0P04o`80
00?o00001?l600Co1@05o`@04?l001?o00<0ool0K?l200Oo0P0fo`806Ol200[o0P08o`801?l200_o
0P03o`800_l200?o0P03o`800ol200;o0P03o`800ol200;o0P04o`8000?o00001Ol400Go1006o`<0
4Ol001?o00<0ool0K?l200Oo0P0So`806_l2013o0P000ol00004o`8000?o00003_l20003o`0000Co
0P02o`802?l200;o0P03o`800ol200?o0P02o`800ol200;o0P04o`8000?o00001Ol400Ko0`0Jo`00
4ol00`3oo`1no`806_l201[o0P09o`802?l200Co0P07o`802ol200Co0P07o`800ol200;o0P03o`80
0_l200Co0P001?l00003o`H01?l500Go100So`002_l300Ko00<0ool0Hol200So0P0?o`808ol201?o
0P05o`@05ol200;o0P03o`803?l200?o0P07o`800ol200;o0P04o`8000?o00001Ol400Ko0`0]o`00
2Ol01@3oool000Go00<0ool0Hol200So0P07o`801ol202;o1008o`801ol200Go0P07o`802ol200Oo
0P03o`800ol200?o0P02o`800ol200?o0P02o`801?l20003o`0000Co1@05o`@01_l302go0009o`05
0?ooo`001Ol00`3oo`1fo`801ol200Oo0`07o`802?l200Oo0P05o`8000?o00005ol20003o`0000Co
0P02o`800ol200;o0P08o`800ol200;o0P03o`800ol200;o0P04o`8000?o00001?l500Go100fo`00
1P03o`050?ooo`001Ol308So0`06o`<02?l200ko0P07o`802ol200Oo0P04o`801ol200;o0P03o`80
0ol200;o0P03o`800_l200Co1@05o`D01Ol3043o0009o`@01_l00`3oo`1So`80;?l202;o0P000ol0
0004o`800_l2017o0P0<o`800ol200;o0P04o`8000?o00001Ol400Go1007o`80@?l000Wo00<0ool0
1ol00`3oo`1Jo`801ol200Oo0P0/o`804ol200Oo0P04o`802?l20003o`0000Co0P02o`800ol200?o
0P02o`800ol200;o0P04o`8000?o00001Ol400Ko0`19o`002_l00`3oo`06o`030?oo05[o0P0@o`80
1ol202?o0P07o`@02?l2017o0P04o`8000?o00001?l200;o0P03o`800ol200;o0P03o`<000?o0000
1?l500Go101Bo`002ol300Go00<0ool0F_l201Wo0P0Uo`801Ol400Go0P07o`801ol200;o0P03o`80
1ol200?o0P02o`801?l200;o0P04o`D01?l400Ko0`1Co`004ol00`3oo`1Ao`801ol200So0P0Ho`80
4ol200Oo0P0>o`801ol200;o0P03o`801ol200?o0P02o`801?l20003o`0000Co0P001?l00004o`@0
1_l305co000Co`030?oo057o0P0Ao`801ol200Oo0P06o`@01Ol400So0P0Jo`802?l200Oo0P08o`80
0_l200Co0P000ol00004o`D01Ol406Go000Co`030?oo06go0P07o`802?l200Go1005o`801ol200So
0P000ol00004o`8000?o00001?l200;o0P03o`800_l200?o0P03o`800_l200Co0P000ol00005o`@0
1_l306Go000Co`030?oo093o0P07o`802?l20003o`0000Co0P07o`800_l200?o0P03o`800_l200?o
0P02o`801?l500Go101^o`004ol00`3oo`2Lo`804_l200_o0P04o`800_l200?o1P04o`@01ol206oo
000Co`030?oo09?o0P07o`802?l200?o0P03o`800_l200?o0P02o`801?l20004o`0000Co1005o`@0
N?l001?o00<0ool0B?l200oo0P08o`801ol200Oo0P07o`801ol20003o`0000Co0P000ol00004o`80
1ol200;o0P03o`800ol200;o0P03o`<000?o00001?l20003o`0000Go1021o`004ol00`3oo`18o`80
1_l300Ko0P08o`801ol200Oo0P07o`@01Ol20003o`0000Co0P07o`800_l200?o0P0<o`800_l200Co
0P000ol00004o`D01Ol4087o000Co`80DOl300Oo0P0Ao`802?l200Oo0P0Ao`802?l200Oo0P03o`80
0ol200;o0P04o`8000?o00001Ol408[o000Co`030?oo04Oo0P0Ao`802?l200Oo0P08o`806_l200Co
0P07o`800_l200?o0P03o`800_l200Co0P000ol00005o`<0Rol001?o00<0ool0Aol201_o0P0To`80
1?l200Oo0P02o`800ol200?o0P02o`801?l500Co1@2Co`004ol00`3oo`1no`@01Ol20003o`0000Co
0P02o`801ol200?o0P03o`8000Co00001?l400Ko0`2Do`004ol00`3oo`1[o`801ol200So1005o`80
2ol200;o0P03o`800ol200?o0P000ol00005o`@0WOl001?o00<0ool0?_l3027o0P07o`801ol20003
o`00017o0P03o`801ol200?o0P02o`801?l20003o`0000Go102Mo`004ol00`3oo`0no`<06?l200Oo
0P0:o`801ol200go0P02o`800ol200?o0P02o`801?l20003o`0000Co1@06o`80W_l001?o00<0ool0
B?l200oo0P09o`802?l200go0P02o`800ol200Oo0P03o`800_l200Co0P000ol00005o`@0Y_l001?o
00<0ool0B?l200Ko0`08o`801ol200ko0P07o`800_l200So0P02o`800ol200;o0P04o`D01Ol30:Oo
000Co`030?oo053o0`08o`805ol20003o`0000go0P03o`800_l200?o0`000ol00004o`@0/?l001?o
00<0ool0Aol202;o0P000ol00007o`801?l200;o0P03o`800ol200;o0P04o`D01Ol30;3o000Co`03
0?oo03Go0P0@o`806Ol200Oo0P000ol0000=o`800_l200?o0P03o`8000?o00001Ol40;Wo000Co`80
=_l202_o0P000ol0000=o`800_l200Oo0P03o`800ol20003o`0000Go102io`004ol00`3oo`0eo`80
8_l400So0P0=o`800_l200?o0P02o`800_l200Co1@06o`<0^Ol001?o00<0ool0?_l301So100>o`80
00?o00002?l200?o0P03o`8000?o00001Ol40<;o000Co`030?oo03ko0`07o`801_l401Oo0P000ol0
0003o`800ol200;o0P04o`8000?o00001Ol30<?o000Co`030?oo04So0P06o`@03_l20003o`0000So
0P02o`800ol200;o0P04o`D01_l20<?o000Co`030?oo06;o0P000ol00003o`800ol200;o0P03o`80
0_l200Co1@3;o`004ol00`3oo`0/o`806Ol2013o100=o`801ol200Co0P000ol00005o`<0c?l001?o
00<0ool0;?l201Wo0P0@o`@01?l200;o0P03o`800ol200;o0P04o`D0e?l001?o00<0ool0D_l200go
0P02o`800ol200?o0P02o`801?l40=Go000Co`030?oo02co0P07o`<04Ol200Co0P000ol00008o`80
1ol200So0P000ol00005o`@0eOl001?o00<0ool0;?l200Oo0`07o`802?l200Co0P07o`800_l200?o
0P02o`800ol200Co103No`004ol00`3oo`0no`<05ol200Oo0P03o`8000Co00001?l40=ko000Co`03
0?oo03ko0P06o`802_l200So0P03o`800ol20003o`0000Go103No`004ol204Oo0P07o`8000?o0000
1?l200;o0P03o`800ol20003o`0000Ko0P3Oo`004ol00`3oo`19o`801?l200Oo0P02o`800_l200Co
0P000ol0003Wo`004ol00`3oo`0So`802?l201[o0P08o`801ol200;o0P04o`D0iol001?o00<0ool0
8ol200So0P0@o`804_l200?o0P03o`8000?o00001Ol30>So000Co`030?oo03Co1005o`@01Ol200Oo
0P02o`800ol200?o0P000ol0003`o`004ol00`3oo`0To`803_l400Go0P07o`8000?o00001?l200;o
0P02o`801?l50?3o000Co`030?oo02Co0P06o`806ol200?o0P03o`800_l200Co103ao`004ol00`3o
o`0/o`808?l200?o0P02o`801Ol30?7o000Co`030?oo043o0P04o`800_l200So0P000ol0003io`00
2ol300Go00<0ool0?Ol20003o`0000Co0P02o`800_l200Co1@3io`003?l00`3oo`04o`030?oo02go
0P07o`801Ol200_o0P02o`801?l40?[o000<o`030?oo00Co00<0ool0;Ol200Go1008o`800ol200?o
0P02o`801?l40?[o000600;o1P05o`<08ol200oo0P0:o`800ol200?o0P001?l00005o`80nol000Wo
00@0ool01_l00`3oo`0Ko`801_l201So0P06o`800ol50?oo1?l000Wo00@0ool01_l00`3oo`0Ko`80
3_l200[o0P04o`8000?o00000ol200Co103oo`Co000:o`030?l000Ko00<0ool09?l200Go0P0:o`80
1ol200?o0P04o`@0ool4o`002ol200Ko00<0ool06_l200So0P07o`801Ol200Ko0P03o`800_l200Co
0`3oo`Go000Co`030?oo01[o0P0Ao`801Ol200Ko0P03o`8000?o0000ool=o`004ol00`3oo`0go`80
2?l20003o`000?oo3Ol001?o00<0ool0=ol200?o0P03o`8000?o0000ool=o`004ol00`3oo`0[o`80
1_l200;o0P03o`800ol50?oo3Ol001?o00<0ool08ol200Ko0P000ol00003o`800_l200?o0P04o`<0
ool>o`004ol00`3oo`0So`<02?l200So0P02o`801?l30?oo3_l001?o00<0ool06ol200Oo0P0=o`80
0ol20003o`000?oo5_l001?o00<0ool06ol2017o0P03o`800ol20003o`000?oo5_l001?o0P0/o`80
00?o00002?l20003o`000?oo5_l001?o00<0ool0:ol200Ko0P03o`D0oolFo`004ol00`3oo`0Co`80
6Ol200?o0P04o`<0oolGo`004ol00`3oo`0Co`801Ol200Ko0P000ol00007o`800ol200Co0`3ooaOo
000Co`030?oo01[o0P06o`8000?o00000ol200?o0P02o`80oolNo`004ol00`3oo`0Zo`800ol20003
o`000?oo7ol001?o00<0ool06ol201;o0P000ol0003ooaoo000Co`030?oo01;o0P07o`802?l200?o
0P03o`8000?o0000oolOo`004ol00`3oo`0Bo`803_l20003o`0000?o0P03o`D0oolOo`004ol00`3o
o`0Ro`803?l30?oo8?l001?o00<0ool09Ol200?o0P04o`<0oolPo`004ol00`3oo`0Uo`800ol20?oo
9ol001?o0P0Ko`802_l20003o`000?oo:?l001?o00<0ool06_l400Co0P02o`8000?o0000oolXo`00
4ol00`3oo`0Co`801ol200Co0P02o`8000?o0000oolXo`004ol00`3oo`0Co`804Ol20003o`000?oo
:?l001?o00<0ool08Ol200?o1@3oobSo000Co`030?oo00co0P0>o`800ol200?o103oobWo000Co`03
0?oo00co0P0<o`@02Ol30?oo:Ol001?o00<0ool06_l200Go0P04o`80oolZo`004ol00`3oo`0Lo`80
0ol20?oo<?l001?o00<0ool04_l200So0P03o`80ool`o`004ol00`3oo`0Bo`803Ol20?oo<?l001?o
00<0ool04ol200Co0P02o`8000?o0000oolao`004ol00`3oo`0Co`801?l200;o0P000ol0003ooc7o
000Co`807_l20003o`000?oo<Ol001?o00<0ool07Ol20003o`000?oo<Ol001?o00<0ool06Ol200;o
1@3ooc7o000Co`030?oo01Wo0P03o`<0oolbo`004ol00`3oo`0Do`802?l30?oo<_l001?o00<0ool0
4_l40?oo?Ol001?o00<0ool04_l200Go0P3oocSo000Co`030?oo01Wo0P3oocSo000Co`030?oo01Co
0P02o`80oolio`002?l500Ko00<0ool05?l200;o0P3oocWo0008o`050?ooo`001_l00`3oo`3ooe?o
0009o`030?oo00Oo00<0ool03?l200Ko0P02o`80oolio`001P04o`030?oo00Ko0`0<o`800ol20003
o`0000;o0P3oocWo000;o`030?oo00Go00<0ool04Ol200;o0P000ol0003oocWo000<o`030?oo00Co
00<0ool03?l200Oo103ooc[o0008o`050?ooo`001_l00`3oo`0<o`801ol40?oo>_l000Wo0`07o`03
0?oo01Go103ooc[o000Co`030?oo017o0P02o`@0ooljo`004ol00`3oo`0Ao`800ol20?oo>ol001?o
00<0ool0oomCo`004ol00`3oo`3ooe?o000Co`030?oo0?ooDol001?o00<0ool03Ol200;o0P3ood3o
000Co`030?oo00go0P02o`80oom0o`004ol00`3oo`3ooe?o000Co`804Ol20?oo@Ol001?o00<0ool0
4?l20?oo@Ol001?o00<0ool0oomCo`004ol00`3oo`0=o`8000?o0000oom1o`004ol00`3oo`0=o`80
00?o0000oom1o`004ol00`3oo`0;o`800ol20?oo@Ol001?o00<0ool02ol200?o0P3ood7o000Co`03
0?oo00go103ood;o000Co`030?oo00go103ood;o000Co`030?oo00go103ood;o000Co`030?oo00go
103ood;o000Co`030?oo00ko0P3ood?o000Co`80oomDo`004ol00`3oo`3ooe?o000Co`030?oo0?oo
Dol001?o00<0ool02ol20?ooA_l001?o00<0ool02ol20?ooA_l001?o00<0ool0oomCo`004ol00`3o
o`3ooe?o000Co`030?oo0?ooDol001?o00<0ool0oomCo`004ol00`3oo`0;o`80oom6o`004ol00`3o
o`0;o`809_l500Co1004o`@0;ol300?o1004o`@0;_l300Co1004o`@0;Ol400Co1004o`@0:Ol500?o
1004o`@01?l400;o000Co`030?oo03?o00D0oooo0003o`030?oo00;o00@0ool01?l00`3oo`0]o`05
0?ooo`001?l0103oo`04o`030?oo02[o00D0oooo0002o`030?oo00;o00@0ool01?l00`3oo`0Yo`03
0?oo00;o00@0ool01?l0103oo`04o`030?oo02So00<0ool00_l00`3oo`02o`040?oo00Co00@0ool0
1?l1007o000Co`030?oo03Co00<0ool01?l00`3oo`02o`040?oo00Co00<0ool0;Ol01@3oool000Co
00@0ool01?l00`3oo`0Zo`050?ooo`000_l00`3oo`02o`040?oo00Co00<0ool0:Ol00`3oo`02o`04
0?oo00Co00@0ool01?l00`3oo`0Xo`030?oo00;o00<0ool00_l0103oo`04o`040?oo00Co0@01o`00
4ol203Ko00<0ool00ol00`3oo`02o`040?oo00Co00<0ool0:Ol600;o00<0ool00_l0103oo`04o`03
0?oo02[o00D0oooo0002o`030?oo00;o00@0ool01?l00`3oo`0Yo`030?oo00;o00@0ool01?l0103o
o`04o`030?oo02So00<0ool00_l00`3oo`02o`040?oo00Co00@0ool01?l1007o000Co`030?oo00[o
0P0Zo`030?oo00;o00<0ool00_l0103oo`04o`030?oo02[o00@0ool00ol00`3oo`02o`040?oo00Co
00<0ool0:_l400?o00<0ool00_l0103oo`04o`030?oo02[o1003o`030?oo00;o00@0ool01?l00`3o
o`0Xo`030?oo00;o00<0ool00_l0103oo`04o`040?oo00Co0@01o`004ol00`3oo`0:o`80:ol01@3o
ool000Co00@0ool01?l00`3oo`0Zo`040?oo00?o00<0ool00_l0103oo`04o`030?oo02[o00<0ool0
1?l00`3oo`02o`040?oo00Co00<0ool0:Ol00`3oo`02o`040?oo00Co00@0ool01?l00`3oo`0Xo`03
0?oo00;o00<0ool00_l0103oo`04o`040?oo00Co0@01o`004ol00`3oo`0co`050?ooo`000ol00`3o
o`02o`040?oo00Co00<0ool0:ol00`3o0003o`030?oo00;o00@0ool01?l00`3oo`0[o`030?oo00?o
00<0ool00_l0103oo`04o`030?oo02Wo00<0ool00_l0103oo`04o`040?oo00Co00<0ool09_l300Co
00<0ool00_l0103oo`04o`040?oo00Co0@01o`004ol00`3oo`0:o`80:?l300Go1004o`@0;ol200Co
1004o`@0;ol300?o1004o`@0;Ol400Co1004o`@0:ol00`3oo`03o`@01?l400Co1002o`004ol00`3o
o`0:o`80oom7o`004ol00`3oo`3ooe?o000Co`030?oo00[o0P3oodOo000Co`030?oo00Wo0`3oodOo
000Co`030?oo00Wo0P3oodSo000Co`030?oo00Wo0P3oodSo000Co`030?oo00Oo103oodSo000;ool0
E`07o`004_l=00Co00<0ool03Ol00`3oo`0=o`030?oo00ko00<0ool03Ol00`3oo`0=o`030?oo00go
00<0ool03_l00`3oo`0=o`030?oo00go00<0ool03Ol00`3oo`0>o`030?oo00go00<0ool03Ol00`3o
o`0=o`030?oo00ko00<0ool03Ol00`3oo`0=o`030?oo00go00<0ool03_l00`3oo`0=o`004ol00`3o
o`0no`030?oo03ko00<0ool0?_l00`3oo`0no`030?oo03ko00<0ool03Ol001?o00<0ool0oomCo`00
4ol00`3oo`3ooe?o000Co`030?oo0?ooDol00?ooJOl00?ooJOl00?ooJOl00?ooJOl00?ooJOl00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-59.3211, -8.4448, 3.84929, \
0.0500197}}],

Cell[OutputFormData["\<\
{1.9299999999998363*Second, Null}\
\>", "\<\
{1.93 Second, Null}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({\ {qq, 1}, {qq, \(-1\)}}/\((2*qq)\)\)], "Input"],

Cell[OutputFormData["\<\
{{1/2, 1/(2*qq)}, {1/2, -1/(2*qq)}}\
\>", "\<\
  1   1      1   -1
{{-, ----}, {-, ----}}
  2  2 qq    2  2 qq\
\>"], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(ReflecNPCompiled4 = 
        Compile[\[IndentingNewLine]{{\ 
              lambda, \ _Real}, \ {angles, \ _Real, \ 1}, \ {z, _Real, 
              1}, \ {V, \ _Complex, 
              1}}, \[IndentingNewLine]Module[\[IndentingNewLine]{\ 
              hb2over2mn, \ auxCos, \ auxSin, \ nbrLayers, nbrPoints, 
              k, \ \ \[IndentingNewLine]q = {I}, \ qq, \ q0, \ Eq0, 
              Eq, \[IndentingNewLine]DD = {\ {I, 0}, {0, 0}}, 
              P = {\ {I, 0}, \ {\ 0, 0\ }}, \ M = {{I, 0}, {0, 0}}, \ R, \ 
              T}, \ \[IndentingNewLine]nbrLayers\  = \ \(Dimensions[
                  z]\)[\([1]\)]; \[IndentingNewLine]nbrPoints\  = \ \
\(Dimensions[angles]\)[\([1]\)]; \[IndentingNewLine]k = 
              2*Pi/\((lambda*10^\(-9\))\); \  (*\ 
              moment\ du\ neutron\ en\ SI\ *) \[IndentingNewLine]hb2over2mn = \
\(hb2/2\)/mn; \[IndentingNewLine]R = 
              Table[1.0, {nbrPoints}]; \[IndentingNewLine]T = 
              Table[1.0, {nbrPoints}]; \[IndentingNewLine]Eq0\  = \ 
              hb2over2mn*
                Table[1, {nbrLayers}]; \[IndentingNewLine]Do[\ \
\[IndentingNewLine]\t
              q0 = \ k*Sin[angles[\([i]\)]*Deg];  (*\ 
                comp . \ perp . \ du\ vecteur\ d' 
                  onde\ *) \[IndentingNewLine]\t
              Eq = q0*q0*Eq0; \  (*\ 
                energy\ cinetique\ perp . \ 
                    dans\ chaque\ couche\ *) \[IndentingNewLine]\t
              q = \((\((Eq - 
                          V)\)/\((hb2over2mn)\))\)^0.5; \ \ \
\[IndentingNewLine]\t (*\ 
                perp . \ 
                    wavevectors\ in\ each\ layer\ *) \[IndentingNewLine]\t
              Do[\ \[IndentingNewLine]\t\tqq = 
                  q[\([k]\)]; \[IndentingNewLine]\t\tIf[\ 
                  k \[Equal] 
                    1, \[IndentingNewLine]\t\t\tM = {\ {0.5, 
                        0.5/qq}, {0.5, \(-0.5\)/
                          qq}}, \[IndentingNewLine]\t\t\tIf[\ 
                    k \[Equal] nbrLayers, \[IndentingNewLine]\t\t\t\tM = 
                      M . {\ {1, 
                            1}, {qq, \(-qq\)}}, \[IndentingNewLine]\t\t\t\t\
auxCos\  = \ 
                      0.5*Cos[
                          qq*z[\([k]\)]]; \[IndentingNewLine]\t\t\t\tauxSin\  \
= \ \(-0.5\)*I*Sin[qq*z[\([k]\)]]; 
                    M = M . {\ {auxCos, auxSin/qq}, {qq*auxSin, 
                            auxCos}}]];\[IndentingNewLine]\t, {k, 
                  nbrLayers}\[IndentingNewLine]\t]; \[IndentingNewLine]\t (*\ \
\(T[\([i]\)] = \((1/Abs[M[\([1, 1]\)]])\)^2;\)\ *) \[IndentingNewLine]\t
              R[\([i]\)] = \((Abs[M[\([2, 1]\)]]/
                      Abs[M[\([1, 1]\)]])\)^2;\[IndentingNewLine], {i, 
                nbrPoints}\[IndentingNewLine]]; \[IndentingNewLine]\  (*\ \
\(ListPlot[Log[10, 
                    R]];\)\ \
*) \[IndentingNewLine]]\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(angles = Table[i, {i, 0.01, 10, 0.01}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ReflecNPCompiled4[0.4, angles, z, \ V];\)\  // Timing\)], "Input"],

Cell[OutputFormData["\<\
{1.150000000000091*Second, Null}\
\>", "\<\
{1.15 Second, Null}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(1.81*3*\(10/6\)/1.54\)], "Input"],

Cell[OutputFormData["\<\
5.876623376623376\
\>", "\<\
5.87662\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(2.19/1.12\)], "Input"],

Cell[OutputFormData["\<\
1.9553571428571426\
\>", "\<\
1.95536\
\>"], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 2048}, {0, 695}},
WindowToolbars->"EditBar",
WindowSize->{801, 582},
WindowMargins->{{Automatic, 0}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Default.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 90, 1, 185, "Title"],

Cell[CellGroupData[{
Cell[1854, 56, 60, 0, 66, "Section"],
Cell[1917, 58, 1025, 19, 224, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2979, 82, 122, 3, 66, "Section"],
Cell[3104, 87, 76, 1, 35, "Input"],
Cell[3183, 90, 335, 7, 122, "Text"],
Cell[3521, 99, 84, 1, 35, "Input"],

Cell[CellGroupData[{
Cell[3630, 104, 39, 1, 35, "Input"],
Cell[3672, 107, 185, 7, 55, "Output"]
}, Open  ]],
Cell[3872, 117, 496, 9, 119, "Input"],

Cell[CellGroupData[{
Cell[4393, 130, 34, 1, 35, "Input"],
Cell[4430, 133, 172, 5, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4639, 143, 42, 0, 57, "Subsection"],
Cell[4684, 145, 643, 11, 224, "Input"],

Cell[CellGroupData[{
Cell[5352, 160, 75, 1, 35, "Input"],
Cell[5430, 163, 305, 5, 35, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5784, 174, 77, 0, 57, "Subsection"],
Cell[5864, 176, 233, 5, 80, "Text"],
Cell[6100, 183, 2654, 49, 707, "Input"],
Cell[8757, 234, 75, 1, 35, "Input"],

Cell[CellGroupData[{
Cell[8857, 239, 71, 1, 35, "Input"],
Cell[8931, 242, 14882, 513, 233, 6602, 406, "GraphicsData", "PostScript", \
"Graphics"],
Cell[23816, 757, 69, 1, 35, "Output"]
}, Open  ]],
Cell[23900, 761, 1948, 37, 539, "Input"],

Cell[CellGroupData[{
Cell[25873, 802, 79, 1, 35, "Input"],
Cell[25955, 805, 68, 1, 35, "Output"]
}, Open  ]],
Cell[26038, 809, 1135, 19, 329, "Input"],
Cell[27176, 830, 1777, 33, 476, "Input"],
Cell[28956, 865, 50, 1, 35, "Input"],

Cell[CellGroupData[{
Cell[29031, 870, 80, 1, 35, "Input"],
Cell[29114, 873, 14956, 519, 233, 6664, 412, "GraphicsData", "PostScript", \
"Graphics"],
Cell[44073, 1394, 69, 1, 35, "Output"]
}, Open  ]],
Cell[44157, 1398, 2972, 53, 791, "Input"],
Cell[47132, 1453, 76, 1, 35, "Input"],

Cell[CellGroupData[{
Cell[47233, 1458, 88, 1, 35, "Input"],
Cell[47324, 1461, 35978, 1371, 233, 21321, 1185, "GraphicsData", \
"PostScript", "Graphics"],
Cell[83305, 2834, 106, 4, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[83448, 2843, 69, 1, 35, "Input"],
Cell[83520, 2846, 152, 6, 55, "Output"]
}, Open  ]],
Cell[83687, 2855, 2923, 54, 791, "Input"],
Cell[86613, 2911, 76, 1, 35, "Input"],

Cell[CellGroupData[{
Cell[86714, 2916, 88, 1, 35, "Input"],
Cell[86805, 2919, 105, 4, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[86947, 2928, 53, 1, 35, "Input"],
Cell[87003, 2931, 78, 4, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[87118, 2940, 42, 1, 35, "Input"],
Cell[87163, 2943, 79, 4, 32, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

